
CREATE TABLE "EKC15"."SQLN_EXPLAIN_PLAN"
  (
    "STATEMENT_ID" VARCHAR2(30 BYTE),
    "TIMESTAMP" DATE,
    "REMARKS"         VARCHAR2(80 BYTE),
    "OPERATION"       VARCHAR2(30 BYTE),
    "OPTIONS"         VARCHAR2(30 BYTE),
    "OBJECT_NODE"     VARCHAR2(128 BYTE),
    "OBJECT_OWNER"    VARCHAR2(30 BYTE),
    "OBJECT_NAME"     VARCHAR2(30 BYTE),
    "OBJECT_INSTANCE" NUMBER(*,0),
    "OBJECT_TYPE"     VARCHAR2(30 BYTE),
    "OPTIMIZER"       VARCHAR2(255 BYTE),
    "SEARCH_COLUMNS"  NUMBER(*,0),
    "ID"              NUMBER(*,0),
    "PARENT_ID"       NUMBER(*,0),
    "POSITION"        NUMBER(*,0),
    "COST"            NUMBER(*,0),
    "CARDINALITY"     NUMBER(*,0),
    "BYTES"           NUMBER(*,0),
    "OTHER_TAG"       VARCHAR2(255 BYTE),
    "PARTITION_START" VARCHAR2(255 BYTE),
    "PARTITION_STOP"  VARCHAR2(255 BYTE),
    "PARTITION_ID"    NUMBER(*,0),
    "OTHER" LONG,
    "DISTRIBUTION" VARCHAR2(30 BYTE)
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "USERS" ;



CREATE TABLE "EKC15"."T_DIC_ADDRESS"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_COUNTRY"   VARCHAR2(20 BYTE) DEFAULT '7',
    "F_REGION"    VARCHAR2(20 BYTE),
    "F_TOWN"      VARCHAR2(32 BYTE),
    "F_AREA"      VARCHAR2(20 BYTE),
    "F_STREET"    VARCHAR2(128 BYTE),
    "F_DOM"       VARCHAR2(10 BYTE),
    "F_KORP"      VARCHAR2(10 BYTE),
    "F_KVART"     VARCHAR2(10 BYTE),
    CONSTRAINT "CK_ADDRESS_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_ADDRESS_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_ADDRESS_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_T_DIC_ADDRESS_UPDATE" BEFORE
  UPDATE ON T_DIC_ADDRESS REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                             VARCHAR2(512);
  fld_val_new                                                                             VARCHAR2(512);
  table_code                                                                              VARCHAR2(40);
  BEGIN
    table_code := 'T_DIC_ADDRESS';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_COUNTRY
    IF( (:new.F_COUNTRY <> :old.F_COUNTRY) OR (:new.F_COUNTRY IS NULL AND :old.F_COUNTRY IS NOT NULL) OR (:new.F_COUNTRY IS NOT NULL AND :old.F_COUNTRY IS NULL) ) THEN
      fld_name          := 'T_DIC_ADDRESS.F_COUNTRY';
      fld_val_old       := TRUNCATE_STRING(:old.F_COUNTRY, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_COUNTRY, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REGION
    IF( (:new.F_REGION <> :old.F_REGION) OR (:new.F_REGION IS NULL AND :old.F_REGION IS NOT NULL) OR (:new.F_REGION IS NOT NULL AND :old.F_REGION IS NULL) ) THEN
      fld_name         := 'T_DIC_ADDRESS.F_REGION';
      fld_val_old      := GET_DICTIONARY_VALUE('Region', :old.F_REGION);
      fld_val_new      := GET_DICTIONARY_VALUE('Region', :new.F_REGION);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_TOWN
    IF( (:new.F_TOWN <> :old.F_TOWN) OR (:new.F_TOWN IS NULL AND :old.F_TOWN IS NOT NULL) OR (:new.F_TOWN IS NOT NULL AND :old.F_TOWN IS NULL) ) THEN
      fld_name       := 'T_DIC_ADDRESS.F_TOWN';
      fld_val_old    := TRUNCATE_STRING(:old.F_TOWN, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_TOWN, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_AREA
    IF( (:new.F_AREA <> :old.F_AREA) OR (:new.F_AREA IS NULL AND :old.F_AREA IS NOT NULL) OR (:new.F_AREA IS NOT NULL AND :old.F_AREA IS NULL) ) THEN
      fld_name       := 'T_DIC_ADDRESS.F_AREA';
      fld_val_old    := GET_DICTIONARY_VALUE('Area', :old.F_AREA);
      fld_val_new    := GET_DICTIONARY_VALUE('Area', :new.F_AREA);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_STREET
    IF( (:new.F_STREET <> :old.F_STREET) OR (:new.F_STREET IS NULL AND :old.F_STREET IS NOT NULL) OR (:new.F_STREET IS NOT NULL AND :old.F_STREET IS NULL) ) THEN
      fld_name         := 'T_DIC_ADDRESS.F_STREET';
      fld_val_old      := TRUNCATE_STRING(:old.F_STREET, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_STREET, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_DOM
    IF( (:new.F_DOM <> :old.F_DOM) OR (:new.F_DOM IS NULL AND :old.F_DOM IS NOT NULL) OR (:new.F_DOM IS NOT NULL AND :old.F_DOM IS NULL) ) THEN
      fld_name      := 'T_DIC_ADDRESS.F_DOM';
      fld_val_old   := TRUNCATE_STRING(:old.F_DOM, 510);
      fld_val_new   := TRUNCATE_STRING(:new.F_DOM, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_KORP
    IF( (:new.F_KORP <> :old.F_KORP) OR (:new.F_KORP IS NULL AND :old.F_KORP IS NOT NULL) OR (:new.F_KORP IS NOT NULL AND :old.F_KORP IS NULL) ) THEN
      fld_name       := 'T_DIC_ADDRESS.F_KORP';
      fld_val_old    := TRUNCATE_STRING(:old.F_KORP, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_KORP, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_KVART
    IF( (:new.F_KVART <> :old.F_KVART) OR (:new.F_KVART IS NULL AND :old.F_KVART IS NOT NULL) OR (:new.F_KVART IS NOT NULL AND :old.F_KVART IS NULL) ) THEN
      fld_name        := 'T_DIC_ADDRESS.F_KVART';
      fld_val_old     := TRUNCATE_STRING(:old.F_KVART, 510);
      fld_val_new     := TRUNCATE_STRING(:new.F_KVART, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_T_DIC_ADDRESS_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_DIC_AUDIT_TABLES"
  (
    "SYS_ID"         VARCHAR2(32 BYTE) DEFAULT SYS_GUID(),
    "F_NAME"         VARCHAR2(50 BYTE),
    "F_DISPLAY_NAME" VARCHAR2(50 BYTE),
    "F_TYPE"         VARCHAR2(1 BYTE) DEFAULT NULL NOT NULL ENABLE,
    CONSTRAINT "PK_DIC_AUDIT_TABLES" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_DIC_MAIN"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_DOMAIN"     VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_CODE"       VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_MEAN"       VARCHAR2(255 BYTE) NOT NULL ENABLE,
    "F_REF_DOMAIN" VARCHAR2(20 BYTE),
    "F_ORDER"      VARCHAR2(20 BYTE),
    "F_ALTER_REF"  VARCHAR2(20 BYTE),
    CONSTRAINT "CK_DICTIONARIES_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_DICTIONARIES_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 393216 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "UN_DIC_MAIN" UNIQUE ("F_DOMAIN", "F_CODE") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 262144 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_DICTIONARIES_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE NOVALIDATE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 917504 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE UNIQUE INDEX "EKC15"."PK_DICTIONARIES_ID" ON "EKC15"."T_DIC_MAIN"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 393216 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
CREATE UNIQUE INDEX "EKC15"."UN_DIC_MAIN" ON "EKC15"."T_DIC_MAIN"
  (
    "F_DOMAIN", "F_CODE"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 262144 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_DIC_MAIN_MEAN" ON "EKC15"."T_DIC_MAIN"
    (
      "F_MEAN"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 393216 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_DIC_MAIN_DOMAIN" ON "EKC15"."T_DIC_MAIN"
    (
      "F_DOMAIN"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 262144 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_DIC_MAIN_FCODE" ON "EKC15"."T_DIC_MAIN"
    (
      "F_CODE"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 196608 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_DIC_MAIN_PARENT" ON "EKC15"."T_DIC_MAIN"
    (
      "F_REF_DOMAIN"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_T_DIC_MAIN_UPDATE" BEFORE
  UPDATE ON T_DIC_MAIN REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                          VARCHAR2(512);
  fld_val_new                                                                          VARCHAR2(512);
  table_code                                                                           VARCHAR2(40);
  BEGIN
    table_code := 'T_DIC_MAIN';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_DOMAIN
    IF( (:new.F_DOMAIN <> :old.F_DOMAIN) OR (:new.F_DOMAIN IS NULL AND :old.F_DOMAIN IS NOT NULL) OR (:new.F_DOMAIN IS NOT NULL AND :old.F_DOMAIN IS NULL) ) THEN
      fld_name         := 'T_DIC_MAIN.F_DOMAIN';
      fld_val_old      := TRUNCATE_STRING(:old.F_DOMAIN, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_DOMAIN, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_CODE
    IF( (:new.F_CODE <> :old.F_CODE) OR (:new.F_CODE IS NULL AND :old.F_CODE IS NOT NULL) OR (:new.F_CODE IS NOT NULL AND :old.F_CODE IS NULL) ) THEN
      fld_name       := 'T_DIC_MAIN.F_CODE';
      fld_val_old    := TRUNCATE_STRING(:old.F_CODE, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_CODE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_MEAN
    IF( (:new.F_MEAN <> :old.F_MEAN) OR (:new.F_MEAN IS NULL AND :old.F_MEAN IS NOT NULL) OR (:new.F_MEAN IS NOT NULL AND :old.F_MEAN IS NULL) ) THEN
      fld_name       := 'T_DIC_MAIN.F_MEAN';
      fld_val_old    := TRUNCATE_STRING(:old.F_MEAN, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_MEAN, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REF_DOMAIN
    IF( (:new.F_REF_DOMAIN <> :old.F_REF_DOMAIN) OR (:new.F_REF_DOMAIN IS NULL AND :old.F_REF_DOMAIN IS NOT NULL) OR (:new.F_REF_DOMAIN IS NOT NULL AND :old.F_REF_DOMAIN IS NULL) ) THEN
      fld_name             := 'T_DIC_MAIN.F_REF_DOMAIN';
      fld_val_old          := TRUNCATE_STRING(:old.F_REF_DOMAIN, 510);
      fld_val_new          := TRUNCATE_STRING(:new.F_REF_DOMAIN, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_ORDER
    IF( (:new.F_ORDER <> :old.F_ORDER) OR (:new.F_ORDER IS NULL AND :old.F_ORDER IS NOT NULL) OR (:new.F_ORDER IS NOT NULL AND :old.F_ORDER IS NULL) ) THEN
      fld_name        := 'T_DIC_MAIN.F_ORDER';
      fld_val_old     := TRUNCATE_STRING(:old.F_ORDER, 510);
      fld_val_new     := TRUNCATE_STRING(:new.F_ORDER, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_ALTER_REF
    IF( (:new.F_ALTER_REF <> :old.F_ALTER_REF) OR (:new.F_ALTER_REF IS NULL AND :old.F_ALTER_REF IS NOT NULL) OR (:new.F_ALTER_REF IS NOT NULL AND :old.F_ALTER_REF IS NULL) ) THEN
      fld_name            := 'T_DIC_MAIN.F_ALTER_REF';
      fld_val_old         := TRUNCATE_STRING(:old.F_ALTER_REF, 510);
      fld_val_new         := TRUNCATE_STRING(:new.F_ALTER_REF, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_T_DIC_MAIN_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_ADDITIONAL_FIELDS"
  (
    "SYS_ID"   VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "F_TABLE"  VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_RECORD" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_NAME"   VARCHAR2(32 BYTE),
    "F_VALUE"  VARCHAR2(128 BYTE),
    CONSTRAINT "PK_SYS_ADDITIONAL_FIELDS" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_ADDITIONAL_FIELDS_DELETE" BEFORE
  DELETE ON T_SYS_ADDITIONAL_FIELDS REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                       VARCHAR2(512);
  fld_val_new                                                                                       VARCHAR2(512);
  table_code                                                                                        VARCHAR2(40);
  BEGIN
    table_code  := :old.F_TABLE;
    fld_name    := :old.F_NAME;
    fld_val_old := TRUNCATE_STRING(:old.F_VALUE, 510);
    fld_val_new := '';
    P_AUDIT_POPULATE(NULL, table_code, :old.F_RECORD, fld_name, fld_val_old, fld_val_new);
  END;
  /
  ALTER TRIGGER "EKC15"."TR_ADDITIONAL_FIELDS_DELETE" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_ADDITIONAL_FIELDS_UPDATE" BEFORE
  UPDATE ON T_SYS_ADDITIONAL_FIELDS REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                       VARCHAR2(512);
  fld_val_new                                                                                       VARCHAR2(512);
  table_code                                                                                        VARCHAR2(40);
  BEGIN
    -- F_VALUE
    IF( (:new.F_VALUE <> :old.F_VALUE) OR (:new.F_VALUE IS NULL AND :old.F_VALUE IS NOT NULL) OR (:new.F_VALUE IS NOT NULL AND :old.F_VALUE IS NULL) ) THEN
      table_code      := :old.F_TABLE;
      fld_name        := :old.F_NAME;
      fld_val_old     := TRUNCATE_STRING(:old.F_VALUE, 510);
      fld_val_new     := TRUNCATE_STRING(:new.F_VALUE, 510);
      P_AUDIT_POPULATE(NULL, table_code, :old.F_RECORD, fld_name, fld_val_old, fld_val_new);
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_ADDITIONAL_FIELDS_UPDATE" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_ADDITIONAL_FIELDS_INSERT" BEFORE
  INSERT ON T_SYS_ADDITIONAL_FIELDS REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2
    (
      80
    );
  fld_val_old VARCHAR2
  (
    512
  )
  ;
  fld_val_new VARCHAR2
  (
    512
  )
  ;
  table_code VARCHAR2
  (
    40
  )
  ;
  BEGIN
    table_code  := :new.F_TABLE;
    fld_name    := :new.F_NAME;
    fld_val_old := '';
    fld_val_new := TRUNCATE_STRING
    (
      :new.F_VALUE, 510
    )
    ;
    P_AUDIT_POPULATE
    (
      NULL, table_code, :new.F_RECORD, fld_name, fld_val_old, fld_val_new
    )
    ;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_ADDITIONAL_FIELDS_INSERT" ENABLE;



CREATE TABLE "EKC15"."T_SYS_ADIS_ORM"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_DEPART"    VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_NUMBER"    NUMBER(9,0),
    "F_DATE" DATE,
    "F_REF_DACT_FOLDER" VARCHAR2(32 BYTE),
    "F_REF_INFO_CARD"   VARCHAR2(32 BYTE),
    CONSTRAINT "PK_ADIS_ORM_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "CK_ADIS_ORM_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "FK_ADIS_ORM_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_ADIS_ORM_FOLDER" FOREIGN KEY ("F_REF_DACT_FOLDER") REFERENCES "EKC15"."T_SYS_DACT_FOLDER" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_ADIS_ORM_IK" FOREIGN KEY ("F_REF_INFO_CARD") REFERENCES "EKC15"."T_SYS_INFO_CARD" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_ADIS_ORM_UPDATE" BEFORE
  UPDATE ON T_SYS_ADIS_ORM REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                              VARCHAR2(512);
  fld_val_new                                                                              VARCHAR2(512);
  table_code                                                                               VARCHAR2(40);
  BEGIN
    table_code := 'T_SYS_ADIS_ORM';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_DEPART
    IF( (:new.F_DEPART <> :old.F_DEPART) OR (:new.F_DEPART IS NULL AND :old.F_DEPART IS NOT NULL) OR (:new.F_DEPART IS NOT NULL AND :old.F_DEPART IS NULL) ) THEN
      fld_name         := 'T_SYS_ADIS_ORM.F_DEPART';
      fld_val_old      := GET_DICTIONARY_VALUE('Regions-EKC', :old.F_DEPART);
      fld_val_new      := GET_DICTIONARY_VALUE('Regions-EKC', :new.F_DEPART);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_NUMBER
    IF( (:new.F_NUMBER <> :old.F_NUMBER) OR (:new.F_NUMBER IS NULL AND :old.F_NUMBER IS NOT NULL) OR (:new.F_NUMBER IS NOT NULL AND :old.F_NUMBER IS NULL) ) THEN
      fld_name         := 'T_SYS_ADIS_ORM.F_NUMBER';
      fld_val_old      := TRUNCATE_STRING(:old.F_NUMBER, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_NUMBER, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_DATE
    IF( (:new.F_DATE <> :old.F_DATE) OR (:new.F_DATE IS NULL AND :old.F_DATE IS NOT NULL) OR (:new.F_DATE IS NOT NULL AND :old.F_DATE IS NULL) ) THEN
      fld_name       := 'T_SYS_ADIS_ORM.F_DATE';
      fld_val_old    := TO_CHAR(:old.F_DATE, 'DD.MM.YYYY');
      fld_val_new    := TO_CHAR(:new.F_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REF_DACT_FOLDER
    IF( (:new.F_REF_DACT_FOLDER <> :old.F_REF_DACT_FOLDER) OR (:new.F_REF_DACT_FOLDER IS NULL AND :old.F_REF_DACT_FOLDER IS NOT NULL) OR (:new.F_REF_DACT_FOLDER IS NOT NULL AND :old.F_REF_DACT_FOLDER IS NULL) ) THEN
      fld_name                  := 'T_SYS_ADIS_ORM.F_REF_DACT_FOLDER';
      fld_val_old               := TRUNCATE_STRING(:old.F_REF_DACT_FOLDER, 510);
      fld_val_new               := TRUNCATE_STRING(:new.F_REF_DACT_FOLDER, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REF_INFO_CARD
    IF( (:new.F_REF_INFO_CARD <> :old.F_REF_INFO_CARD) OR (:new.F_REF_INFO_CARD IS NULL AND :old.F_REF_INFO_CARD IS NOT NULL) OR (:new.F_REF_INFO_CARD IS NOT NULL AND :old.F_REF_INFO_CARD IS NULL) ) THEN
      fld_name                := 'T_SYS_ADIS_ORM.F_REF_INFO_CARD';
      fld_val_old             := TRUNCATE_STRING(:old.F_REF_INFO_CARD, 510);
      fld_val_new             := TRUNCATE_STRING(:new.F_REF_INFO_CARD, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_ADIS_ORM_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_ANSWERS"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_OUT_NUMBER" VARCHAR2(10 BYTE),
    "F_OUT_DATE" DATE,
    "F_ANSWER_NUM" VARCHAR2(10 BYTE),
    "F_ANSWER_DATE" DATE,
    "F_FORMAL_ANSW" VARCHAR2(20 BYTE),
    "F_FROM"        VARCHAR2(64 BYTE),
    "F_COMMENT"     VARCHAR2(256 BYTE),
    CONSTRAINT "PK_ANSWERS_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "CK_ANSWERS_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "FK_ANSWERS_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_AUDIT"
  (
    "SYS_ID"   VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "F_USERID" VARCHAR2(32 BYTE),
    "F_MOD_STAMP" TIMESTAMP (6) DEFAULT SYSDATE NOT NULL ENABLE,
    "F_TABLE_CODE"    VARCHAR2(40 BYTE) DEFAULT 0 NOT NULL ENABLE,
    "F_RECORD_SYS_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_FLD_NAME"      VARCHAR2(80 BYTE) NOT NULL ENABLE,
    "F_VALUE_OLD"     VARCHAR2(512 BYTE),
    "F_VALUE_NEW"     VARCHAR2(512 BYTE),
    CONSTRAINT "PK_AUDIT_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE UNIQUE INDEX "EKC15"."PK_AUDIT_ID" ON "EKC15"."T_SYS_AUDIT"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
  CREATE INDEX "EKC15"."IDX_RECORD_SYS_ID" ON "EKC15"."T_SYS_AUDIT"
    (
      "F_RECORD_SYS_ID"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_AUDIT_LOGINS"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE),
    "F_LOGIN_DATE" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "F_LOGOUT_DATE" DATE,
    "F_SESSION_ID" VARCHAR2(255 BYTE) NOT NULL ENABLE,
    "F_IP"         VARCHAR2(15 BYTE) NOT NULL ENABLE,
    "F_USER_NAME"  VARCHAR2(255 BYTE),
    CONSTRAINT "PK_SYS_AUDIT_LOGINS" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_AUDIT_LOGINS_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_SYS_AUDIT_LOGINS_INSERT" BEFORE
  INSERT ON T_SYS_AUDIT_LOGINS REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE BEGIN IF
    (
      :new.F_LOGIN_DATE IS NULL
    )
    THEN :new.F_LOGIN_DATE := SYSDATE;
END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_SYS_AUDIT_LOGINS_INSERT" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_SYS_AUDIT_LOGINS_UPDATE" BEFORE
  UPDATE ON T_SYS_AUDIT_LOGINS REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE BEGIN IF(:new.F_LOGIN_DATE IS NULL) THEN :new.F_LOGIN_DATE := :old.F_LOGIN_DATE;
  :new.F_LOGOUT_DATE                                                                                             := SYSDATE;
END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_SYS_AUDIT_LOGINS_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_CP_REVELATION"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REVEL_TYPE" VARCHAR2(1 BYTE) NOT NULL ENABLE,
    "F_REF_PHOTO"  VARCHAR2(32 BYTE),
    "F_REF_PHOTO2" VARCHAR2(32 BYTE),
    "F_DATE" DATE,
    "F_COMMENT"     VARCHAR2(256 BYTE),
    "F_REF_CP_IK"   VARCHAR2(32 BYTE),
    "F_REF_CP_IK2"  VARCHAR2(32 BYTE),
    "F_REG_AREA"    VARCHAR2(20 BYTE),
    "F_POST_NUMBER" VARCHAR2(10 BYTE),
    "F_POST_DATE" DATE,
    "F_OPERATOR" VARCHAR2(32 BYTE),
    CONSTRAINT "PK_SYS_CP_REVELATION" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_CP_REVELATION_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_CP_REVELATION_PHOTO" FOREIGN KEY ("F_REF_PHOTO") REFERENCES "EKC15"."T_SYS_PERSON_PHOTO" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_CP_REVELATION_PHOTO2" FOREIGN KEY ("F_REF_PHOTO2") REFERENCES "EKC15"."T_SYS_PERSON_PHOTO" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_CP_REVELATION_CP" FOREIGN KEY ("F_REF_CP_IK") REFERENCES "EKC15"."T_SYS_INFO_CARD_CP" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_CP_REVELATION_CP2" FOREIGN KEY ("F_REF_CP_IK2") REFERENCES "EKC15"."T_SYS_INFO_CARD_CP" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_CP_REVELATION_OPER_ID" FOREIGN KEY ("F_OPERATOR") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_CP_REVEL_STATUSES_INSERT" AFTER
  INSERT ON T_SYS_CP_REVELATION REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE BEGIN INCRIMENT_REVELATION_CP
    (
      1,
      :new.F_REVEL_TYPE,
      :new.F_REF_CP_IK,
      :new.F_REF_CP_IK2,
      :new.F_REF_PHOTO,
      :new.F_REF_PHOTO2
    );
END;
/
ALTER TRIGGER "EKC15"."TR_CP_REVEL_STATUSES_INSERT" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_CP_REVEL_STATUSES_UPDATE" AFTER
  UPDATE ON T_SYS_CP_REVELATION REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE BEGIN IF (:old.SYS_DELETED = 'N'
  AND :new.SYS_DELETED                                                                                            = 'Y') THEN INCRIMENT_REVELATION_CP(-1, :new.F_REVEL_TYPE, :new.F_REF_CP_IK, :new.F_REF_CP_IK2, :new.F_REF_PHOTO, :new.F_REF_PHOTO2);
ELSE
  IF (:old.SYS_DELETED = 'Y' AND :new.SYS_DELETED = 'N') THEN
    INCRIMENT_REVELATION_CP(1, :new.F_REVEL_TYPE, :new.F_REF_CP_IK, :new.F_REF_CP_IK2, :new.F_REF_PHOTO, :new.F_REF_PHOTO2);
  END IF;
END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_CP_REVEL_STATUSES_UPDATE" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_CP_REVELATION_UPDATE" BEFORE
  UPDATE ON T_SYS_CP_REVELATION REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                   VARCHAR2(512);
  fld_val_new                                                                                   VARCHAR2(512);
  table_code                                                                                    VARCHAR2(40);
  BEGIN
    table_code := 'T_SYS_CP_REVELATION';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_DATE
    IF( (:new.F_DATE <> :old.F_DATE) OR (:new.F_DATE IS NULL AND :old.F_DATE IS NOT NULL) OR (:new.F_DATE IS NOT NULL AND :old.F_DATE IS NULL) ) THEN
      fld_name       := 'T_SYS_CP_REVELATION.F_DATE';
      fld_val_old    := TO_CHAR(:old.F_DATE, 'DD.MM.YYYY');
      fld_val_new    := TO_CHAR(:new.F_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_COMMENT
    IF( (:new.F_COMMENT <> :old.F_COMMENT) OR (:new.F_COMMENT IS NULL AND :old.F_COMMENT IS NOT NULL) OR (:new.F_COMMENT IS NOT NULL AND :old.F_COMMENT IS NULL) ) THEN
      fld_name          := 'T_SYS_CP_REVELATION.F_COMMENT';
      fld_val_old       := TRUNCATE_STRING(:old.F_COMMENT, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_COMMENT, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_POST_NUMBER
    IF( (:new.F_POST_NUMBER <> :old.F_POST_NUMBER) OR (:new.F_POST_NUMBER IS NULL AND :old.F_POST_NUMBER IS NOT NULL) OR (:new.F_POST_NUMBER IS NOT NULL AND :old.F_POST_NUMBER IS NULL) ) THEN
      fld_name              := 'T_SYS_CP_REVELATION.F_POST_NUMBER';
      fld_val_old           := TRUNCATE_STRING(:old.F_POST_NUMBER, 510);
      fld_val_new           := TRUNCATE_STRING(:new.F_POST_NUMBER, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_POST_DATE
    IF( (:new.F_POST_DATE <> :old.F_POST_DATE) OR (:new.F_POST_DATE IS NULL AND :old.F_POST_DATE IS NOT NULL) OR (:new.F_POST_DATE IS NOT NULL AND :old.F_POST_DATE IS NULL) ) THEN
      fld_name            := 'T_SYS_CP_REVELATION.F_POST_DATE';
      fld_val_old         := TO_CHAR(:old.F_POST_DATE, 'DD.MM.YYYY');
      fld_val_new         := TO_CHAR(:new.F_POST_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_OPERATOR
    IF( (:new.F_OPERATOR <> :old.F_OPERATOR) OR (:new.F_OPERATOR IS NULL AND :old.F_OPERATOR IS NOT NULL) OR (:new.F_OPERATOR IS NOT NULL AND :old.F_OPERATOR IS NULL) ) THEN
      fld_name           := 'T_SYS_CP_REVELATION.F_OPERATOR';
      fld_val_old        := GET_OPERATOR_NAME(:old.F_OPERATOR);
      fld_val_new        := GET_OPERATOR_NAME(:new.F_OPERATOR);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_CP_REVELATION_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_DACT_FOLDER"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_RECEIVE_DATE" DATE,
    "F_REGION"     VARCHAR2(20 BYTE),
    "F_DEPART"     VARCHAR2(20 BYTE),
    "F_INIT_NAME"  VARCHAR2(50 BYTE),
    "F_INIT_PHONE" VARCHAR2(20 BYTE),
    "F_EXEC_NAME"  VARCHAR2(50 BYTE),
    "F_EXEC_PHONE" VARCHAR2(20 BYTE),
    "F_COMMENT"    VARCHAR2(255 BYTE),
    "F_OUT_NUM"    VARCHAR2(32 BYTE),
    "F_OUT_DATE" DATE,
    "F_CHECK_NUM" VARCHAR2(32 BYTE),
    "F_DBL_CNT"   VARCHAR2(20 BYTE),
    "F_OLDKEY"    VARCHAR2(20 BYTE),
    "F_IN_NUM"    VARCHAR2(32 BYTE),
    "F_IN_DATE" DATE,
    "F_MAX_NUM_CARDS" NUMBER(5,0),
    "F_START_NUMBER"  VARCHAR2(20 BYTE),
    "F_IS_CORPSE"     VARCHAR2(1 BYTE) DEFAULT 'N',
    "F_INPUT_EKC"     VARCHAR2(20 BYTE),
    CONSTRAINT "CK_DACT_FOLDER_DEL" CHECK (SYS_DELETED IN ('N','Y') ) ENABLE,
    CONSTRAINT "PK_DACT_FOLDER" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_DACT_FOLDER_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_DACT_FOLDER"."F_CHECK_NUM"
IS
  '???????????? ? UI ? ???????? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_DACT_FOLDER"."F_DBL_CNT"
IS
  '??????????? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_DACT_FOLDER"."F_OLDKEY"
IS
  '???? ? ?????? ????';
  COMMENT ON COLUMN "EKC15"."T_SYS_DACT_FOLDER"."F_MAX_NUM_CARDS"
IS
  '??????????? ???? ? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_DACT_FOLDER"."F_START_NUMBER"
IS
  '????????? ????? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_DACT_FOLDER"."F_IS_CORPSE"
IS
  '????? ???? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_DACT_FOLDER"."F_INPUT_EKC"
IS
  '????? ??? ????? ?????';
CREATE UNIQUE INDEX "EKC15"."PK_DACT_FOLDER" ON "EKC15"."T_SYS_DACT_FOLDER"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_DACT_FOLDER_OLDKEY" ON "EKC15"."T_SYS_DACT_FOLDER"
    (
      "F_OLDKEY"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_RECEIVE_DATE" ON "EKC15"."T_SYS_DACT_FOLDER"
    (
      "F_RECEIVE_DATE"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_REGION" ON "EKC15"."T_SYS_DACT_FOLDER"
    (
      "F_REGION"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_DACT_FOLDER_UPDATE" BEFORE
  UPDATE ON T_SYS_DACT_FOLDER REFERENCING OLD AS OLD NEW AS NEW FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                 VARCHAR2(512);
  fld_val_new                                                                                 VARCHAR2(512);
  table_code                                                                                  VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_DACT_FOLDER';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RECEIVE_DATE
  IF( (:new.F_RECEIVE_DATE <> :old.F_RECEIVE_DATE) OR (:new.F_RECEIVE_DATE IS NULL AND :old.F_RECEIVE_DATE IS NOT NULL) OR (:new.F_RECEIVE_DATE IS NOT NULL AND :old.F_RECEIVE_DATE IS NULL) ) THEN
    fld_name               := 'T_SYS_DACT_FOLDER.F_RECEIVE_DATE';
    fld_val_old            := TRUNCATE_STRING(:old.F_RECEIVE_DATE, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_RECEIVE_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REGION
  IF( (:new.F_REGION <> :old.F_REGION) OR (:new.F_REGION IS NULL AND :old.F_REGION IS NOT NULL) OR (:new.F_REGION IS NOT NULL AND :old.F_REGION IS NULL) ) THEN
    fld_name         := 'T_SYS_DACT_FOLDER.F_REGION';
    fld_val_old      := TRUNCATE_STRING(:old.F_REGION, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_REGION, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DEPART
  IF( (:new.F_DEPART <> :old.F_DEPART) OR (:new.F_DEPART IS NULL AND :old.F_DEPART IS NOT NULL) OR (:new.F_DEPART IS NOT NULL AND :old.F_DEPART IS NULL) ) THEN
    fld_name         := 'T_SYS_DACT_FOLDER.F_DEPART';
    fld_val_old      := TRUNCATE_STRING(:old.F_DEPART, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_DEPART, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_INIT_NAME
  IF( (:new.F_INIT_NAME <> :old.F_INIT_NAME) OR (:new.F_INIT_NAME IS NULL AND :old.F_INIT_NAME IS NOT NULL) OR (:new.F_INIT_NAME IS NOT NULL AND :old.F_INIT_NAME IS NULL) ) THEN
    fld_name            := 'T_SYS_DACT_FOLDER.F_INIT_NAME';
    fld_val_old         := TRUNCATE_STRING(:old.F_INIT_NAME, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_INIT_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_INIT_PHONE
  IF( (:new.F_INIT_PHONE <> :old.F_INIT_PHONE) OR (:new.F_INIT_PHONE IS NULL AND :old.F_INIT_PHONE IS NOT NULL) OR (:new.F_INIT_PHONE IS NOT NULL AND :old.F_INIT_PHONE IS NULL) ) THEN
    fld_name             := 'T_SYS_DACT_FOLDER.F_INIT_PHONE';
    fld_val_old          := TRUNCATE_STRING(:old.F_INIT_PHONE, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_INIT_PHONE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EXEC_NAME
  IF( (:new.F_EXEC_NAME <> :old.F_EXEC_NAME) OR (:new.F_EXEC_NAME IS NULL AND :old.F_EXEC_NAME IS NOT NULL) OR (:new.F_EXEC_NAME IS NOT NULL AND :old.F_EXEC_NAME IS NULL) ) THEN
    fld_name            := 'T_SYS_DACT_FOLDER.F_EXEC_NAME';
    fld_val_old         := TRUNCATE_STRING(:old.F_EXEC_NAME, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_EXEC_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EXEC_PHONE
  IF( (:new.F_EXEC_PHONE <> :old.F_EXEC_PHONE) OR (:new.F_EXEC_PHONE IS NULL AND :old.F_EXEC_PHONE IS NOT NULL) OR (:new.F_EXEC_PHONE IS NOT NULL AND :old.F_EXEC_PHONE IS NULL) ) THEN
    fld_name             := 'T_SYS_DACT_FOLDER.F_EXEC_PHONE';
    fld_val_old          := TRUNCATE_STRING(:old.F_EXEC_PHONE, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_EXEC_PHONE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COMMENT
  IF( (:new.F_COMMENT <> :old.F_COMMENT) OR (:new.F_COMMENT IS NULL AND :old.F_COMMENT IS NOT NULL) OR (:new.F_COMMENT IS NOT NULL AND :old.F_COMMENT IS NULL) ) THEN
    fld_name          := 'T_SYS_DACT_FOLDER.F_COMMENT';
    fld_val_old       := TRUNCATE_STRING(:old.F_COMMENT, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_COMMENT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OUT_NUM
  IF( (:new.F_OUT_NUM <> :old.F_OUT_NUM) OR (:new.F_OUT_NUM IS NULL AND :old.F_OUT_NUM IS NOT NULL) OR (:new.F_OUT_NUM IS NOT NULL AND :old.F_OUT_NUM IS NULL) ) THEN
    fld_name          := 'T_SYS_DACT_FOLDER.F_OUT_NUM';
    fld_val_old       := TRUNCATE_STRING(:old.F_OUT_NUM, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_OUT_NUM, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OUT_DATE
  IF( (:new.F_OUT_DATE <> :old.F_OUT_DATE) OR (:new.F_OUT_DATE IS NULL AND :old.F_OUT_DATE IS NOT NULL) OR (:new.F_OUT_DATE IS NOT NULL AND :old.F_OUT_DATE IS NULL) ) THEN
    fld_name           := 'T_SYS_DACT_FOLDER.F_OUT_DATE';
    fld_val_old        := TRUNCATE_STRING(:old.F_OUT_DATE, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_OUT_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_IN_NUM
  IF( (:new.F_IN_NUM <> :old.F_IN_NUM) OR (:new.F_IN_NUM IS NULL AND :old.F_IN_NUM IS NOT NULL) OR (:new.F_IN_NUM IS NOT NULL AND :old.F_IN_NUM IS NULL) ) THEN
    fld_name         := 'T_SYS_DACT_FOLDER.F_IN_NUM';
    fld_val_old      := TRUNCATE_STRING(:old.F_IN_NUM, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_IN_NUM, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_IN_DATE
  IF( (:new.F_IN_DATE <> :old.F_IN_DATE) OR (:new.F_IN_DATE IS NULL AND :old.F_IN_DATE IS NOT NULL) OR (:new.F_IN_DATE IS NOT NULL AND :old.F_IN_DATE IS NULL) ) THEN
    fld_name          := 'T_SYS_DACT_FOLDER.F_IN_DATE';
    fld_val_old       := TRUNCATE_STRING(:old.F_IN_DATE, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_IN_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_CHECK_NUM
  IF( (:new.F_CHECK_NUM <> :old.F_CHECK_NUM) OR (:new.F_CHECK_NUM IS NULL AND :old.F_CHECK_NUM IS NOT NULL) OR (:new.F_CHECK_NUM IS NOT NULL AND :old.F_CHECK_NUM IS NULL) ) THEN
    fld_name            := 'T_SYS_DACT_FOLDER.F_CHECK_NUM';
    fld_val_old         := TRUNCATE_STRING(:old.F_CHECK_NUM, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_CHECK_NUM, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DBL_CNT
  IF( (:new.F_DBL_CNT <> :old.F_DBL_CNT) OR (:new.F_DBL_CNT IS NULL AND :old.F_DBL_CNT IS NOT NULL) OR (:new.F_DBL_CNT IS NOT NULL AND :old.F_DBL_CNT IS NULL) ) THEN
    fld_name          := 'T_SYS_DACT_FOLDER.F_DBL_CNT';
    fld_val_old       := TRUNCATE_STRING(:old.F_DBL_CNT, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_DBL_CNT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OLDKEY
  IF( (:new.F_OLDKEY <> :old.F_OLDKEY) OR (:new.F_OLDKEY IS NULL AND :old.F_OLDKEY IS NOT NULL) OR (:new.F_OLDKEY IS NOT NULL AND :old.F_OLDKEY IS NULL) ) THEN
    fld_name         := 'T_SYS_DACT_FOLDER.F_OLDKEY';
    fld_val_old      := TRUNCATE_STRING(:old.F_OLDKEY, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_OLDKEY, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_DACT_FOLDER_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_EMVI_DACT_LOG"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"   VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_EXPERTZ" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_FIO"         VARCHAR2(100 BYTE),
    "F_DATE" DATE,
    "F_RESUME1"  NUMBER(1,0),
    "F_RESUME2"  NUMBER(1,0),
    "F_RESUME3"  NUMBER(1,0),
    "F_REF_USER" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    CONSTRAINT "PK_EMVI_DACT_LOG_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "CK_EMVI_DACT_LOG_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "FK_EMVI_DACT_LOG_USERID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EMVI_DACT_LOG_EXPERTZ" FOREIGN KEY ("F_REF_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EMVI_DACT_LOG_OPERATOR" FOREIGN KEY ("F_REF_USER") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_EVENTS"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_TYPE"      VARCHAR2(32 BYTE) DEFAULT 'NEW_UGD' NOT NULL ENABLE,
    "F_INFO_CARD" VARCHAR2(32 BYTE),
    "F_EKC_SKIP"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_EKP_SKIP"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    CONSTRAINT "CK_EVENTS_DELETETED" CHECK ("SYS_DELETED" IN ('Y','N')) ENABLE,
    CONSTRAINT "CK_EKC_SKIP" CHECK ("F_EKC_SKIP"          IN ('Y','N')) ENABLE,
    CONSTRAINT "CK_EKP_SKIP" CHECK ("F_EKP_SKIP"          IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_EVENTS_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_EVENTS_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EVENTS_INFO_CARD" FOREIGN KEY ("F_INFO_CARD") REFERENCES "EKC15"."T_SYS_INFO_CARD" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_EVIDENCE"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_TITLE"     VARCHAR2(50 BYTE) NOT NULL ENABLE,
    "F_COMMENT"   VARCHAR2(256 BYTE),
    "F_NUM"       NUMBER NOT NULL ENABLE,
    "F_FABULA"    VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_IMPRSMT_DATE" DATE,
    "F_IMPRSMT_OMP"  VARCHAR2(32 BYTE),
    "F_IMPRSMT_WHOM" VARCHAR2(200 BYTE),
    "F_REF_CD"       VARCHAR2(32 BYTE),
    "F_REF_ORM"      VARCHAR2(32 BYTE),
    "F_REF_FIO"      VARCHAR2(32 BYTE),
    "F_INPUT_TYPE"   VARCHAR2(1 BYTE) DEFAULT 'S',
    "F_CATEGORY"     VARCHAR2(20 BYTE),
    CONSTRAINT "PK_EVIDENCE" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_EVIDENCE_OMP" FOREIGN KEY ("F_IMPRSMT_OMP") REFERENCES "EKC15"."T_SYS_OMP" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EVIDENCE_CD" FOREIGN KEY ("F_REF_CD") REFERENCES "EKC15"."T_SYS_SD_ORM" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EVIDENCE_ORM" FOREIGN KEY ("F_REF_ORM") REFERENCES "EKC15"."T_SYS_SD_ORM" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EVIDENCE_FABULA" FOREIGN KEY ("F_FABULA") REFERENCES "EKC15"."T_SYS_FABULA" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_F_REF_FIO" FOREIGN KEY ("F_REF_FIO") REFERENCES "EKC15"."T_SYS_PERSON" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE UNIQUE INDEX "EKC15"."PK_EVIDENCE" ON "EKC15"."T_SYS_EVIDENCE"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IDX_BY_OMP" ON "EKC15"."T_SYS_EVIDENCE"
    (
      "F_IMPRSMT_OMP"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_EVIDENCE_UPDATE" BEFORE
  UPDATE ON T_SYS_EVIDENCE REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                              VARCHAR2(512);
  fld_val_new                                                                              VARCHAR2(512);
  table_code                                                                               VARCHAR2(40);
  BEGIN
    table_code := 'T_SYS_EVIDENCE';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_TITLE
    IF( (:new.F_TITLE <> :old.F_TITLE) OR (:new.F_TITLE IS NULL AND :old.F_TITLE IS NOT NULL) OR (:new.F_TITLE IS NOT NULL AND :old.F_TITLE IS NULL) ) THEN
      fld_name        := 'T_SYS_EVIDENCE.F_TITLE';
      fld_val_old     := TRUNCATE_STRING(:old.F_TITLE, 510);
      fld_val_new     := TRUNCATE_STRING(:new.F_TITLE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_COMMENT
    IF( (:new.F_COMMENT <> :old.F_COMMENT) OR (:new.F_COMMENT IS NULL AND :old.F_COMMENT IS NOT NULL) OR (:new.F_COMMENT IS NOT NULL AND :old.F_COMMENT IS NULL) ) THEN
      fld_name          := 'T_SYS_EVIDENCE.F_COMMENT';
      fld_val_old       := TRUNCATE_STRING(:old.F_COMMENT, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_COMMENT, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_NUM
    IF( (:new.F_NUM <> :old.F_NUM) OR (:new.F_NUM IS NULL AND :old.F_NUM IS NOT NULL) OR (:new.F_NUM IS NOT NULL AND :old.F_NUM IS NULL) ) THEN
      fld_name      := 'T_SYS_EVIDENCE.F_NUM';
      fld_val_old   := TRUNCATE_STRING(:old.F_NUM, 510);
      fld_val_new   := TRUNCATE_STRING(:new.F_NUM, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_FABULA
    IF( (:new.F_FABULA <> :old.F_FABULA) OR (:new.F_FABULA IS NULL AND :old.F_FABULA IS NOT NULL) OR (:new.F_FABULA IS NOT NULL AND :old.F_FABULA IS NULL) ) THEN
      fld_name         := 'T_SYS_EVIDENCE.F_FABULA';
      fld_val_old      := TRUNCATE_STRING(:old.F_FABULA, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_FABULA, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_IMPRSMT_DATE
    IF( (:new.F_IMPRSMT_DATE <> :old.F_IMPRSMT_DATE) OR (:new.F_IMPRSMT_DATE IS NULL AND :old.F_IMPRSMT_DATE IS NOT NULL) OR (:new.F_IMPRSMT_DATE IS NOT NULL AND :old.F_IMPRSMT_DATE IS NULL) ) THEN
      fld_name               := 'T_SYS_EVIDENCE.F_IMPRSMT_DATE';
      fld_val_old            := TRUNCATE_STRING(:old.F_IMPRSMT_DATE, 510);
      fld_val_new            := TRUNCATE_STRING(:new.F_IMPRSMT_DATE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_IMPRSMT_OMP
    IF( (:new.F_IMPRSMT_OMP <> :old.F_IMPRSMT_OMP) OR (:new.F_IMPRSMT_OMP IS NULL AND :old.F_IMPRSMT_OMP IS NOT NULL) OR (:new.F_IMPRSMT_OMP IS NOT NULL AND :old.F_IMPRSMT_OMP IS NULL) ) THEN
      fld_name              := 'T_SYS_EVIDENCE.F_IMPRSMT_OMP';
      fld_val_old           := GET_OMP_DISPLAYNAME(:old.F_IMPRSMT_OMP);
      fld_val_new           := GET_OMP_DISPLAYNAME(:new.F_IMPRSMT_OMP);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_IMPRSMT_WHOM
    IF( (:new.F_IMPRSMT_WHOM <> :old.F_IMPRSMT_WHOM) OR (:new.F_IMPRSMT_WHOM IS NULL AND :old.F_IMPRSMT_WHOM IS NOT NULL) OR (:new.F_IMPRSMT_WHOM IS NOT NULL AND :old.F_IMPRSMT_WHOM IS NULL) ) THEN
      fld_name               := 'T_SYS_EVIDENCE.F_IMPRSMT_WHOM';
      fld_val_old            := TRUNCATE_STRING(:old.F_IMPRSMT_WHOM, 510);
      fld_val_new            := TRUNCATE_STRING(:new.F_IMPRSMT_WHOM, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REF_CD
    IF( (:new.F_REF_CD <> :old.F_REF_CD) OR (:new.F_REF_CD IS NULL AND :old.F_REF_CD IS NOT NULL) OR (:new.F_REF_CD IS NOT NULL AND :old.F_REF_CD IS NULL) ) THEN
      fld_name         := 'T_SYS_EVIDENCE.F_REF_CD';
      fld_val_old      := TRUNCATE_STRING(:old.F_REF_CD, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_REF_CD, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REF_ORM
    IF( (:new.F_REF_ORM <> :old.F_REF_ORM) OR (:new.F_REF_ORM IS NULL AND :old.F_REF_ORM IS NOT NULL) OR (:new.F_REF_ORM IS NOT NULL AND :old.F_REF_ORM IS NULL) ) THEN
      fld_name          := 'T_SYS_EVIDENCE.F_REF_ORM';
      fld_val_old       := TRUNCATE_STRING(:old.F_REF_ORM, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_REF_ORM, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REF_FIO
    IF( (:new.F_REF_FIO <> :old.F_REF_FIO) OR (:new.F_REF_FIO IS NULL AND :old.F_REF_FIO IS NOT NULL) OR (:new.F_REF_FIO IS NOT NULL AND :old.F_REF_FIO IS NULL) ) THEN
      fld_name          := 'T_SYS_EVIDENCE.F_REF_FIO';
      fld_val_old       := TRUNCATE_STRING(:old.F_REF_FIO, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_REF_FIO, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_CATEGORY
    IF ( (:new.F_CATEGORY <> :old.F_CATEGORY) OR (:new.F_CATEGORY IS NULL AND :old.F_CATEGORY IS NOT NULL) OR (:new.F_CATEGORY IS NOT NULL AND :old.F_CATEGORY IS NULL) ) THEN
      fld_name            := 'T_SYS_EVIDENCE.F_CATEGORY';
      fld_val_old         := GET_DICTIONARY_VALUE('FingprntCategory', :old.F_CATEGORY);
      fld_val_new         := GET_DICTIONARY_VALUE('FingprntCategory', :new.F_CATEGORY);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_EVIDENCE_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_EVIDENCE_IN_EXPERTZ"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"    VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_EVIDENCE" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_REF_EXPERTZ"  VARCHAR2(32 BYTE) NOT NULL ENABLE,
    CONSTRAINT "PK_EVIDENCE_IN_EXPERTZ" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_EVIDENCE_IN_EXP_DELETE" CHECK (SYS_DELETED IN ('N', 'Y') ) ENABLE,
    CONSTRAINT "FK_EVIDENCE_INE_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EVID_IN_EXPERTZ_EXPERTZ" FOREIGN KEY ("F_REF_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EVID_IN_EXPERTZ_EVIDENCE" FOREIGN KEY ("F_REF_EVIDENCE") REFERENCES "EKC15"."T_SYS_EVIDENCE" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_EVIDENCE_IN_EXPERTZ"."F_REF_EVIDENCE"
IS
  '?????? ?? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EVIDENCE_IN_EXPERTZ"."F_REF_EXPERTZ"
IS
  '?????? ?? ??????????';
  CREATE INDEX "EKC15"."IE_EVIDENCE_IN_EXPERTZ" ON "EKC15"."T_SYS_EVIDENCE_IN_EXPERTZ"
    (
      "F_REF_EXPERTZ"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "DATA" ;
CREATE UNIQUE INDEX "EKC15"."PK_EVIDENCE_IN_EXPERTZ" ON "EKC15"."T_SYS_EVIDENCE_IN_EXPERTZ"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_EVIDENCE_IN_EXPERTZ_UPDATE" BEFORE
  UPDATE ON T_SYS_EVIDENCE_IN_EXPERTZ REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                         VARCHAR2(512);
  fld_val_new                                                                                         VARCHAR2(512);
  table_code                                                                                          VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_EVIDENCE_IN_EXPERTZ';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REF_EVIDENCE
  IF( (:new.F_REF_EVIDENCE <> :old.F_REF_EVIDENCE) OR (:new.F_REF_EVIDENCE IS NULL AND :old.F_REF_EVIDENCE IS NOT NULL) OR (:new.F_REF_EVIDENCE IS NOT NULL AND :old.F_REF_EVIDENCE IS NULL) ) THEN
    fld_name               := 'T_SYS_EVIDENCE_IN_EXPERTZ.F_REF_EVIDENCE';
    fld_val_old            := TRUNCATE_STRING(:old.F_REF_EVIDENCE, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_REF_EVIDENCE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REF_EXPERTZ
  IF( (:new.F_REF_EXPERTZ <> :old.F_REF_EXPERTZ) OR (:new.F_REF_EXPERTZ IS NULL AND :old.F_REF_EXPERTZ IS NOT NULL) OR (:new.F_REF_EXPERTZ IS NOT NULL AND :old.F_REF_EXPERTZ IS NULL) ) THEN
    fld_name              := 'T_SYS_EVIDENCE_IN_EXPERTZ.F_REF_EXPERTZ';
    fld_val_old           := TRUNCATE_STRING(:old.F_REF_EXPERTZ, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_REF_EXPERTZ, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_EVIDENCE_IN_EXPERTZ_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_EXP_EXTENSION"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"    VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_EXPERTZ"  VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_REF_EVIDENCE" VARCHAR2(32 BYTE),
    "F_NUMBER"       NUMBER(9,0),
    "F_RESULT_CODE"  VARCHAR2(20 BYTE),
    "F_RESULT_CODE2" VARCHAR2(20 BYTE),
    CONSTRAINT "CK_EXP_EXTENSION_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_EXP_EXTENSION_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_EXTENSION_EVIDENCE" FOREIGN KEY ("F_REF_EVIDENCE") REFERENCES "EKC15"."T_SYS_EVIDENCE" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EXTENSION_EXPERTZ" FOREIGN KEY ("F_REF_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EXTENSION_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_EXPERTZ"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REG_NUM"    VARCHAR2(40 BYTE),
    "F_EXPRT_TYPE" VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_INITIATOR"  VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_RECIPIENT"  VARCHAR2(20 BYTE),
    "F_ARRIVAL_DATE" DATE DEFAULT NULL NOT NULL ENABLE,
    "F_START_DATE" DATE,
    "F_END_DATE" DATE,
    "F_CONCLUSION_DATE" DATE,
    "F_EXPRT_GENUS"      VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_REF_FABULA"       VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_RESLT_TEXT1"      VARCHAR2(1024 BYTE),
    "F_RESLT_DIC1"       VARCHAR2(20 BYTE),
    "F_RESLT_DIC2"       VARCHAR2(20 BYTE),
    "F_REF_SPECIAL_PART" VARCHAR2(32 BYTE),
    "F_EKC_AREA"         VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_RESLT_FLAG1"      VARCHAR2(1 BYTE),
    "F_RESLT_NUMBER1"    NUMBER(9,0),
    "F_RESLT_NUMBER2"    NUMBER(9,0),
    "F_RESLT_NUMBER3"    NUMBER(9,0),
    "F_RESLT_TEXT2"      VARCHAR2(255 BYTE),
    "F_RESLT_TEXT3"      VARCHAR2(255 BYTE),
    "F_RESLT_NUMBER4"    NUMBER(9,0),
    "F_PROPERTIES"       VARCHAR2(32 BYTE),
    "F_DEST_TEXT"        VARCHAR2(200 BYTE),
    "F_INIT_TEXT"        VARCHAR2(64 BYTE),
    "F_EKC_GROUP"        VARCHAR2(20 BYTE),
    "F_COMMENT"          VARCHAR2(1024 BYTE),
    "REV_COUNT"          NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    "UNI_COUNT"          NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    CONSTRAINT "CK_EXPERTZ_DEL" CHECK (SYS_DELETED IN ('Y','N') ) ENABLE,
    CONSTRAINT "PK_EXPERTZ" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_EXPERTZ_FLAG1" CHECK (F_RESLT_FLAG1 IN ('N', 'Y') ) ENABLE,
    CONSTRAINT "FK_EXPERTZ_REF_FABULA" FOREIGN KEY ("F_REF_FABULA") REFERENCES "EKC15"."T_SYS_FABULA" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EXPERTZ_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_REG_NUM"
IS
  '??????????????? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_EXPRT_TYPE"
IS
  '??? (????????????, ??????????...)';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_INITIATOR"
IS
  '?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RECIPIENT"
IS
  '??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_ARRIVAL_DATE"
IS
  '???? ???????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_START_DATE"
IS
  '???? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_END_DATE"
IS
  '???? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_CONCLUSION_DATE"
IS
  '?????? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_EXPRT_GENUS"
IS
  '??? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_REF_FABULA"
IS
  '? ?????? ???????????? ????????? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_TEXT1"
IS
  '????????? ???? ??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_DIC1"
IS
  '?????? ?? ??????? ??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_DIC2"
IS
  '?????? ?? ??????? ??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_REF_SPECIAL_PART"
IS
  'ID ????.????? (????. ???????????????)';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_EKC_AREA"
IS
  '?????, ??????????? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_FLAG1"
IS
  '????-???? ??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_NUMBER1"
IS
  '????-????? ??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_NUMBER2"
IS
  '????-????? ??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_NUMBER3"
IS
  '????-????? ??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_TEXT2"
IS
  '????????? ???? ??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_TEXT3"
IS
  '????????? ???? ??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ"."F_RESLT_NUMBER4"
IS
  '????-????? ??? ???????';
CREATE UNIQUE INDEX "EKC15"."PK_EXPERTZ" ON "EKC15"."T_SYS_EXPERTZ"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_EXPERTZ_FABULA" ON "EKC15"."T_SYS_EXPERTZ"
    (
      "F_REF_FABULA"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_EXPERTZ_UPDATE" BEFORE
  UPDATE ON T_SYS_EXPERTZ REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                             VARCHAR2(512);
  fld_val_new                                                                             VARCHAR2(512);
  table_code                                                                              VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_EXPERTZ';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REG_NUM
  IF( (:new.F_REG_NUM <> :old.F_REG_NUM) OR (:new.F_REG_NUM IS NULL AND :old.F_REG_NUM IS NOT NULL) OR (:new.F_REG_NUM IS NOT NULL AND :old.F_REG_NUM IS NULL) ) THEN
    fld_name          := 'T_SYS_EXPERTZ.F_REG_NUM';
    fld_val_old       := TRUNCATE_STRING(:old.F_REG_NUM, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_REG_NUM, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EXPRT_TYPE
  IF( (:new.F_EXPRT_TYPE <> :old.F_EXPRT_TYPE) OR (:new.F_EXPRT_TYPE IS NULL AND :old.F_EXPRT_TYPE IS NOT NULL) OR (:new.F_EXPRT_TYPE IS NOT NULL AND :old.F_EXPRT_TYPE IS NULL) ) THEN
    fld_name             := 'T_SYS_EXPERTZ.F_EXPRT_TYPE';
    fld_val_old          := TRUNCATE_STRING(:old.F_EXPRT_TYPE, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_EXPRT_TYPE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_INITIATOR
  IF( (:new.F_INITIATOR   <> :old.F_INITIATOR) OR (:new.F_INITIATOR IS NULL AND :old.F_INITIATOR IS NOT NULL) OR (:new.F_INITIATOR IS NOT NULL AND :old.F_INITIATOR IS NULL) ) THEN
    fld_name              := 'T_SYS_EXPERTZ.F_INITIATOR';
    IF( :new.F_EXPRT_GENUS = '11' ) THEN
      fld_val_old         := GET_DICTIONARY_VALUE('InitFireExpert', :old.F_INITIATOR);
      fld_val_new         := GET_DICTIONARY_VALUE('InitFireExpert', :new.F_INITIATOR);
    ELSE
      fld_val_old := GET_DICTIONARY_VALUE('Initiators', :old.F_INITIATOR);
      fld_val_new := GET_DICTIONARY_VALUE('Initiators', :new.F_INITIATOR);
    END IF;
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RECIPIENT
  IF( (:new.F_RECIPIENT <> :old.F_RECIPIENT) OR (:new.F_RECIPIENT IS NULL AND :old.F_RECIPIENT IS NOT NULL) OR (:new.F_RECIPIENT IS NOT NULL AND :old.F_RECIPIENT IS NULL) ) THEN
    fld_name            := 'T_SYS_EXPERTZ.F_RECIPIENT';
    fld_val_old         := GET_DICTIONARY_VALUE('AdvInitiators', :old.F_RECIPIENT);
    fld_val_new         := GET_DICTIONARY_VALUE('AdvInitiators', :new.F_RECIPIENT);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_INIT_TEXT
  IF( (:new.F_INIT_TEXT <> :old.F_INIT_TEXT) OR (:new.F_INIT_TEXT IS NULL AND :old.F_INIT_TEXT IS NOT NULL) OR (:new.F_INIT_TEXT IS NOT NULL AND :old.F_INIT_TEXT IS NULL) ) THEN
    fld_name            := 'T_SYS_EXPERTZ.F_INIT_TEXT';
    fld_val_old         := TRUNCATE_STRING(:old.F_INIT_TEXT, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_INIT_TEXT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_ARRIVAL_DATE
  IF ( TO_CHAR(:new.F_ARRIVAL_DATE, 'YYYYMMDD') <> TO_CHAR(:old.F_ARRIVAL_DATE, 'YYYYMMDD') ) THEN
    fld_name                                    := 'T_SYS_EXPERTZ.F_ARRIVAL_DATE';
    fld_val_old                                 := TO_CHAR(:old.F_ARRIVAL_DATE, 'DD.MM.YYYY');
    fld_val_new                                 := TO_CHAR(:new.F_ARRIVAL_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_ARRIVAL_TIME
  IF ( TO_CHAR(:new.F_ARRIVAL_DATE, 'HH24:MI') <> TO_CHAR(:old.F_ARRIVAL_DATE, 'HH24:MI') ) THEN
    fld_name                                   := 'T_SYS_EXPERTZ.F_ARRIVAL_TIME';
    fld_val_old                                := TO_CHAR(:old.F_ARRIVAL_DATE, 'HH24:MI');
    fld_val_new                                := TO_CHAR(:new.F_ARRIVAL_DATE, 'HH24:MI');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_START_DATE
  IF ( TO_CHAR(:new.F_START_DATE, 'YYYYMMDD') <> TO_CHAR(:old.F_START_DATE, 'YYYYMMDD') ) THEN
    fld_name                                  := 'T_SYS_EXPERTZ.F_START_DATE';
    fld_val_old                               := TO_CHAR(:old.F_START_DATE, 'DD.MM.YYYY');
    fld_val_new                               := TO_CHAR(:new.F_START_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_START_TIME
  IF ( TO_CHAR(:new.F_START_DATE, 'HH24:MI') <> TO_CHAR(:old.F_START_DATE, 'HH24:MI') ) THEN
    fld_name                                 := 'T_SYS_EXPERTZ.F_START_TIME';
    fld_val_old                              := TO_CHAR(:old.F_START_DATE, 'HH24:MI');
    fld_val_new                              := TO_CHAR(:new.F_START_DATE, 'HH24:MI');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_END_DATE
  IF( TO_CHAR(:new.F_END_DATE, 'YYYYMMDD') <> TO_CHAR(:old.F_END_DATE, 'YYYYMMDD') ) THEN
    fld_name                               := 'T_SYS_EXPERTZ.F_END_DATE';
    fld_val_old                            := TO_CHAR(:old.F_END_DATE, 'DD.MM.YYYY');
    fld_val_new                            := TO_CHAR(:new.F_END_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_END_TIME
  IF( TO_CHAR(:new.F_END_DATE, 'HH24:MI') <> TO_CHAR(:old.F_END_DATE, 'HH24:MI') ) THEN
    fld_name                              := 'T_SYS_EXPERTZ.F_END_TIME';
    fld_val_old                           := TO_CHAR(:old.F_END_DATE, 'HH24:MI');
    fld_val_new                           := TO_CHAR(:new.F_END_DATE, 'HH24:MI');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_CONCLUSION_DATE
  IF( TO_CHAR(:new.F_CONCLUSION_DATE, 'YYYYMMDD') <> TO_CHAR(:old.F_CONCLUSION_DATE, 'YYYYMMDD') ) THEN
    fld_name                                      := 'T_SYS_EXPERTZ.F_CONCLUSION_DATE';
    fld_val_old                                   := TO_CHAR(:old.F_CONCLUSION_DATE, 'DD.MM.YYYY');
    fld_val_new                                   := TO_CHAR(:new.F_CONCLUSION_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_CONCLUSION_TIME
  IF( TO_CHAR(:new.F_CONCLUSION_DATE, 'HH24:MI') <> TO_CHAR(:old.F_CONCLUSION_DATE, 'HH24:MI') ) THEN
    fld_name                                     := 'T_SYS_EXPERTZ.F_CONCLUSION_TIME';
    fld_val_old                                  := TO_CHAR(:old.F_CONCLUSION_DATE, 'HH24:MI');
    fld_val_new                                  := TO_CHAR(:new.F_CONCLUSION_DATE, 'HH24:MI');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EXPRT_GENUS
  IF( (:new.F_EXPRT_GENUS <> :old.F_EXPRT_GENUS) OR (:new.F_EXPRT_GENUS IS NULL AND :old.F_EXPRT_GENUS IS NOT NULL) OR (:new.F_EXPRT_GENUS IS NOT NULL AND :old.F_EXPRT_GENUS IS NULL) ) THEN
    fld_name              := 'T_SYS_EXPERTZ.F_EXPRT_GENUS';
    fld_val_old           := TRUNCATE_STRING(:old.F_EXPRT_GENUS, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_EXPRT_GENUS, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REF_FABULA
  IF( (:new.F_REF_FABULA <> :old.F_REF_FABULA) OR (:new.F_REF_FABULA IS NULL AND :old.F_REF_FABULA IS NOT NULL) OR (:new.F_REF_FABULA IS NOT NULL AND :old.F_REF_FABULA IS NULL) ) THEN
    fld_name             := 'T_SYS_EXPERTZ.F_REF_FABULA';
    fld_val_old          := TRUNCATE_STRING(:old.F_REF_FABULA, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_REF_FABULA, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_TEXT1
  IF( (:new.F_RESLT_TEXT1 <> :old.F_RESLT_TEXT1) OR (:new.F_RESLT_TEXT1 IS NULL AND :old.F_RESLT_TEXT1 IS NOT NULL) OR (:new.F_RESLT_TEXT1 IS NOT NULL AND :old.F_RESLT_TEXT1 IS NULL) ) THEN
    fld_name              := 'T_SYS_EXPERTZ.F_RESLT_TEXT1';
    fld_val_old           := TRUNCATE_STRING(:old.F_RESLT_TEXT1, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_RESLT_TEXT1, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_DIC1
  IF( (:new.F_RESLT_DIC1 <> :old.F_RESLT_DIC1) OR (:new.F_RESLT_DIC1 IS NULL AND :old.F_RESLT_DIC1 IS NOT NULL) OR (:new.F_RESLT_DIC1 IS NOT NULL AND :old.F_RESLT_DIC1 IS NULL) ) THEN
    fld_name             := 'T_SYS_EXPERTZ.F_RESLT_DIC1';
    fld_val_old          := TRUNCATE_STRING(:old.F_RESLT_DIC1, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_RESLT_DIC1, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_DIC2
  IF( (:new.F_RESLT_DIC2 <> :old.F_RESLT_DIC2) OR (:new.F_RESLT_DIC2 IS NULL AND :old.F_RESLT_DIC2 IS NOT NULL) OR (:new.F_RESLT_DIC2 IS NOT NULL AND :old.F_RESLT_DIC2 IS NULL) ) THEN
    fld_name             := 'T_SYS_EXPERTZ.F_RESLT_DIC2';
    fld_val_old          := TRUNCATE_STRING(:old.F_RESLT_DIC2, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_RESLT_DIC2, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REF_SPECIAL_PART
  IF( (:new.F_REF_SPECIAL_PART <> :old.F_REF_SPECIAL_PART) OR (:new.F_REF_SPECIAL_PART IS NULL AND :old.F_REF_SPECIAL_PART IS NOT NULL) OR (:new.F_REF_SPECIAL_PART IS NOT NULL AND :old.F_REF_SPECIAL_PART IS NULL) ) THEN
    fld_name                   := 'T_SYS_EXPERTZ.F_REF_SPECIAL_PART';
    fld_val_old                := TRUNCATE_STRING(:old.F_REF_SPECIAL_PART, 510);
    fld_val_new                := TRUNCATE_STRING(:new.F_REF_SPECIAL_PART, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKC_AREA
  IF( (:new.F_EKC_AREA <> :old.F_EKC_AREA) OR (:new.F_EKC_AREA IS NULL AND :old.F_EKC_AREA IS NOT NULL) OR (:new.F_EKC_AREA IS NOT NULL AND :old.F_EKC_AREA IS NULL) ) THEN
    fld_name           := 'T_SYS_EXPERTZ.F_EKC_AREA';
    fld_val_old        := TRUNCATE_STRING(:old.F_EKC_AREA, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_EKC_AREA, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_FLAG1
  IF( (:new.F_RESLT_FLAG1 <> :old.F_RESLT_FLAG1) OR (:new.F_RESLT_FLAG1 IS NULL AND :old.F_RESLT_FLAG1 IS NOT NULL) OR (:new.F_RESLT_FLAG1 IS NOT NULL AND :old.F_RESLT_FLAG1 IS NULL) ) THEN
    fld_name              := 'T_SYS_EXPERTZ.F_RESLT_FLAG1';
    fld_val_old           := TRUNCATE_STRING(:old.F_RESLT_FLAG1, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_RESLT_FLAG1, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_NUMBER1
  IF( (:new.F_RESLT_NUMBER1 <> :old.F_RESLT_NUMBER1) OR (:new.F_RESLT_NUMBER1 IS NULL AND :old.F_RESLT_NUMBER1 IS NOT NULL) OR (:new.F_RESLT_NUMBER1 IS NOT NULL AND :old.F_RESLT_NUMBER1 IS NULL) ) THEN
    fld_name                := 'T_SYS_EXPERTZ.F_RESLT_NUMBER1';
    fld_val_old             := TRUNCATE_STRING(:old.F_RESLT_NUMBER1, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_RESLT_NUMBER1, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_NUMBER2
  IF( (:new.F_RESLT_NUMBER2 <> :old.F_RESLT_NUMBER2) OR (:new.F_RESLT_NUMBER2 IS NULL AND :old.F_RESLT_NUMBER2 IS NOT NULL) OR (:new.F_RESLT_NUMBER2 IS NOT NULL AND :old.F_RESLT_NUMBER2 IS NULL) ) THEN
    fld_name                := 'T_SYS_EXPERTZ.F_RESLT_NUMBER2';
    fld_val_old             := TRUNCATE_STRING(:old.F_RESLT_NUMBER2, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_RESLT_NUMBER2, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_NUMBER3
  IF( (:new.F_RESLT_NUMBER3 <> :old.F_RESLT_NUMBER3) OR (:new.F_RESLT_NUMBER3 IS NULL AND :old.F_RESLT_NUMBER3 IS NOT NULL) OR (:new.F_RESLT_NUMBER3 IS NOT NULL AND :old.F_RESLT_NUMBER3 IS NULL) ) THEN
    fld_name                := 'T_SYS_EXPERTZ.F_RESLT_NUMBER3';
    fld_val_old             := TRUNCATE_STRING(:old.F_RESLT_NUMBER3, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_RESLT_NUMBER3, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_TEXT2
  IF( (:new.F_RESLT_TEXT2 <> :old.F_RESLT_TEXT2) OR (:new.F_RESLT_TEXT2 IS NULL AND :old.F_RESLT_TEXT2 IS NOT NULL) OR (:new.F_RESLT_TEXT2 IS NOT NULL AND :old.F_RESLT_TEXT2 IS NULL) ) THEN
    fld_name              := 'T_SYS_EXPERTZ.F_RESLT_TEXT2';
    fld_val_old           := TRUNCATE_STRING(:old.F_RESLT_TEXT2, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_RESLT_TEXT2, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_TEXT3
  IF( (:new.F_RESLT_TEXT3 <> :old.F_RESLT_TEXT3) OR (:new.F_RESLT_TEXT3 IS NULL AND :old.F_RESLT_TEXT3 IS NOT NULL) OR (:new.F_RESLT_TEXT3 IS NOT NULL AND :old.F_RESLT_TEXT3 IS NULL) ) THEN
    fld_name              := 'T_SYS_EXPERTZ.F_RESLT_TEXT3';
    fld_val_old           := TRUNCATE_STRING(:old.F_RESLT_TEXT3, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_RESLT_TEXT3, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESLT_NUMBER4
  IF( (:new.F_RESLT_NUMBER4 <> :old.F_RESLT_NUMBER4) OR (:new.F_RESLT_NUMBER4 IS NULL AND :old.F_RESLT_NUMBER4 IS NOT NULL) OR (:new.F_RESLT_NUMBER4 IS NOT NULL AND :old.F_RESLT_NUMBER4 IS NULL) ) THEN
    fld_name                := 'T_SYS_EXPERTZ.F_RESLT_NUMBER4';
    fld_val_old             := TRUNCATE_STRING(:old.F_RESLT_NUMBER4, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_RESLT_NUMBER4, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COMMENT
  IF( (:new.F_COMMENT <> :old.F_COMMENT) OR (:new.F_COMMENT IS NULL AND :old.F_COMMENT IS NOT NULL) OR (:new.F_COMMENT IS NOT NULL AND :old.F_COMMENT IS NULL) ) THEN
    fld_name          := 'T_SYS_EXPERTZ.F_COMMENT';
    fld_val_old       := TRUNCATE_STRING(:old.F_COMMENT, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_COMMENT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DEST_TEXT
  IF( (:new.F_DEST_TEXT <> :old.F_DEST_TEXT) OR (:new.F_DEST_TEXT IS NULL AND :old.F_DEST_TEXT IS NOT NULL) OR (:new.F_DEST_TEXT IS NOT NULL AND :old.F_DEST_TEXT IS NULL) ) THEN
    fld_name            := 'T_SYS_EXPERTZ.F_DEST_TEXT';
    fld_val_old         := TRUNCATE_STRING(:old.F_DEST_TEXT, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_DEST_TEXT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_EXPERTZ_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_EXPERTZ_AUTOTECH"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"          VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_MODEL"              VARCHAR2(64 BYTE),
    "F_GOS_NUMBER"         VARCHAR2(16 BYTE),
    "F_COLOR"              VARCHAR2(32 BYTE),
    "F_DATE_BUILD"         NUMBER(4,0),
    "F_WIN_NUMBER"         VARCHAR2(32 BYTE),
    "F_MOTOR_NUMBER"       VARCHAR2(32 BYTE),
    "F_BODY_NUMBER"        VARCHAR2(32 BYTE),
    "F_SHASSY_NUMBER"      VARCHAR2(32 BYTE),
    "F_WIN_NUMBER_REAL"    VARCHAR2(32 BYTE),
    "F_MOTOR_NUMBER_REAL"  VARCHAR2(32 BYTE),
    "F_BODY_NUMBER_REAL"   VARCHAR2(32 BYTE),
    "F_SHASSY_NUMBER_REAL" VARCHAR2(32 BYTE),
    "F_RESUME_WIN"         VARCHAR2(32 BYTE),
    "F_RESUME_MOTOR"       VARCHAR2(32 BYTE),
    "F_RESUME_BODY"        VARCHAR2(32 BYTE),
    "F_RESUME_SHASSY"      VARCHAR2(32 BYTE),
    "F_REF_MAIN_EXPERTZ"   VARCHAR2(32 BYTE) NOT NULL ENABLE,
    CONSTRAINT "CK_EXPERTZ_AUTOTECH_DEL" CHECK (SYS_DELETED IN ('Y','N') ) ENABLE,
    CONSTRAINT "PK_EXPERTZ_AUTOTECH" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_EXPERTZ_AUTOTECH_USER" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EXPERTZ_AUTOTECH_EXP" FOREIGN KEY ("F_REF_MAIN_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_MODEL"
IS
  '?????? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_GOS_NUMBER"
IS
  '???.?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_COLOR"
IS
  '???? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_DATE_BUILD"
IS
  '??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_WIN_NUMBER"
IS
  'WIN ?? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_MOTOR_NUMBER"
IS
  '????? ????????? ?? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_BODY_NUMBER"
IS
  '????? ?????? ?? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_SHASSY_NUMBER"
IS
  '????? ????/????? ?? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_WIN_NUMBER_REAL"
IS
  '???????? WIN';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_MOTOR_NUMBER_REAL"
IS
  '???????? ????? ?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_BODY_NUMBER_REAL"
IS
  '???????? ????? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_SHASSY_NUMBER_REAL"
IS
  '???????? ????? ????/?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_RESUME_WIN"
IS
  '?????????? ?? WIN';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_RESUME_MOTOR"
IS
  '?????????? ?? ?????? ?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_RESUME_BODY"
IS
  '?????????? ?? ?????? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_RESUME_SHASSY"
IS
  '?????????? ?? ?????? ????/?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_AUTOTECH"."F_REF_MAIN_EXPERTZ"
IS
  '?????? ?? ?????????? (???????? ?????)';
CREATE OR REPLACE TRIGGER "EKC15"."TR_EXPERTZ_AUTOTECH_UPDATE" BEFORE
  UPDATE ON T_SYS_EXPERTZ_AUTOTECH REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                      VARCHAR2(512);
  fld_val_new                                                                                      VARCHAR2(512);
  table_code                                                                                       VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_EXPERTZ_AUTOTECH';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_MODEL
  IF( (:new.F_MODEL <> :old.F_MODEL) OR (:new.F_MODEL IS NULL AND :old.F_MODEL IS NOT NULL) OR (:new.F_MODEL IS NOT NULL AND :old.F_MODEL IS NULL) ) THEN
    fld_name        := 'T_SYS_EXPERTZ_AUTOTECH.F_MODEL';
    fld_val_old     := TRUNCATE_STRING(:old.F_MODEL, 510);
    fld_val_new     := TRUNCATE_STRING(:new.F_MODEL, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_GOS_NUMBER
  IF( (:new.F_GOS_NUMBER <> :old.F_GOS_NUMBER) OR (:new.F_GOS_NUMBER IS NULL AND :old.F_GOS_NUMBER IS NOT NULL) OR (:new.F_GOS_NUMBER IS NOT NULL AND :old.F_GOS_NUMBER IS NULL) ) THEN
    fld_name             := 'T_SYS_EXPERTZ_AUTOTECH.F_GOS_NUMBER';
    fld_val_old          := TRUNCATE_STRING(:old.F_GOS_NUMBER, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_GOS_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COLOR
  IF( (:new.F_COLOR <> :old.F_COLOR) OR (:new.F_COLOR IS NULL AND :old.F_COLOR IS NOT NULL) OR (:new.F_COLOR IS NOT NULL AND :old.F_COLOR IS NULL) ) THEN
    fld_name        := 'T_SYS_EXPERTZ_AUTOTECH.F_COLOR';
    fld_val_old     := TRUNCATE_STRING(:old.F_COLOR, 510);
    fld_val_new     := TRUNCATE_STRING(:new.F_COLOR, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DATE_BUILD
  IF( (:new.F_DATE_BUILD <> :old.F_DATE_BUILD) OR (:new.F_DATE_BUILD IS NULL AND :old.F_DATE_BUILD IS NOT NULL) OR (:new.F_DATE_BUILD IS NOT NULL AND :old.F_DATE_BUILD IS NULL) ) THEN
    fld_name             := 'T_SYS_EXPERTZ_AUTOTECH.F_DATE_BUILD';
    fld_val_old          := TRUNCATE_STRING(:old.F_DATE_BUILD, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_DATE_BUILD, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_WIN_NUMBER
  IF( (:new.F_WIN_NUMBER <> :old.F_WIN_NUMBER) OR (:new.F_WIN_NUMBER IS NULL AND :old.F_WIN_NUMBER IS NOT NULL) OR (:new.F_WIN_NUMBER IS NOT NULL AND :old.F_WIN_NUMBER IS NULL) ) THEN
    fld_name             := 'T_SYS_EXPERTZ_AUTOTECH.F_WIN_NUMBER';
    fld_val_old          := TRUNCATE_STRING(:old.F_WIN_NUMBER, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_WIN_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_MOTOR_NUMBER
  IF( (:new.F_MOTOR_NUMBER <> :old.F_MOTOR_NUMBER) OR (:new.F_MOTOR_NUMBER IS NULL AND :old.F_MOTOR_NUMBER IS NOT NULL) OR (:new.F_MOTOR_NUMBER IS NOT NULL AND :old.F_MOTOR_NUMBER IS NULL) ) THEN
    fld_name               := 'T_SYS_EXPERTZ_AUTOTECH.F_MOTOR_NUMBER';
    fld_val_old            := TRUNCATE_STRING(:old.F_MOTOR_NUMBER, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_MOTOR_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_BODY_NUMBER
  IF( (:new.F_BODY_NUMBER <> :old.F_BODY_NUMBER) OR (:new.F_BODY_NUMBER IS NULL AND :old.F_BODY_NUMBER IS NOT NULL) OR (:new.F_BODY_NUMBER IS NOT NULL AND :old.F_BODY_NUMBER IS NULL) ) THEN
    fld_name              := 'T_SYS_EXPERTZ_AUTOTECH.F_BODY_NUMBER';
    fld_val_old           := TRUNCATE_STRING(:old.F_BODY_NUMBER, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_BODY_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SHASSY_NUMBER
  IF( (:new.F_SHASSY_NUMBER <> :old.F_SHASSY_NUMBER) OR (:new.F_SHASSY_NUMBER IS NULL AND :old.F_SHASSY_NUMBER IS NOT NULL) OR (:new.F_SHASSY_NUMBER IS NOT NULL AND :old.F_SHASSY_NUMBER IS NULL) ) THEN
    fld_name                := 'T_SYS_EXPERTZ_AUTOTECH.F_SHASSY_NUMBER';
    fld_val_old             := TRUNCATE_STRING(:old.F_SHASSY_NUMBER, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_SHASSY_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_WIN_NUMBER_REAL
  IF( (:new.F_WIN_NUMBER_REAL <> :old.F_WIN_NUMBER_REAL) OR (:new.F_WIN_NUMBER_REAL IS NULL AND :old.F_WIN_NUMBER_REAL IS NOT NULL) OR (:new.F_WIN_NUMBER_REAL IS NOT NULL AND :old.F_WIN_NUMBER_REAL IS NULL) ) THEN
    fld_name                  := 'T_SYS_EXPERTZ_AUTOTECH.F_WIN_NUMBER_REAL';
    fld_val_old               := TRUNCATE_STRING(:old.F_WIN_NUMBER_REAL, 510);
    fld_val_new               := TRUNCATE_STRING(:new.F_WIN_NUMBER_REAL, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_MOTOR_NUMBER_REAL
  IF( (:new.F_MOTOR_NUMBER_REAL <> :old.F_MOTOR_NUMBER_REAL) OR (:new.F_MOTOR_NUMBER_REAL IS NULL AND :old.F_MOTOR_NUMBER_REAL IS NOT NULL) OR (:new.F_MOTOR_NUMBER_REAL IS NOT NULL AND :old.F_MOTOR_NUMBER_REAL IS NULL) ) THEN
    fld_name                    := 'T_SYS_EXPERTZ_AUTOTECH.F_MOTOR_NUMBER_REAL';
    fld_val_old                 := TRUNCATE_STRING(:old.F_MOTOR_NUMBER_REAL, 510);
    fld_val_new                 := TRUNCATE_STRING(:new.F_MOTOR_NUMBER_REAL, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_BODY_NUMBER_REAL
  IF( (:new.F_BODY_NUMBER_REAL <> :old.F_BODY_NUMBER_REAL) OR (:new.F_BODY_NUMBER_REAL IS NULL AND :old.F_BODY_NUMBER_REAL IS NOT NULL) OR (:new.F_BODY_NUMBER_REAL IS NOT NULL AND :old.F_BODY_NUMBER_REAL IS NULL) ) THEN
    fld_name                   := 'T_SYS_EXPERTZ_AUTOTECH.F_BODY_NUMBER_REAL';
    fld_val_old                := TRUNCATE_STRING(:old.F_BODY_NUMBER_REAL, 510);
    fld_val_new                := TRUNCATE_STRING(:new.F_BODY_NUMBER_REAL, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SHASSY_NUMBER_REAL
  IF( (:new.F_SHASSY_NUMBER_REAL <> :old.F_SHASSY_NUMBER_REAL) OR (:new.F_SHASSY_NUMBER_REAL IS NULL AND :old.F_SHASSY_NUMBER_REAL IS NOT NULL) OR (:new.F_SHASSY_NUMBER_REAL IS NOT NULL AND :old.F_SHASSY_NUMBER_REAL IS NULL) ) THEN
    fld_name                     := 'T_SYS_EXPERTZ_AUTOTECH.F_SHASSY_NUMBER_REAL';
    fld_val_old                  := TRUNCATE_STRING(:old.F_SHASSY_NUMBER_REAL, 510);
    fld_val_new                  := TRUNCATE_STRING(:new.F_SHASSY_NUMBER_REAL, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESUME_WIN
  IF( (:new.F_RESUME_WIN <> :old.F_RESUME_WIN) OR (:new.F_RESUME_WIN IS NULL AND :old.F_RESUME_WIN IS NOT NULL) OR (:new.F_RESUME_WIN IS NOT NULL AND :old.F_RESUME_WIN IS NULL) ) THEN
    fld_name             := 'T_SYS_EXPERTZ_AUTOTECH.F_RESUME_WIN';
    fld_val_old          := TRUNCATE_STRING(:old.F_RESUME_WIN, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_RESUME_WIN, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESUME_MOTOR
  IF( (:new.F_RESUME_MOTOR <> :old.F_RESUME_MOTOR) OR (:new.F_RESUME_MOTOR IS NULL AND :old.F_RESUME_MOTOR IS NOT NULL) OR (:new.F_RESUME_MOTOR IS NOT NULL AND :old.F_RESUME_MOTOR IS NULL) ) THEN
    fld_name               := 'T_SYS_EXPERTZ_AUTOTECH.F_RESUME_MOTOR';
    fld_val_old            := TRUNCATE_STRING(:old.F_RESUME_MOTOR, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_RESUME_MOTOR, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESUME_BODY
  IF( (:new.F_RESUME_BODY <> :old.F_RESUME_BODY) OR (:new.F_RESUME_BODY IS NULL AND :old.F_RESUME_BODY IS NOT NULL) OR (:new.F_RESUME_BODY IS NOT NULL AND :old.F_RESUME_BODY IS NULL) ) THEN
    fld_name              := 'T_SYS_EXPERTZ_AUTOTECH.F_RESUME_BODY';
    fld_val_old           := TRUNCATE_STRING(:old.F_RESUME_BODY, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_RESUME_BODY, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RESUME_SHASSY
  IF( (:new.F_RESUME_SHASSY <> :old.F_RESUME_SHASSY) OR (:new.F_RESUME_SHASSY IS NULL AND :old.F_RESUME_SHASSY IS NOT NULL) OR (:new.F_RESUME_SHASSY IS NOT NULL AND :old.F_RESUME_SHASSY IS NULL) ) THEN
    fld_name                := 'T_SYS_EXPERTZ_AUTOTECH.F_RESUME_SHASSY';
    fld_val_old             := TRUNCATE_STRING(:old.F_RESUME_SHASSY, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_RESUME_SHASSY, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REF_MAIN_EXPERTZ
  IF( (:new.F_REF_MAIN_EXPERTZ <> :old.F_REF_MAIN_EXPERTZ) OR (:new.F_REF_MAIN_EXPERTZ IS NULL AND :old.F_REF_MAIN_EXPERTZ IS NOT NULL) OR (:new.F_REF_MAIN_EXPERTZ IS NOT NULL AND :old.F_REF_MAIN_EXPERTZ IS NULL) ) THEN
    fld_name                   := 'T_SYS_EXPERTZ_AUTOTECH.F_REF_MAIN_EXPERTZ';
    fld_val_old                := TRUNCATE_STRING(:old.F_REF_MAIN_EXPERTZ, 510);
    fld_val_new                := TRUNCATE_STRING(:new.F_REF_MAIN_EXPERTZ, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_EXPERTZ_AUTOTECH_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_EXPERTZ_FIO_LINKS"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"     VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_EVIDENCE"  VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_REF_EXPERTZ"   VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_NUMBER_TRACES" NUMBER NOT NULL ENABLE,
    "F_LINK_TYPE"     VARCHAR2(1 BYTE) DEFAULT 'D' NOT NULL ENABLE,
    CONSTRAINT "PK_SYS_EXPERTZ_FIO_LINKS" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_SYS_EXP_FIO_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_SYS_EXP_FIO_EVIDENCE" FOREIGN KEY ("F_REF_EVIDENCE") REFERENCES "EKC15"."T_SYS_EVIDENCE" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_SYS_EXP_FIO_EXPERTZ" FOREIGN KEY ("F_REF_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_FIO_LINKS"."F_REF_EVIDENCE"
IS
  '??????? ?????????? (????? ???)';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_FIO_LINKS"."F_REF_EXPERTZ"
IS
  '????????? ?? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_FIO_LINKS"."F_NUMBER_TRACES"
IS
  '????? ??????????? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_EXPERTZ_FIO_LINKS"."F_LINK_TYPE"
IS
  '??????? ?????????????: ''D''-??????????, ''V''-????????';
CREATE UNIQUE INDEX "EKC15"."PK_SYS_EXPERTZ_FIO_LINKS" ON "EKC15"."T_SYS_EXPERTZ_FIO_LINKS"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
  CREATE INDEX "EKC15"."EXP_LINK_INDEX" ON "EKC15"."T_SYS_EXPERTZ_FIO_LINKS"
    (
      "F_REF_EXPERTZ"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_EXPERTZ_SPEC"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"   VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_EXPERTZ" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_OPERATOR"    VARCHAR2(32 BYTE) NOT NULL ENABLE,
    CONSTRAINT "CK_EXPERTZ_SPEC_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_EXPERTZ_SPEC_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_EXPERTZ_SPEC_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EXPERTZ_SPEC_OPERATOR_ID" FOREIGN KEY ("F_OPERATOR") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EXPERTZ_SPEC_EXP_ID" FOREIGN KEY ("F_REF_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE UNIQUE INDEX "EKC15"."PK_EXPERTZ_SPEC_ID" ON "EKC15"."T_SYS_EXPERTZ_SPEC"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
  CREATE INDEX "EKC15"."IE_EXPERTZ_SPEC" ON "EKC15"."T_SYS_EXPERTZ_SPEC"
    (
      "F_REF_EXPERTZ"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_FABULA"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REG_AREA"  VARCHAR2(20 BYTE) DEFAULT NULL NOT NULL ENABLE,
    "F_REG_DATE" DATE,
    "F_DATE" DATE,
    "F_N_DELA"    VARCHAR2(32 BYTE),
    "F_OM"        VARCHAR2(6 BYTE),
    "F_KUSP"      VARCHAR2(15 BYTE),
    "F_VID_PREST" VARCHAR2(20 BYTE),
    "F_ADDR"      VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_KAT_DELA"  VARCHAR2(5 BYTE),
    "F_KUSP_DATE" DATE,
    "F_ADDR_EXT"            VARCHAR2(20 BYTE),
    "F_COMMENTS"            VARCHAR2(4000 BYTE),
    "F_OLDKEY"              VARCHAR2(20 BYTE),
    "F_NUM_DUPL_PLACE_DATE" NUMBER(10,0) DEFAULT 0,
    "F_ADDR_EXT_TEXT"       VARCHAR2(256 BYTE),
    "F_MAIN_VID_PREST"      VARCHAR2(20 BYTE),
    "F_UK_NUMBER"           VARCHAR2(128 BYTE),
    "F_IN_NUMBER"           VARCHAR2(20 BYTE),
    "F_IN_DATE" DATE,
    "F_SPOSOB"         VARCHAR2(10 BYTE),
    "F_IS_ANOTHER"     VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_IS_MAX_CONTROL" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "REV_COUNT"        NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    "UNI_COUNT"        NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    "F_UGD_DATE" DATE,
    CONSTRAINT "UK_FABULA_MAIN" UNIQUE ("F_DATE", "F_ADDR", "F_OLDKEY", "F_NUM_DUPL_PLACE_DATE") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_FABULA_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_FABULA_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_FABULA_ADDR" FOREIGN KEY ("F_ADDR") REFERENCES "EKC15"."T_DIC_ADDRESS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_FABULA_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_FABULA"."F_DATE"
IS
  '???? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_FABULA"."F_VID_PREST"
IS
  '??? ????????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_FABULA"."F_COMMENTS"
IS
  '??????????, ?????????? ? ???????????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_FABULA"."F_OLDKEY"
IS
  '???? ? ???? ??????+, ?????? ??? ???????????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_FABULA"."F_NUM_DUPL_PLACE_DATE"
IS
  '?????? ???????????? ? ????? ????? ? ???? ?????, ???????? ? unique index ?????? ? ????? ? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_FABULA"."F_ADDR_EXT_TEXT"
IS
  '?????????? ? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_FABULA"."F_MAIN_VID_PREST"
IS
  '??? ???????????? - ?????';
CREATE UNIQUE INDEX "EKC15"."UK_FABULA_MAIN" ON "EKC15"."T_SYS_FABULA"
  (
    "F_DATE", "F_ADDR", "F_OLDKEY", "F_NUM_DUPL_PLACE_DATE"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
CREATE UNIQUE INDEX "EKC15"."PK_FABULA_ID" ON "EKC15"."T_SYS_FABULA"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_FABULA_OLDKEY" ON "EKC15"."T_SYS_FABULA"
    (
      "F_OLDKEY"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_SYS_FABULA_ADDRESS" ON "EKC15"."T_SYS_FABULA"
    (
      "F_ADDR"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_SYS_FABULA_VID_PREST" ON "EKC15"."T_SYS_FABULA"
    (
      "F_VID_PREST"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_FABULA_REF_AREA" ON "EKC15"."T_SYS_FABULA"
    (
      "F_REG_AREA"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_FABULA_SYS_DELETED" ON "EKC15"."T_SYS_FABULA"
    (
      "SYS_DELETED"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_FABULA_DATE" ON "EKC15"."T_SYS_FABULA"
    (
      "SYS_UPDATED" DESC,
      "SYS_ID"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_FABULA_UPDATE" BEFORE
  UPDATE ON T_SYS_FABULA REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                            VARCHAR2(512);
  fld_val_new                                                                            VARCHAR2(512);
  table_code                                                                             VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_FABULA';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REG_AREA
  IF( (:new.F_REG_AREA <> :old.F_REG_AREA) OR (:new.F_REG_AREA IS NULL AND :old.F_REG_AREA IS NOT NULL) OR (:new.F_REG_AREA IS NOT NULL AND :old.F_REG_AREA IS NULL) ) THEN
    fld_name           := 'T_SYS_FABULA.F_REG_AREA';
    fld_val_old        := TRUNCATE_STRING(:old.F_REG_AREA, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_REG_AREA, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REG_DATE
  IF( (:new.F_REG_DATE <> :old.F_REG_DATE) OR (:new.F_REG_DATE IS NULL AND :old.F_REG_DATE IS NOT NULL) OR (:new.F_REG_DATE IS NOT NULL AND :old.F_REG_DATE IS NULL) ) THEN
    fld_name           := 'T_SYS_FABULA.F_REG_DATE';
    fld_val_old        := TRUNCATE_STRING(:old.F_REG_DATE, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_REG_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DATE
  IF( (:new.F_DATE <> :old.F_DATE) OR (:new.F_DATE IS NULL AND :old.F_DATE IS NOT NULL) OR (:new.F_DATE IS NOT NULL AND :old.F_DATE IS NULL) ) THEN
    fld_name       := 'T_SYS_FABULA.F_DATE';
    fld_val_old    := TO_CHAR(:old.F_DATE, 'DD.MM.YYYY');
    fld_val_new    := TO_CHAR(:new.F_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_N_DELA
  IF( (:new.F_N_DELA <> :old.F_N_DELA) OR (:new.F_N_DELA IS NULL AND :old.F_N_DELA IS NOT NULL) OR (:new.F_N_DELA IS NOT NULL AND :old.F_N_DELA IS NULL) ) THEN
    fld_name         := 'T_SYS_FABULA.F_N_DELA';
    fld_val_old      := TRUNCATE_STRING(:old.F_N_DELA, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_N_DELA, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OM
  IF( (:new.F_OM <> :old.F_OM) OR (:new.F_OM IS NULL AND :old.F_OM IS NOT NULL) OR (:new.F_OM IS NOT NULL AND :old.F_OM IS NULL) ) THEN
    fld_name     := 'T_SYS_FABULA.F_OM';
    fld_val_old  := GET_DICTIONARY_VALUE('OM', :old.F_OM);
    fld_val_new  := GET_DICTIONARY_VALUE('OM', :new.F_OM);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_KUSP
  IF( (:new.F_KUSP <> :old.F_KUSP) OR (:new.F_KUSP IS NULL AND :old.F_KUSP IS NOT NULL) OR (:new.F_KUSP IS NOT NULL AND :old.F_KUSP IS NULL) ) THEN
    fld_name       := 'T_SYS_FABULA.F_KUSP';
    fld_val_old    := TRUNCATE_STRING(:old.F_KUSP, 510);
    fld_val_new    := TRUNCATE_STRING(:new.F_KUSP, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_MAIN_VID_PREST
  IF( (:new.F_MAIN_VID_PREST <> :old.F_MAIN_VID_PREST) OR (:new.F_MAIN_VID_PREST IS NULL AND :old.F_MAIN_VID_PREST IS NOT NULL) OR (:new.F_MAIN_VID_PREST IS NOT NULL AND :old.F_MAIN_VID_PREST IS NULL) ) THEN
    fld_name                 := 'T_SYS_FABULA.F_MAIN_VID_PREST';
    fld_val_old              := GET_DICTIONARY_VALUE('Incident', :old.F_MAIN_VID_PREST);
    fld_val_new              := GET_DICTIONARY_VALUE('Incident', :new.F_MAIN_VID_PREST);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_VID_PREST
  IF( (:new.F_VID_PREST <> :old.F_VID_PREST) OR (:new.F_VID_PREST IS NULL AND :old.F_VID_PREST IS NOT NULL) OR (:new.F_VID_PREST IS NOT NULL AND :old.F_VID_PREST IS NULL) ) THEN
    fld_name            := 'T_SYS_FABULA.F_VID_PREST';
    fld_val_old         := GET_DICTIONARY_VALUE('PrecisedIncident', :old.F_VID_PREST);
    fld_val_new         := GET_DICTIONARY_VALUE('PrecisedIncident', :new.F_VID_PREST);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_ADDR
  IF( (:new.F_ADDR <> :old.F_ADDR) OR (:new.F_ADDR IS NULL AND :old.F_ADDR IS NOT NULL) OR (:new.F_ADDR IS NOT NULL AND :old.F_ADDR IS NULL) ) THEN
    fld_name       := 'T_SYS_FABULA.F_ADDR';
    fld_val_old    := TRUNCATE_STRING(:old.F_ADDR, 510);
    fld_val_new    := TRUNCATE_STRING(:new.F_ADDR, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_KAT_DELA
  IF( (:new.F_KAT_DELA <> :old.F_KAT_DELA) OR (:new.F_KAT_DELA IS NULL AND :old.F_KAT_DELA IS NOT NULL) OR (:new.F_KAT_DELA IS NOT NULL AND :old.F_KAT_DELA IS NULL) ) THEN
    fld_name           := 'T_SYS_FABULA.F_KAT_DELA';
    fld_val_old        := GET_DICTIONARY_VALUE('Categories', :old.F_KAT_DELA);
    fld_val_new        := GET_DICTIONARY_VALUE('Categories', :new.F_KAT_DELA);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_KUSP_DATE
  IF( (:new.F_KUSP_DATE <> :old.F_KUSP_DATE) OR (:new.F_KUSP_DATE IS NULL AND :old.F_KUSP_DATE IS NOT NULL) OR (:new.F_KUSP_DATE IS NOT NULL AND :old.F_KUSP_DATE IS NULL) ) THEN
    fld_name            := 'T_SYS_FABULA.F_KUSP_DATE';
    fld_val_old         := TO_CHAR(:old.F_KUSP_DATE, 'DD.MM.YYYY');
    fld_val_new         := TO_CHAR(:new.F_KUSP_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_ADDR_EXT
  IF( (:new.F_ADDR_EXT <> :old.F_ADDR_EXT) OR (:new.F_ADDR_EXT IS NULL AND :old.F_ADDR_EXT IS NOT NULL) OR (:new.F_ADDR_EXT IS NOT NULL AND :old.F_ADDR_EXT IS NULL) ) THEN
    fld_name           := 'T_SYS_FABULA.F_ADDR_EXT';
    fld_val_old        := GET_DICTIONARY_VALUE('Details', :old.F_ADDR_EXT);
    fld_val_new        := GET_DICTIONARY_VALUE('Details', :new.F_ADDR_EXT);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COMMENTS
  IF( (:new.F_COMMENTS <> :old.F_COMMENTS) OR (:new.F_COMMENTS IS NULL AND :old.F_COMMENTS IS NOT NULL) OR (:new.F_COMMENTS IS NOT NULL AND :old.F_COMMENTS IS NULL) ) THEN
    fld_name           := 'T_SYS_FABULA.F_COMMENTS';
    fld_val_old        := TRUNCATE_STRING(:old.F_COMMENTS, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_COMMENTS, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OLDKEY
  IF( (:new.F_OLDKEY <> :old.F_OLDKEY) OR (:new.F_OLDKEY IS NULL AND :old.F_OLDKEY IS NOT NULL) OR (:new.F_OLDKEY IS NOT NULL AND :old.F_OLDKEY IS NULL) ) THEN
    fld_name         := 'T_SYS_FABULA.F_OLDKEY';
    fld_val_old      := TRUNCATE_STRING(:old.F_OLDKEY, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_OLDKEY, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_NUM_DUPL_PLACE_DATE
  IF( (:new.F_NUM_DUPL_PLACE_DATE <> :old.F_NUM_DUPL_PLACE_DATE) OR (:new.F_NUM_DUPL_PLACE_DATE IS NULL AND :old.F_NUM_DUPL_PLACE_DATE IS NOT NULL) OR (:new.F_NUM_DUPL_PLACE_DATE IS NOT NULL AND :old.F_NUM_DUPL_PLACE_DATE IS NULL) ) THEN
    fld_name                      := 'T_SYS_FABULA.F_NUM_DUPL_PLACE_DATE';
    fld_val_old                   := TRUNCATE_STRING(:old.F_NUM_DUPL_PLACE_DATE, 510);
    fld_val_new                   := TRUNCATE_STRING(:new.F_NUM_DUPL_PLACE_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_ADDR_EXT_TEXT
  IF( (:new.F_ADDR_EXT_TEXT <> :old.F_ADDR_EXT_TEXT) OR (:new.F_ADDR_EXT_TEXT IS NULL AND :old.F_ADDR_EXT_TEXT IS NOT NULL) OR (:new.F_ADDR_EXT_TEXT IS NOT NULL AND :old.F_ADDR_EXT_TEXT IS NULL) ) THEN
    fld_name                := 'T_SYS_FABULA.F_ADDR_EXT_TEXT';
    fld_val_old             := TRUNCATE_STRING(:old.F_ADDR_EXT_TEXT, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_ADDR_EXT_TEXT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_UK_NUMBER
  IF( (:new.F_UK_NUMBER <> :old.F_UK_NUMBER) OR (:new.F_UK_NUMBER IS NULL AND :old.F_UK_NUMBER IS NOT NULL) OR (:new.F_UK_NUMBER IS NOT NULL AND :old.F_UK_NUMBER IS NULL) ) THEN
    fld_name            := 'T_SYS_FABULA.F_UK_NUMBER';
    fld_val_old         := TRUNCATE_STRING(:old.F_UK_NUMBER, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_UK_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SPOSOB
  IF( (:new.F_SPOSOB <> :old.F_SPOSOB) OR (:new.F_SPOSOB IS NULL AND :old.F_SPOSOB IS NOT NULL) OR (:new.F_SPOSOB IS NOT NULL AND :old.F_SPOSOB IS NULL) ) THEN
    fld_name         := 'T_SYS_FABULA.F_SPOSOB';
    fld_val_old      := GET_DICTIONARY_VALUE('Enter_methods', :old.F_SPOSOB);
    fld_val_new      := GET_DICTIONARY_VALUE('Enter_methods', :new.F_SPOSOB);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_IS_ANOTHER
  IF( (:new.F_IS_ANOTHER <> :old.F_IS_ANOTHER) OR (:new.F_IS_ANOTHER IS NULL AND :old.F_IS_ANOTHER IS NOT NULL) OR (:new.F_IS_ANOTHER IS NOT NULL AND :old.F_IS_ANOTHER IS NULL) ) THEN
    fld_name             := 'T_SYS_FABULA.F_IS_ANOTHER';
    fld_val_old          := TRUNCATE_STRING(:old.F_IS_ANOTHER, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_IS_ANOTHER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_IS_MAX_CONTROL
  IF( (:new.F_IS_MAX_CONTROL <> :old.F_IS_MAX_CONTROL) OR (:new.F_IS_MAX_CONTROL IS NULL AND :old.F_IS_MAX_CONTROL IS NOT NULL) OR (:new.F_IS_MAX_CONTROL IS NOT NULL AND :old.F_IS_MAX_CONTROL IS NULL) ) THEN
    fld_name                 := 'T_SYS_FABULA.F_IS_MAX_CONTROL';
    fld_val_old              := TRUNCATE_STRING(:old.F_IS_MAX_CONTROL, 510);
    fld_val_new              := TRUNCATE_STRING(:new.F_IS_MAX_CONTROL, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_UGD_DATE
  IF( (:new.F_UGD_DATE <> :old.F_UGD_DATE) OR (:new.F_UGD_DATE IS NULL AND :old.F_UGD_DATE IS NOT NULL) OR (:new.F_UGD_DATE IS NOT NULL AND :old.F_UGD_DATE IS NULL) ) THEN
    fld_name           := 'T_SYS_FABULA.F_UGD_DATE';
    fld_val_old        := TRUNCATE_STRING(:old.F_UGD_DATE, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_UGD_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_FABULA_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_INFO_CARD"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_TYPE"      VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_SUBTYPE"   VARCHAR2(20 BYTE),
    "F_EKC_REG_DATE" DATE,
    "F_EKC_REG_NUM" VARCHAR2(50 BYTE),
    "F_EKP_REG_DATE" DATE,
    "F_EKP_REG_NUM" VARCHAR2(50 BYTE),
    "F_REF_EXPERTZ" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_LINE_CODE"   VARCHAR2(20 BYTE),
    "F_OVD_CODE"    VARCHAR2(20 BYTE),
    "F_EKCEKP_FIO"  VARCHAR2(32 BYTE),
    "F_EKCEKP_DATE" DATE,
    "F_EKCEKP_NUMBER" VARCHAR2(16 BYTE),
    "F_GIACP_FIO"     VARCHAR2(32 BYTE),
    "F_GIACP_DATE" DATE,
    "F_GIACP_NUMBER" VARCHAR2(32 BYTE),
    "F_SP_FIO"       VARCHAR2(32 BYTE),
    "F_SP_DATE" DATE,
    "F_SP_NUMBER"    VARCHAR2(16 BYTE),
    "F_UNREG_REASON" VARCHAR2(64 BYTE),
    "F_UNREG_DATE" DATE,
    "F_UNREG_NUMBER"       VARCHAR2(16 BYTE),
    "F_COMMENTS"           VARCHAR2(2048 BYTE),
    "F_NUM_TOTAL"          NUMBER(9,0),
    "F_NUM_FINGER"         NUMBER(9,0),
    "F_NUM_PALM"           NUMBER(9,0),
    "F_NUM_FINGER_PAPILON" NUMBER(9,0),
    "F_NUM_PALM_PAPILON"   NUMBER(9,0),
    "F_EKC_DEPART"         VARCHAR2(20 BYTE),
    "F_EKP_DEPART"         VARCHAR2(20 BYTE),
    "F_EKC_REG_YEAR"       VARCHAR2(4 BYTE),
    "F_EKP_REG_YEAR"       VARCHAR2(4 BYTE),
    "F_REF_OMP"            VARCHAR2(32 BYTE),
    "F_OLDKEY"             VARCHAR2(20 BYTE),
    "F_PRODACTION_DATE" DATE,
    "F_PRODACTION_NUM"    VARCHAR2(40 BYTE),
    "F_PRODACTION_DEPART" VARCHAR2(20 BYTE),
    "F_07_FIO"            VARCHAR2(32 BYTE),
    "F_07_DATE" DATE,
    "F_07_NUMBER"      VARCHAR2(16 BYTE),
    "F_NUM_TOTAL_TAIS" NUMBER(9,0),
    "F_COMMENT_PUBLIC" VARCHAR2(2048 BYTE),
    "REV_COUNT"        NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    "UNI_COUNT"        NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    "F_HARD_COPY_DATE" DATE,
    CONSTRAINT "CK_INFO_CARD_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_INFO_CARD_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_INFO_CARD_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_INFO_CARD_OMP" FOREIGN KEY ("F_REF_OMP") REFERENCES "EKC15"."T_SYS_OMP" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_INFOCARD_EXPERTZ" FOREIGN KEY ("F_REF_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_REF_EXPERTZ"
IS
  '????????? ?????????? ? ?????????? ??????? ??? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_LINE_CODE"
IS
  '??? ????????????????, ??? ?????????? ???';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_OVD_CODE"
IS
  '???, ??? ?????????? ???';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_EKCEKP_FIO"
IS
  '???? ?????????? ? ???/???';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_EKCEKP_DATE"
IS
  '????? ?????????? ? ???/???';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_EKCEKP_NUMBER"
IS
  '???.????? ???????? ? ???/???';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_GIACP_FIO"
IS
  '???? ?????????? ? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_GIACP_DATE"
IS
  '????? ?????????? ? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_GIACP_NUMBER"
IS
  '???.????? ???????? ? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_SP_FIO"
IS
  '???? ?????????? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_SP_DATE"
IS
  '????? ?????????? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_SP_NUMBER"
IS
  '???.?????  ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_UNREG_REASON"
IS
  '??????? ?????? ? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_UNREG_DATE"
IS
  '???? ?????? ? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_UNREG_NUMBER"
IS
  'N ???? ?????? ? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_COMMENTS"
IS
  '????????????? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_NUM_TOTAL"
IS
  '?????????? ????????? ?????? ?? ??';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_NUM_FINGER"
IS
  '?????????? ?????? - ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_NUM_PALM"
IS
  '?????????? ?????? - ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_NUM_FINGER_PAPILON"
IS
  '???-?? ?????? ??????? ???. ? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_NUM_PALM_PAPILON"
IS
  '???-?? ?????? ?????? ???. ? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_EKC_DEPART"
IS
  '??? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_EKP_DEPART"
IS
  '??? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_EKC_REG_YEAR"
IS
  '??? ?????????? ?? ???? ? ???';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_EKP_REG_YEAR"
IS
  '??? ?????????? ?? ???? ? ???';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD"."F_REF_OMP"
IS
  '?????? ?? ???';
CREATE OR REPLACE TRIGGER "EKC15"."TR_INFO_CARD_UPDATE" BEFORE
  UPDATE ON T_SYS_INFO_CARD REFERENCING OLD AS OLD NEW AS NEW FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                               VARCHAR2(512);
  fld_val_new                                                                               VARCHAR2(512);
  table_code                                                                                VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_INFO_CARD';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_TYPE
  IF( (:new.F_TYPE <> :old.F_TYPE) OR (:new.F_TYPE IS NULL AND :old.F_TYPE IS NOT NULL) OR (:new.F_TYPE IS NOT NULL AND :old.F_TYPE IS NULL) ) THEN
    fld_name       := 'T_SYS_INFO_CARD.F_TYPE';
    fld_val_old    := TRUNCATE_STRING(:old.F_TYPE, 510);
    fld_val_new    := TRUNCATE_STRING(:new.F_TYPE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SUBTYPE
  IF( (:new.F_SUBTYPE <> :old.F_SUBTYPE) OR (:new.F_SUBTYPE IS NULL AND :old.F_SUBTYPE IS NOT NULL) OR (:new.F_SUBTYPE IS NOT NULL AND :old.F_SUBTYPE IS NULL) ) THEN
    fld_name          := 'T_SYS_INFO_CARD.F_SUBTYPE';
    fld_val_old       := TRUNCATE_STRING(:old.F_SUBTYPE, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_SUBTYPE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKC_REG_DATE
  IF( (:new.F_EKC_REG_DATE <> :old.F_EKC_REG_DATE) OR (:new.F_EKC_REG_DATE IS NULL AND :old.F_EKC_REG_DATE IS NOT NULL) OR (:new.F_EKC_REG_DATE IS NOT NULL AND :old.F_EKC_REG_DATE IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD.F_EKC_REG_DATE';
    fld_val_old            := TRUNCATE_STRING(:old.F_EKC_REG_DATE, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_EKC_REG_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKC_REG_NUM
  IF( (:new.F_EKC_REG_NUM <> :old.F_EKC_REG_NUM) OR (:new.F_EKC_REG_NUM IS NULL AND :old.F_EKC_REG_NUM IS NOT NULL) OR (:new.F_EKC_REG_NUM IS NOT NULL AND :old.F_EKC_REG_NUM IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD.F_EKC_REG_NUM';
    fld_val_old           := TRUNCATE_STRING(:old.F_EKC_REG_NUM, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_EKC_REG_NUM, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKP_REG_DATE
  IF( (:new.F_EKP_REG_DATE <> :old.F_EKP_REG_DATE) OR (:new.F_EKP_REG_DATE IS NULL AND :old.F_EKP_REG_DATE IS NOT NULL) OR (:new.F_EKP_REG_DATE IS NOT NULL AND :old.F_EKP_REG_DATE IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD.F_EKP_REG_DATE';
    fld_val_old            := TRUNCATE_STRING(:old.F_EKP_REG_DATE, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_EKP_REG_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKP_REG_NUM
  IF( (:new.F_EKP_REG_NUM <> :old.F_EKP_REG_NUM) OR (:new.F_EKP_REG_NUM IS NULL AND :old.F_EKP_REG_NUM IS NOT NULL) OR (:new.F_EKP_REG_NUM IS NOT NULL AND :old.F_EKP_REG_NUM IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD.F_EKP_REG_NUM';
    fld_val_old           := TRUNCATE_STRING(:old.F_EKP_REG_NUM, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_EKP_REG_NUM, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REF_EXPERTZ
  IF( (:new.F_REF_EXPERTZ <> :old.F_REF_EXPERTZ) OR (:new.F_REF_EXPERTZ IS NULL AND :old.F_REF_EXPERTZ IS NOT NULL) OR (:new.F_REF_EXPERTZ IS NOT NULL AND :old.F_REF_EXPERTZ IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD.F_REF_EXPERTZ';
    fld_val_old           := TRUNCATE_STRING(:old.F_REF_EXPERTZ, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_REF_EXPERTZ, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_LINE_CODE
  IF( (:new.F_LINE_CODE <> :old.F_LINE_CODE) OR (:new.F_LINE_CODE IS NULL AND :old.F_LINE_CODE IS NOT NULL) OR (:new.F_LINE_CODE IS NOT NULL AND :old.F_LINE_CODE IS NULL) ) THEN
    fld_name            := 'T_SYS_INFO_CARD.F_LINE_CODE';
    fld_val_old         := TRUNCATE_STRING(:old.F_LINE_CODE, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_LINE_CODE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OVD_CODE
  IF( (:new.F_OVD_CODE <> :old.F_OVD_CODE) OR (:new.F_OVD_CODE IS NULL AND :old.F_OVD_CODE IS NOT NULL) OR (:new.F_OVD_CODE IS NOT NULL AND :old.F_OVD_CODE IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD.F_OVD_CODE';
    fld_val_old        := TRUNCATE_STRING(:old.F_OVD_CODE, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_OVD_CODE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKC_REG_YEAR
  IF( (:new.F_EKC_REG_YEAR <> :old.F_EKC_REG_YEAR) OR (:new.F_EKC_REG_YEAR IS NULL AND :old.F_EKC_REG_YEAR IS NOT NULL) OR (:new.F_EKC_REG_YEAR IS NOT NULL AND :old.F_EKC_REG_YEAR IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD.F_EKC_REG_YEAR';
    fld_val_old            := TRUNCATE_STRING(:old.F_EKC_REG_YEAR, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_EKC_REG_YEAR, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKP_REG_YEAR
  IF( (:new.F_EKP_REG_YEAR <> :old.F_EKP_REG_YEAR) OR (:new.F_EKP_REG_YEAR IS NULL AND :old.F_EKP_REG_YEAR IS NOT NULL) OR (:new.F_EKP_REG_YEAR IS NOT NULL AND :old.F_EKP_REG_YEAR IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD.F_EKP_REG_YEAR';
    fld_val_old            := TRUNCATE_STRING(:old.F_EKP_REG_YEAR, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_EKP_REG_YEAR, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKCEKP_FIO
  IF( (:new.F_EKCEKP_FIO <> :old.F_EKCEKP_FIO) OR (:new.F_EKCEKP_FIO IS NULL AND :old.F_EKCEKP_FIO IS NOT NULL) OR (:new.F_EKCEKP_FIO IS NOT NULL AND :old.F_EKCEKP_FIO IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD.F_EKCEKP_FIO';
    fld_val_old          := TRUNCATE_STRING(:old.F_EKCEKP_FIO, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_EKCEKP_FIO, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKCEKP_DATE
  IF( (:new.F_EKCEKP_DATE <> :old.F_EKCEKP_DATE) OR (:new.F_EKCEKP_DATE IS NULL AND :old.F_EKCEKP_DATE IS NOT NULL) OR (:new.F_EKCEKP_DATE IS NOT NULL AND :old.F_EKCEKP_DATE IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD.F_EKCEKP_DATE';
    fld_val_old           := TRUNCATE_STRING(:old.F_EKCEKP_DATE, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_EKCEKP_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKCEKP_NUMBER
  IF( (:new.F_EKCEKP_NUMBER <> :old.F_EKCEKP_NUMBER) OR (:new.F_EKCEKP_NUMBER IS NULL AND :old.F_EKCEKP_NUMBER IS NOT NULL) OR (:new.F_EKCEKP_NUMBER IS NOT NULL AND :old.F_EKCEKP_NUMBER IS NULL) ) THEN
    fld_name                := 'T_SYS_INFO_CARD.F_EKCEKP_NUMBER';
    fld_val_old             := TRUNCATE_STRING(:old.F_EKCEKP_NUMBER, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_EKCEKP_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_GIACP_FIO
  IF( (:new.F_GIACP_FIO <> :old.F_GIACP_FIO) OR (:new.F_GIACP_FIO IS NULL AND :old.F_GIACP_FIO IS NOT NULL) OR (:new.F_GIACP_FIO IS NOT NULL AND :old.F_GIACP_FIO IS NULL) ) THEN
    fld_name            := 'T_SYS_INFO_CARD.F_GIACP_FIO';
    fld_val_old         := TRUNCATE_STRING(:old.F_GIACP_FIO, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_GIACP_FIO, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_GIACP_DATE
  IF( (:new.F_GIACP_DATE <> :old.F_GIACP_DATE) OR (:new.F_GIACP_DATE IS NULL AND :old.F_GIACP_DATE IS NOT NULL) OR (:new.F_GIACP_DATE IS NOT NULL AND :old.F_GIACP_DATE IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD.F_GIACP_DATE';
    fld_val_old          := TRUNCATE_STRING(:old.F_GIACP_DATE, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_GIACP_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_GIACP_NUMBER
  IF( (:new.F_GIACP_NUMBER <> :old.F_GIACP_NUMBER) OR (:new.F_GIACP_NUMBER IS NULL AND :old.F_GIACP_NUMBER IS NOT NULL) OR (:new.F_GIACP_NUMBER IS NOT NULL AND :old.F_GIACP_NUMBER IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD.F_GIACP_NUMBER';
    fld_val_old            := TRUNCATE_STRING(:old.F_GIACP_NUMBER, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_GIACP_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SP_FIO
  IF( (:new.F_SP_FIO <> :old.F_SP_FIO) OR (:new.F_SP_FIO IS NULL AND :old.F_SP_FIO IS NOT NULL) OR (:new.F_SP_FIO IS NOT NULL AND :old.F_SP_FIO IS NULL) ) THEN
    fld_name         := 'T_SYS_INFO_CARD.F_SP_FIO';
    fld_val_old      := TRUNCATE_STRING(:old.F_SP_FIO, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_SP_FIO, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SP_DATE
  IF( (:new.F_SP_DATE <> :old.F_SP_DATE) OR (:new.F_SP_DATE IS NULL AND :old.F_SP_DATE IS NOT NULL) OR (:new.F_SP_DATE IS NOT NULL AND :old.F_SP_DATE IS NULL) ) THEN
    fld_name          := 'T_SYS_INFO_CARD.F_SP_DATE';
    fld_val_old       := TRUNCATE_STRING(:old.F_SP_DATE, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_SP_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SP_NUMBER
  IF( (:new.F_SP_NUMBER <> :old.F_SP_NUMBER) OR (:new.F_SP_NUMBER IS NULL AND :old.F_SP_NUMBER IS NOT NULL) OR (:new.F_SP_NUMBER IS NOT NULL AND :old.F_SP_NUMBER IS NULL) ) THEN
    fld_name            := 'T_SYS_INFO_CARD.F_SP_NUMBER';
    fld_val_old         := TRUNCATE_STRING(:old.F_SP_NUMBER, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_SP_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_UNREG_REASON
  IF( (:new.F_UNREG_REASON <> :old.F_UNREG_REASON) OR (:new.F_UNREG_REASON IS NULL AND :old.F_UNREG_REASON IS NOT NULL) OR (:new.F_UNREG_REASON IS NOT NULL AND :old.F_UNREG_REASON IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD.F_UNREG_REASON';
    fld_val_old            := TRUNCATE_STRING(:old.F_UNREG_REASON, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_UNREG_REASON, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_UNREG_DATE
  IF( (:new.F_UNREG_DATE <> :old.F_UNREG_DATE) OR (:new.F_UNREG_DATE IS NULL AND :old.F_UNREG_DATE IS NOT NULL) OR (:new.F_UNREG_DATE IS NOT NULL AND :old.F_UNREG_DATE IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD.F_UNREG_DATE';
    fld_val_old          := TRUNCATE_STRING(:old.F_UNREG_DATE, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_UNREG_DATE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_UNREG_NUMBER
  IF( (:new.F_UNREG_NUMBER <> :old.F_UNREG_NUMBER) OR (:new.F_UNREG_NUMBER IS NULL AND :old.F_UNREG_NUMBER IS NOT NULL) OR (:new.F_UNREG_NUMBER IS NOT NULL AND :old.F_UNREG_NUMBER IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD.F_UNREG_NUMBER';
    fld_val_old            := TRUNCATE_STRING(:old.F_UNREG_NUMBER, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_UNREG_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COMMENTS
  IF( (:new.F_COMMENTS <> :old.F_COMMENTS) OR (:new.F_COMMENTS IS NULL AND :old.F_COMMENTS IS NOT NULL) OR (:new.F_COMMENTS IS NOT NULL AND :old.F_COMMENTS IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD.F_COMMENTS';
    fld_val_old        := TRUNCATE_STRING(:old.F_COMMENTS, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_COMMENTS, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_NUM_TOTAL
  IF( (:new.F_NUM_TOTAL <> :old.F_NUM_TOTAL) OR (:new.F_NUM_TOTAL IS NULL AND :old.F_NUM_TOTAL IS NOT NULL) OR (:new.F_NUM_TOTAL IS NOT NULL AND :old.F_NUM_TOTAL IS NULL) ) THEN
    fld_name            := 'T_SYS_INFO_CARD.F_NUM_TOTAL';
    fld_val_old         := TRUNCATE_STRING(:old.F_NUM_TOTAL, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_NUM_TOTAL, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_NUM_FINGER
  IF( (:new.F_NUM_FINGER <> :old.F_NUM_FINGER) OR (:new.F_NUM_FINGER IS NULL AND :old.F_NUM_FINGER IS NOT NULL) OR (:new.F_NUM_FINGER IS NOT NULL AND :old.F_NUM_FINGER IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD.F_NUM_FINGER';
    fld_val_old          := TRUNCATE_STRING(:old.F_NUM_FINGER, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_NUM_FINGER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_NUM_PALM
  IF( (:new.F_NUM_PALM <> :old.F_NUM_PALM) OR (:new.F_NUM_PALM IS NULL AND :old.F_NUM_PALM IS NOT NULL) OR (:new.F_NUM_PALM IS NOT NULL AND :old.F_NUM_PALM IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD.F_NUM_PALM';
    fld_val_old        := TRUNCATE_STRING(:old.F_NUM_PALM, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_NUM_PALM, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_NUM_FINGER_PAPILON
  IF( (:new.F_NUM_FINGER_PAPILON <> :old.F_NUM_FINGER_PAPILON) OR (:new.F_NUM_FINGER_PAPILON IS NULL AND :old.F_NUM_FINGER_PAPILON IS NOT NULL) OR (:new.F_NUM_FINGER_PAPILON IS NOT NULL AND :old.F_NUM_FINGER_PAPILON IS NULL) ) THEN
    fld_name                     := 'T_SYS_INFO_CARD.F_NUM_FINGER_PAPILON';
    fld_val_old                  := TRUNCATE_STRING(:old.F_NUM_FINGER_PAPILON, 510);
    fld_val_new                  := TRUNCATE_STRING(:new.F_NUM_FINGER_PAPILON, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_NUM_PALM_PAPILON
  IF( (:new.F_NUM_PALM_PAPILON <> :old.F_NUM_PALM_PAPILON) OR (:new.F_NUM_PALM_PAPILON IS NULL AND :old.F_NUM_PALM_PAPILON IS NOT NULL) OR (:new.F_NUM_PALM_PAPILON IS NOT NULL AND :old.F_NUM_PALM_PAPILON IS NULL) ) THEN
    fld_name                   := 'T_SYS_INFO_CARD.F_NUM_PALM_PAPILON';
    fld_val_old                := TRUNCATE_STRING(:old.F_NUM_PALM_PAPILON, 510);
    fld_val_new                := TRUNCATE_STRING(:new.F_NUM_PALM_PAPILON, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKC_DEPART
  IF( (:new.F_EKC_DEPART <> :old.F_EKC_DEPART) OR (:new.F_EKC_DEPART IS NULL AND :old.F_EKC_DEPART IS NOT NULL) OR (:new.F_EKC_DEPART IS NOT NULL AND :old.F_EKC_DEPART IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD.F_EKC_DEPART';
    fld_val_old          := TRUNCATE_STRING(:old.F_EKC_DEPART, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_EKC_DEPART, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKP_DEPART
  IF( (:new.F_EKP_DEPART <> :old.F_EKP_DEPART) OR (:new.F_EKP_DEPART IS NULL AND :old.F_EKP_DEPART IS NOT NULL) OR (:new.F_EKP_DEPART IS NOT NULL AND :old.F_EKP_DEPART IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD.F_EKP_DEPART';
    fld_val_old          := TRUNCATE_STRING(:old.F_EKP_DEPART, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_EKP_DEPART, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_INFO_CARD_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_INFO_CARD_CP"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REG_NUM"   VARCHAR2(64 BYTE),
    "F_REG_DATE" DATE,
    "F_SOFT_NAME"         VARCHAR2(50 BYTE),
    "F_REF_FABULA"        VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_INITIATOR"         VARCHAR2(100 BYTE),
    "F_INIT_STAT"         VARCHAR2(100 BYTE),
    "F_INIT_DEPART"       VARCHAR2(20 BYTE),
    "F_INIT_PHONE"        VARCHAR2(50 BYTE),
    "F_EYE_FIO"           VARCHAR2(200 BYTE),
    "F_EYE_OLD"           VARCHAR2(32 BYTE),
    "F_EYE_HEIGHT"        VARCHAR2(64 BYTE),
    "F_EYE_TYPE"          VARCHAR2(50 BYTE),
    "F_EYE_NATIONAL"      VARCHAR2(100 BYTE),
    "F_EYE_EDUCATION"     VARCHAR2(50 BYTE),
    "F_EYE_PROF"          VARCHAR2(100 BYTE),
    "F_EYE_OCCUP"         VARCHAR2(100 BYTE),
    "F_EYE_EYES"          VARCHAR2(64 BYTE),
    "F_EYE_PSIHOFIZ"      VARCHAR2(64 BYTE),
    "F_EYE_ROLE"          VARCHAR2(32 BYTE),
    "F_EYE_DISTANCE"      VARCHAR2(40 BYTE),
    "F_EYE_PERIOD"        VARCHAR2(50 BYTE),
    "F_EYE_SIMILARITY"    VARCHAR2(20 BYTE),
    "F_EYE_COMMENT"       VARCHAR2(1024 BYTE),
    "F_OBJ_MALE"          VARCHAR2(1 BYTE),
    "F_OBJ_OLD"           VARCHAR2(20 BYTE),
    "F_OBJ_TYPE"          VARCHAR2(64 BYTE),
    "F_OBJ_HEIGHT"        VARCHAR2(64 BYTE),
    "F_OBJ_BODY"          VARCHAR2(32 BYTE),
    "F_OBJ_HAIR_COLOR"    VARCHAR2(60 BYTE),
    "F_OBJ_EYE_COLOR"     VARCHAR2(100 BYTE),
    "F_OBJ_SPEC"          VARCHAR2(500 BYTE),
    "F_OBJ_DRESS"         VARCHAR2(400 BYTE),
    "F_TEST_CP_DEPART"    VARCHAR2(20 BYTE),
    "F_TEST_CP_NUMBER"    VARCHAR2(50 BYTE),
    "F_TEST_CP_FIO"       VARCHAR2(32 BYTE),
    "F_TEST_CP_SEND"      VARCHAR2(20 BYTE),
    "F_TEST_PHOTO_DEPART" VARCHAR2(20 BYTE),
    "F_TEST_PHOTO_NUMBER" VARCHAR2(50 BYTE),
    "F_TEST_PHOTO_FIO"    VARCHAR2(32 BYTE),
    "F_REG_FIO"           VARCHAR2(32 BYTE),
    "F_REF_OMP"           VARCHAR2(32 BYTE),
    "F_CODE_VID"          VARCHAR2(8 BYTE),
    "F_CODE_SUBJECT"      VARCHAR2(8 BYTE),
    "F_CODE_ORGAN"        VARCHAR2(8 BYTE),
    "F_YEAR_REG"          VARCHAR2(8 BYTE),
    "F_REG_AREA"          VARCHAR2(20 BYTE),
    "F_REG_CB_DATE" DATE,
    "F_ARCHIVED"   VARCHAR2(1 BYTE),
    "F_REG_NUM_07" VARCHAR2(64 BYTE),
    "F_REG_DATE_07" DATE,
    "F_YEAR_REG_07"  VARCHAR2(8 BYTE),
    "F_COMMENTS"     VARCHAR2(2048 BYTE),
    "F_UNREG_REASON" VARCHAR2(64 BYTE),
    "F_UNREG_DATE" DATE,
    "F_EKP_CH_DATE" DATE,
    "F_EKC_CH_DATE" DATE,
    "F_EKP_CHECKER" VARCHAR2(32 BYTE),
    "F_EKC_CHECKER" VARCHAR2(32 BYTE),
    "REV_COUNT"     NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    "UNI_COUNT"     NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    CONSTRAINT "PK_INFO_CARD_CP_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_INFO_CARD_CP_DELETED" CHECK (SYS_DELETED IN ('Y','N') ) ENABLE,
    CONSTRAINT "FK_EKP_EXECUTOR" FOREIGN KEY ("F_EKP_CHECKER") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_INFO_CARD_CP_FABULA" FOREIGN KEY ("F_REF_FABULA") REFERENCES "EKC15"."T_SYS_FABULA" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_EKC_EXECUTOR" FOREIGN KEY ("F_EKC_CHECKER") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_INFO_CARD_CP_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_INFO_CARD_CP_OMP" FOREIGN KEY ("F_REF_OMP") REFERENCES "EKC15"."T_SYS_OMP" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_REG_NUM"
IS
  '????? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_REG_DATE"
IS
  '???? ???????????? ??';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_SOFT_NAME"
IS
  '????????? ??';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_REF_FABULA"
IS
  '?????? ?? ????????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_INITIATOR"
IS
  '?????????(???)';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_INIT_STAT"
IS
  '????????? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_INIT_DEPART"
IS
  '????? ?????????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_INIT_PHONE"
IS
  '??.???.??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_FIO"
IS
  '???';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_OLD"
IS
  '??????? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_HEIGHT"
IS
  '???? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_TYPE"
IS
  '????????????????? ??? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_NATIONAL"
IS
  '?????????????? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_EDUCATION"
IS
  '??????????? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_PROF"
IS
  '????????? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_OCCUP"
IS
  '??? ??????? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_EYES"
IS
  '????????? ?????? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_PSIHOFIZ"
IS
  '???????????.????????? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_ROLE"
IS
  '???? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_DISTANCE"
IS
  '?????????? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_PERIOD"
IS
  '???????????? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_SIMILARITY"
IS
  '???????? ?? ? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_EYE_COMMENT"
IS
  '???? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_OBJ_MALE"
IS
  '??? ?????????????? ????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_OBJ_OLD"
IS
  '??????? ?????????????? ????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_OBJ_TYPE"
IS
  '????????????????? ???';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_OBJ_HEIGHT"
IS
  '???? ?????????????? ????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_OBJ_BODY"
IS
  '????????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_OBJ_HAIR_COLOR"
IS
  '???? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_OBJ_EYE_COLOR"
IS
  '???? ????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_OBJ_SPEC"
IS
  '?????? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_OBJ_DRESS"
IS
  '??????, ????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_TEST_CP_DEPART"
IS
  '?? ???????? ?? ????????? ?? (?????????????)';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_TEST_CP_NUMBER"
IS
  '??????????? ??????? ???????? ? ?? ?? N';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_TEST_CP_FIO"
IS
  '??????? ???????? ?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_TEST_CP_SEND"
IS
  '?? ???????????? ? ????????? (?????????????)';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_TEST_PHOTO_DEPART"
IS
  '?? ???????? ?? ???????? (?????????????)';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_TEST_PHOTO_NUMBER"
IS
  '??????????? ??????? ???????? ? ???? ?? N';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_TEST_PHOTO_FIO"
IS
  '??????? ???????? ?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_REG_FIO"
IS
  '?? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_REF_OMP"
IS
  '?????? ?? ??? (???????????)';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_CODE_VID"
IS
  '??? ???? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_CODE_SUBJECT"
IS
  '??? ???????? ?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_CODE_ORGAN"
IS
  '??? ???????????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_INFO_CARD_CP"."F_YEAR_REG"
IS
  '??? ?????????? ?? ????';
CREATE OR REPLACE TRIGGER "EKC15"."TR_SUBJPORT_UPDATE" BEFORE
  UPDATE ON T_SYS_INFO_CARD_CP REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                  VARCHAR2(512);
  fld_val_new                                                                                  VARCHAR2(512);
  table_code                                                                                   VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_INFO_CARD_CP';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REG_NUM
  IF( (:new.F_REG_NUM <> :old.F_REG_NUM) OR (:new.F_REG_NUM IS NULL AND :old.F_REG_NUM IS NOT NULL) OR (:new.F_REG_NUM IS NOT NULL AND :old.F_REG_NUM IS NULL) ) THEN
    fld_name          := 'T_SYS_INFO_CARD_CP.F_REG_NUM';
    fld_val_old       := TRUNCATE_STRING(:old.F_REG_NUM, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_REG_NUM, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REG_DATE
  IF( (:new.F_REG_DATE <> :old.F_REG_DATE) OR (:new.F_REG_DATE IS NULL AND :old.F_REG_DATE IS NOT NULL) OR (:new.F_REG_DATE IS NOT NULL AND :old.F_REG_DATE IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_REG_DATE';
    fld_val_old        := TO_CHAR(:old.F_REG_DATE, 'DD.MM.YYYY');
    fld_val_new        := TO_CHAR(:new.F_REG_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SOFT_NAME
  IF( (:new.F_SOFT_NAME <> :old.F_SOFT_NAME) OR (:new.F_SOFT_NAME IS NULL AND :old.F_SOFT_NAME IS NOT NULL) OR (:new.F_SOFT_NAME IS NOT NULL AND :old.F_SOFT_NAME IS NULL) ) THEN
    fld_name            := 'T_SYS_INFO_CARD_CP.F_SOFT_NAME';
    fld_val_old         := TRUNCATE_STRING(:old.F_SOFT_NAME, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_SOFT_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_INITIATOR
  IF( (:new.F_INITIATOR <> :old.F_INITIATOR) OR (:new.F_INITIATOR IS NULL AND :old.F_INITIATOR IS NOT NULL) OR (:new.F_INITIATOR IS NOT NULL AND :old.F_INITIATOR IS NULL) ) THEN
    fld_name            := 'T_SYS_INFO_CARD_CP.F_INITIATOR';
    fld_val_old         := TRUNCATE_STRING(:old.F_INITIATOR, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_INITIATOR, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_INIT_STAT
  IF( (:new.F_INIT_STAT <> :old.F_INIT_STAT) OR (:new.F_INIT_STAT IS NULL AND :old.F_INIT_STAT IS NOT NULL) OR (:new.F_INIT_STAT IS NOT NULL AND :old.F_INIT_STAT IS NULL) ) THEN
    fld_name            := 'T_SYS_INFO_CARD_CP.F_INIT_STAT';
    fld_val_old         := TRUNCATE_STRING(:old.F_INIT_STAT, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_INIT_STAT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_INIT_DEPART
  IF( (:new.F_INIT_DEPART <> :old.F_INIT_DEPART) OR (:new.F_INIT_DEPART IS NULL AND :old.F_INIT_DEPART IS NOT NULL) OR (:new.F_INIT_DEPART IS NOT NULL AND :old.F_INIT_DEPART IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD_CP.F_INIT_DEPART';
    fld_val_old           := TRUNCATE_STRING(:old.F_INIT_DEPART, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_INIT_DEPART, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_INIT_PHONE
  IF( (:new.F_INIT_PHONE <> :old.F_INIT_PHONE) OR (:new.F_INIT_PHONE IS NULL AND :old.F_INIT_PHONE IS NOT NULL) OR (:new.F_INIT_PHONE IS NOT NULL AND :old.F_INIT_PHONE IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD_CP.F_INIT_PHONE';
    fld_val_old          := TRUNCATE_STRING(:old.F_INIT_PHONE, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_INIT_PHONE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_FIO
  IF( (:new.F_EYE_FIO <> :old.F_EYE_FIO) OR (:new.F_EYE_FIO IS NULL AND :old.F_EYE_FIO IS NOT NULL) OR (:new.F_EYE_FIO IS NOT NULL AND :old.F_EYE_FIO IS NULL) ) THEN
    fld_name          := 'T_SYS_INFO_CARD_CP.F_EYE_FIO';
    fld_val_old       := TRUNCATE_STRING(:old.F_EYE_FIO, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_EYE_FIO, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_OLD
  IF( (:new.F_EYE_OLD <> :old.F_EYE_OLD) OR (:new.F_EYE_OLD IS NULL AND :old.F_EYE_OLD IS NOT NULL) OR (:new.F_EYE_OLD IS NOT NULL AND :old.F_EYE_OLD IS NULL) ) THEN
    fld_name          := 'T_SYS_INFO_CARD_CP.F_EYE_OLD';
    fld_val_old       := TRUNCATE_STRING(:old.F_EYE_OLD, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_EYE_OLD, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_HEIGHT
  IF( (:new.F_EYE_HEIGHT <> :old.F_EYE_HEIGHT) OR (:new.F_EYE_HEIGHT IS NULL AND :old.F_EYE_HEIGHT IS NOT NULL) OR (:new.F_EYE_HEIGHT IS NOT NULL AND :old.F_EYE_HEIGHT IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD_CP.F_EYE_HEIGHT';
    fld_val_old          := TRUNCATE_STRING(:old.F_EYE_HEIGHT, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_EYE_HEIGHT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_TYPE
  IF( (:new.F_EYE_TYPE <> :old.F_EYE_TYPE) OR (:new.F_EYE_TYPE IS NULL AND :old.F_EYE_TYPE IS NOT NULL) OR (:new.F_EYE_TYPE IS NOT NULL AND :old.F_EYE_TYPE IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_EYE_TYPE';
    fld_val_old        := TRUNCATE_STRING(:old.F_EYE_TYPE, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_EYE_TYPE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_NATIONAL
  IF( (:new.F_EYE_NATIONAL <> :old.F_EYE_NATIONAL) OR (:new.F_EYE_NATIONAL IS NULL AND :old.F_EYE_NATIONAL IS NOT NULL) OR (:new.F_EYE_NATIONAL IS NOT NULL AND :old.F_EYE_NATIONAL IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD_CP.F_EYE_NATIONAL';
    fld_val_old            := TRUNCATE_STRING(:old.F_EYE_NATIONAL, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_EYE_NATIONAL, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_EDUCATION
  IF( (:new.F_EYE_EDUCATION <> :old.F_EYE_EDUCATION) OR (:new.F_EYE_EDUCATION IS NULL AND :old.F_EYE_EDUCATION IS NOT NULL) OR (:new.F_EYE_EDUCATION IS NOT NULL AND :old.F_EYE_EDUCATION IS NULL) ) THEN
    fld_name                := 'T_SYS_INFO_CARD_CP.F_EYE_EDUCATION';
    fld_val_old             := TRUNCATE_STRING(:old.F_EYE_EDUCATION, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_EYE_EDUCATION, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_PROF
  IF( (:new.F_EYE_PROF <> :old.F_EYE_PROF) OR (:new.F_EYE_PROF IS NULL AND :old.F_EYE_PROF IS NOT NULL) OR (:new.F_EYE_PROF IS NOT NULL AND :old.F_EYE_PROF IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_EYE_PROF';
    fld_val_old        := TRUNCATE_STRING(:old.F_EYE_PROF, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_EYE_PROF, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_OCCUP
  IF( (:new.F_EYE_OCCUP <> :old.F_EYE_OCCUP) OR (:new.F_EYE_OCCUP IS NULL AND :old.F_EYE_OCCUP IS NOT NULL) OR (:new.F_EYE_OCCUP IS NOT NULL AND :old.F_EYE_OCCUP IS NULL) ) THEN
    fld_name            := 'T_SYS_INFO_CARD_CP.F_EYE_OCCUP';
    fld_val_old         := TRUNCATE_STRING(:old.F_EYE_OCCUP, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_EYE_OCCUP, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_EYES
  IF( (:new.F_EYE_EYES <> :old.F_EYE_EYES) OR (:new.F_EYE_EYES IS NULL AND :old.F_EYE_EYES IS NOT NULL) OR (:new.F_EYE_EYES IS NOT NULL AND :old.F_EYE_EYES IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_EYE_EYES';
    fld_val_old        := TRUNCATE_STRING(:old.F_EYE_EYES, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_EYE_EYES, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_PSIHOFIZ
  IF( (:new.F_EYE_PSIHOFIZ <> :old.F_EYE_PSIHOFIZ) OR (:new.F_EYE_PSIHOFIZ IS NULL AND :old.F_EYE_PSIHOFIZ IS NOT NULL) OR (:new.F_EYE_PSIHOFIZ IS NOT NULL AND :old.F_EYE_PSIHOFIZ IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD_CP.F_EYE_PSIHOFIZ';
    fld_val_old            := TRUNCATE_STRING(:old.F_EYE_PSIHOFIZ, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_EYE_PSIHOFIZ, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_ROLE
  IF( (:new.F_EYE_ROLE <> :old.F_EYE_ROLE) OR (:new.F_EYE_ROLE IS NULL AND :old.F_EYE_ROLE IS NOT NULL) OR (:new.F_EYE_ROLE IS NOT NULL AND :old.F_EYE_ROLE IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_EYE_ROLE';
    fld_val_old        := TRUNCATE_STRING(:old.F_EYE_ROLE, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_EYE_ROLE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_DISTANCE
  IF( (:new.F_EYE_DISTANCE <> :old.F_EYE_DISTANCE) OR (:new.F_EYE_DISTANCE IS NULL AND :old.F_EYE_DISTANCE IS NOT NULL) OR (:new.F_EYE_DISTANCE IS NOT NULL AND :old.F_EYE_DISTANCE IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD_CP.F_EYE_DISTANCE';
    fld_val_old            := TRUNCATE_STRING(:old.F_EYE_DISTANCE, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_EYE_DISTANCE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_PERIOD
  IF( (:new.F_EYE_PERIOD <> :old.F_EYE_PERIOD) OR (:new.F_EYE_PERIOD IS NULL AND :old.F_EYE_PERIOD IS NOT NULL) OR (:new.F_EYE_PERIOD IS NOT NULL AND :old.F_EYE_PERIOD IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD_CP.F_EYE_PERIOD';
    fld_val_old          := TRUNCATE_STRING(:old.F_EYE_PERIOD, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_EYE_PERIOD, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_SIMILARITY
  IF( (:new.F_EYE_SIMILARITY <> :old.F_EYE_SIMILARITY) OR (:new.F_EYE_SIMILARITY IS NULL AND :old.F_EYE_SIMILARITY IS NOT NULL) OR (:new.F_EYE_SIMILARITY IS NOT NULL AND :old.F_EYE_SIMILARITY IS NULL) ) THEN
    fld_name                 := 'T_SYS_INFO_CARD_CP.F_EYE_SIMILARITY';
    fld_val_old              := TRUNCATE_STRING(:old.F_EYE_SIMILARITY, 510);
    fld_val_new              := TRUNCATE_STRING(:new.F_EYE_SIMILARITY, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EYE_COMMENT
  IF( (:new.F_EYE_COMMENT <> :old.F_EYE_COMMENT) OR (:new.F_EYE_COMMENT IS NULL AND :old.F_EYE_COMMENT IS NOT NULL) OR (:new.F_EYE_COMMENT IS NOT NULL AND :old.F_EYE_COMMENT IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD_CP.F_EYE_COMMENT';
    fld_val_old           := TRUNCATE_STRING(:old.F_EYE_COMMENT, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_EYE_COMMENT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OBJ_MALE
  IF( (:new.F_OBJ_MALE <> :old.F_OBJ_MALE) OR (:new.F_OBJ_MALE IS NULL AND :old.F_OBJ_MALE IS NOT NULL) OR (:new.F_OBJ_MALE IS NOT NULL AND :old.F_OBJ_MALE IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_OBJ_MALE';
    fld_val_old        := TRUNCATE_STRING(:old.F_OBJ_MALE, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_OBJ_MALE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OBJ_OLD
  IF( (:new.F_OBJ_OLD <> :old.F_OBJ_OLD) OR (:new.F_OBJ_OLD IS NULL AND :old.F_OBJ_OLD IS NOT NULL) OR (:new.F_OBJ_OLD IS NOT NULL AND :old.F_OBJ_OLD IS NULL) ) THEN
    fld_name          := 'T_SYS_INFO_CARD_CP.F_OBJ_OLD';
    fld_val_old       := TRUNCATE_STRING(:old.F_OBJ_OLD, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_OBJ_OLD, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OBJ_TYPE
  IF( (:new.F_OBJ_TYPE <> :old.F_OBJ_TYPE) OR (:new.F_OBJ_TYPE IS NULL AND :old.F_OBJ_TYPE IS NOT NULL) OR (:new.F_OBJ_TYPE IS NOT NULL AND :old.F_OBJ_TYPE IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_OBJ_TYPE';
    fld_val_old        := TRUNCATE_STRING(:old.F_OBJ_TYPE, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_OBJ_TYPE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OBJ_HEIGHT
  IF( (:new.F_OBJ_HEIGHT <> :old.F_OBJ_HEIGHT) OR (:new.F_OBJ_HEIGHT IS NULL AND :old.F_OBJ_HEIGHT IS NOT NULL) OR (:new.F_OBJ_HEIGHT IS NOT NULL AND :old.F_OBJ_HEIGHT IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD_CP.F_OBJ_HEIGHT';
    fld_val_old          := TRUNCATE_STRING(:old.F_OBJ_HEIGHT, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_OBJ_HEIGHT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OBJ_BODY
  IF( (:new.F_OBJ_BODY <> :old.F_OBJ_BODY) OR (:new.F_OBJ_BODY IS NULL AND :old.F_OBJ_BODY IS NOT NULL) OR (:new.F_OBJ_BODY IS NOT NULL AND :old.F_OBJ_BODY IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_OBJ_BODY';
    fld_val_old        := TRUNCATE_STRING(:old.F_OBJ_BODY, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_OBJ_BODY, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OBJ_HAIR_COLOR
  IF( (:new.F_OBJ_HAIR_COLOR <> :old.F_OBJ_HAIR_COLOR) OR (:new.F_OBJ_HAIR_COLOR IS NULL AND :old.F_OBJ_HAIR_COLOR IS NOT NULL) OR (:new.F_OBJ_HAIR_COLOR IS NOT NULL AND :old.F_OBJ_HAIR_COLOR IS NULL) ) THEN
    fld_name                 := 'T_SYS_INFO_CARD_CP.F_OBJ_HAIR_COLOR';
    fld_val_old              := TRUNCATE_STRING(:old.F_OBJ_HAIR_COLOR, 510);
    fld_val_new              := TRUNCATE_STRING(:new.F_OBJ_HAIR_COLOR, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OBJ_EYE_COLOR
  IF( (:new.F_OBJ_EYE_COLOR <> :old.F_OBJ_EYE_COLOR) OR (:new.F_OBJ_EYE_COLOR IS NULL AND :old.F_OBJ_EYE_COLOR IS NOT NULL) OR (:new.F_OBJ_EYE_COLOR IS NOT NULL AND :old.F_OBJ_EYE_COLOR IS NULL) ) THEN
    fld_name                := 'T_SYS_INFO_CARD_CP.F_OBJ_EYE_COLOR';
    fld_val_old             := TRUNCATE_STRING(:old.F_OBJ_EYE_COLOR, 510);
    fld_val_new             := TRUNCATE_STRING(:new.F_OBJ_EYE_COLOR, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OBJ_SPEC
  IF( (:new.F_OBJ_SPEC <> :old.F_OBJ_SPEC) OR (:new.F_OBJ_SPEC IS NULL AND :old.F_OBJ_SPEC IS NOT NULL) OR (:new.F_OBJ_SPEC IS NOT NULL AND :old.F_OBJ_SPEC IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_OBJ_SPEC';
    fld_val_old        := TRUNCATE_STRING(:old.F_OBJ_SPEC, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_OBJ_SPEC, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OBJ_DRESS
  IF( (:new.F_OBJ_DRESS <> :old.F_OBJ_DRESS) OR (:new.F_OBJ_DRESS IS NULL AND :old.F_OBJ_DRESS IS NOT NULL) OR (:new.F_OBJ_DRESS IS NOT NULL AND :old.F_OBJ_DRESS IS NULL) ) THEN
    fld_name            := 'T_SYS_INFO_CARD_CP.F_OBJ_DRESS';
    fld_val_old         := TRUNCATE_STRING(:old.F_OBJ_DRESS, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_OBJ_DRESS, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_TEST_CP_DEPART
  IF( (:new.F_TEST_CP_DEPART <> :old.F_TEST_CP_DEPART) OR (:new.F_TEST_CP_DEPART IS NULL AND :old.F_TEST_CP_DEPART IS NOT NULL) OR (:new.F_TEST_CP_DEPART IS NOT NULL AND :old.F_TEST_CP_DEPART IS NULL) ) THEN
    fld_name                 := 'T_SYS_INFO_CARD_CP.F_TEST_CP_DEPART';
    fld_val_old              := GET_DICTIONARY_VALUE('Regions-EKC', :old.F_TEST_CP_DEPART);
    fld_val_new              := GET_DICTIONARY_VALUE('Regions-EKC', :new.F_TEST_CP_DEPART);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_TEST_CP_SEND
  IF( (:new.F_TEST_CP_SEND <> :old.F_TEST_CP_SEND) OR (:new.F_TEST_CP_SEND IS NULL AND :old.F_TEST_CP_SEND IS NOT NULL) OR (:new.F_TEST_CP_SEND IS NOT NULL AND :old.F_TEST_CP_SEND IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD_CP.F_TEST_CP_SEND';
    fld_val_old            := GET_DICTIONARY_VALUE('Regions-EKC', :old.F_TEST_CP_SEND);
    fld_val_new            := GET_DICTIONARY_VALUE('Regions-EKC', :new.F_TEST_CP_SEND);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_TEST_PHOTO_DEPART
  IF( (:new.F_TEST_PHOTO_DEPART <> :old.F_TEST_PHOTO_DEPART) OR (:new.F_TEST_PHOTO_DEPART IS NULL AND :old.F_TEST_PHOTO_DEPART IS NOT NULL) OR (:new.F_TEST_PHOTO_DEPART IS NOT NULL AND :old.F_TEST_PHOTO_DEPART IS NULL) ) THEN
    fld_name                    := 'T_SYS_INFO_CARD_CP.F_TEST_PHOTO_DEPART';
    fld_val_old                 := GET_DICTIONARY_VALUE('Regions-EKC', :old.F_TEST_PHOTO_DEPART);
    fld_val_new                 := GET_DICTIONARY_VALUE('Regions-EKC', :new.F_TEST_PHOTO_DEPART);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_TEST_CP_NUMBER
  IF( (:new.F_TEST_CP_NUMBER <> :old.F_TEST_CP_NUMBER) OR (:new.F_TEST_CP_NUMBER IS NULL AND :old.F_TEST_CP_NUMBER IS NOT NULL) OR (:new.F_TEST_CP_NUMBER IS NOT NULL AND :old.F_TEST_CP_NUMBER IS NULL) ) THEN
    fld_name                 := 'T_SYS_INFO_CARD_CP.F_TEST_CP_NUMBER';
    fld_val_old              := TRUNCATE_STRING(:old.F_TEST_CP_NUMBER, 510);
    fld_val_new              := TRUNCATE_STRING(:new.F_TEST_CP_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_TEST_PHOTO_NUMBER
  IF( (:new.F_TEST_PHOTO_NUMBER <> :old.F_TEST_PHOTO_NUMBER) OR (:new.F_TEST_PHOTO_NUMBER IS NULL AND :old.F_TEST_PHOTO_NUMBER IS NOT NULL) OR (:new.F_TEST_PHOTO_NUMBER IS NOT NULL AND :old.F_TEST_PHOTO_NUMBER IS NULL) ) THEN
    fld_name                    := 'T_SYS_INFO_CARD_CP.F_TEST_PHOTO_NUMBER';
    fld_val_old                 := TRUNCATE_STRING(:old.F_TEST_PHOTO_NUMBER, 510);
    fld_val_new                 := TRUNCATE_STRING(:new.F_TEST_PHOTO_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_CODE_VID
  IF( (:new.F_CODE_VID <> :old.F_CODE_VID) OR (:new.F_CODE_VID IS NULL AND :old.F_CODE_VID IS NOT NULL) OR (:new.F_CODE_VID IS NOT NULL AND :old.F_CODE_VID IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_CODE_VID';
    fld_val_old        := TRUNCATE_STRING(:old.F_CODE_VID, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_CODE_VID, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_CODE_SUBJECT
  IF( (:new.F_CODE_SUBJECT <> :old.F_CODE_SUBJECT) OR (:new.F_CODE_SUBJECT IS NULL AND :old.F_CODE_SUBJECT IS NOT NULL) OR (:new.F_CODE_SUBJECT IS NOT NULL AND :old.F_CODE_SUBJECT IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD_CP.F_CODE_SUBJECT';
    fld_val_old            := TRUNCATE_STRING(:old.F_CODE_SUBJECT, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_CODE_SUBJECT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_CODE_ORGAN
  IF( (:new.F_CODE_ORGAN <> :old.F_CODE_ORGAN) OR (:new.F_CODE_ORGAN IS NULL AND :old.F_CODE_ORGAN IS NOT NULL) OR (:new.F_CODE_ORGAN IS NOT NULL AND :old.F_CODE_ORGAN IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD_CP.F_CODE_ORGAN';
    fld_val_old          := TRUNCATE_STRING(:old.F_CODE_ORGAN, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_CODE_ORGAN, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_YEAR_REG
  IF( (:new.F_YEAR_REG <> :old.F_YEAR_REG) OR (:new.F_YEAR_REG IS NULL AND :old.F_YEAR_REG IS NOT NULL) OR (:new.F_YEAR_REG IS NOT NULL AND :old.F_YEAR_REG IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_YEAR_REG';
    fld_val_old        := TRUNCATE_STRING(:old.F_YEAR_REG, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_YEAR_REG, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REG_CB_DATE
  IF( (:new.F_REG_CB_DATE <> :old.F_REG_CB_DATE) OR (:new.F_REG_CB_DATE IS NULL AND :old.F_REG_CB_DATE IS NOT NULL) OR (:new.F_REG_CB_DATE IS NOT NULL AND :old.F_REG_CB_DATE IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD_CP.F_REG_CB_DATE';
    fld_val_old           := TO_CHAR(:old.F_REG_CB_DATE, 'DD.MM.YYYY');
    fld_val_new           := TO_CHAR(:new.F_REG_CB_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REG_AREA
  IF( (:new.F_REG_AREA <> :old.F_REG_AREA) OR (:new.F_REG_AREA IS NULL AND :old.F_REG_AREA IS NOT NULL) OR (:new.F_REG_AREA IS NOT NULL AND :old.F_REG_AREA IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_REG_AREA';
    fld_val_old        := GET_DICTIONARY_VALUE('Regions-EKC', :old.F_REG_AREA);
    fld_val_new        := GET_DICTIONARY_VALUE('Regions-EKC', :new.F_REG_AREA);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_ARCHIVED
  IF( (:new.F_ARCHIVED <> :old.F_ARCHIVED) OR (:new.F_ARCHIVED IS NULL AND :old.F_ARCHIVED IS NOT NULL) OR (:new.F_ARCHIVED IS NOT NULL AND :old.F_ARCHIVED IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_ARCHIVED';
    fld_val_old        := TRUNCATE_STRING(:old.F_ARCHIVED, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_ARCHIVED, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REG_NUM_07
  IF( (:new.F_REG_NUM_07 <> :old.F_REG_NUM_07) OR (:new.F_REG_NUM_07 IS NULL AND :old.F_REG_NUM_07 IS NOT NULL) OR (:new.F_REG_NUM_07 IS NOT NULL AND :old.F_REG_NUM_07 IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD_CP.F_REG_NUM_07';
    fld_val_old          := TRUNCATE_STRING(:old.F_REG_NUM_07, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_REG_NUM_07, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REG_DATE_07
  IF( (:new.F_REG_DATE_07 <> :old.F_REG_DATE_07) OR (:new.F_REG_DATE_07 IS NULL AND :old.F_REG_DATE_07 IS NOT NULL) OR (:new.F_REG_DATE_07 IS NOT NULL AND :old.F_REG_DATE_07 IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD_CP.F_REG_DATE_07';
    fld_val_old           := TO_CHAR(:old.F_REG_DATE_07, 'DD.MM.YYYY');
    fld_val_new           := TO_CHAR(:new.F_REG_DATE_07, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_YEAR_REG_07
  IF( (:new.F_YEAR_REG_07 <> :old.F_YEAR_REG_07) OR (:new.F_YEAR_REG_07 IS NULL AND :old.F_YEAR_REG_07 IS NOT NULL) OR (:new.F_YEAR_REG_07 IS NOT NULL AND :old.F_YEAR_REG_07 IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD_CP.F_YEAR_REG_07';
    fld_val_old           := TRUNCATE_STRING(:old.F_YEAR_REG_07, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_YEAR_REG_07, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COMMENTS
  IF( (:new.F_COMMENTS <> :old.F_COMMENTS) OR (:new.F_COMMENTS IS NULL AND :old.F_COMMENTS IS NOT NULL) OR (:new.F_COMMENTS IS NOT NULL AND :old.F_COMMENTS IS NULL) ) THEN
    fld_name           := 'T_SYS_INFO_CARD_CP.F_COMMENTS';
    fld_val_old        := TRUNCATE_STRING(:old.F_COMMENTS, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_COMMENTS, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_UNREG_REASON
  IF( (:new.F_UNREG_REASON <> :old.F_UNREG_REASON) OR (:new.F_UNREG_REASON IS NULL AND :old.F_UNREG_REASON IS NOT NULL) OR (:new.F_UNREG_REASON IS NOT NULL AND :old.F_UNREG_REASON IS NULL) ) THEN
    fld_name               := 'T_SYS_INFO_CARD_CP.F_UNREG_REASON';
    fld_val_old            := TRUNCATE_STRING(:old.F_UNREG_REASON, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_UNREG_REASON, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_UNREG_DATE
  IF( (:new.F_UNREG_DATE <> :old.F_UNREG_DATE) OR (:new.F_UNREG_DATE IS NULL AND :old.F_UNREG_DATE IS NOT NULL) OR (:new.F_UNREG_DATE IS NOT NULL AND :old.F_UNREG_DATE IS NULL) ) THEN
    fld_name             := 'T_SYS_INFO_CARD_CP.F_UNREG_DATE';
    fld_val_old          := TO_CHAR(:old.F_UNREG_DATE, 'DD.MM.YYYY');
    fld_val_new          := TO_CHAR(:new.F_UNREG_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKP_CH_DATE
  IF( (:new.F_EKP_CH_DATE <> :old.F_EKP_CH_DATE) OR (:new.F_EKP_CH_DATE IS NULL AND :old.F_EKP_CH_DATE IS NOT NULL) OR (:new.F_EKP_CH_DATE IS NOT NULL AND :old.F_EKP_CH_DATE IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD_CP.F_EKP_CH_DATE';
    fld_val_old           := TO_CHAR(:old.F_EKP_CH_DATE, 'DD.MM.YYYY');
    fld_val_new           := TO_CHAR(:new.F_EKP_CH_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKC_CH_DATE
  IF( (:new.F_EKC_CH_DATE <> :old.F_EKC_CH_DATE) OR (:new.F_EKC_CH_DATE IS NULL AND :old.F_EKC_CH_DATE IS NOT NULL) OR (:new.F_EKC_CH_DATE IS NOT NULL AND :old.F_EKC_CH_DATE IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD_CP.F_EKC_CH_DATE';
    fld_val_old           := TO_CHAR(:old.F_EKC_CH_DATE, 'DD.MM.YYYY');
    fld_val_new           := TO_CHAR(:new.F_EKC_CH_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKP_CHECKER
  IF( (:new.F_EKP_CHECKER <> :old.F_EKP_CHECKER) OR (:new.F_EKP_CHECKER IS NULL AND :old.F_EKP_CHECKER IS NOT NULL) OR (:new.F_EKP_CHECKER IS NOT NULL AND :old.F_EKP_CHECKER IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD_CP.F_EKP_CHECKER';
    fld_val_old           := GET_OPERATOR_NAME(:old.F_EKP_CHECKER);
    fld_val_new           := GET_OPERATOR_NAME(:new.F_EKP_CHECKER);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_EKC_CHECKER
  IF( (:new.F_EKC_CHECKER <> :old.F_EKC_CHECKER) OR (:new.F_EKC_CHECKER IS NULL AND :old.F_EKC_CHECKER IS NOT NULL) OR (:new.F_EKC_CHECKER IS NOT NULL AND :old.F_EKC_CHECKER IS NULL) ) THEN
    fld_name              := 'T_SYS_INFO_CARD_CP.F_EKC_CHECKER';
    fld_val_old           := GET_OPERATOR_NAME(:old.F_EKC_CHECKER);
    fld_val_new           := GET_OPERATOR_NAME(:new.F_EKC_CHECKER);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_SUBJPORT_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_JOURNAL_OMP"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_OMP"   VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_DEPART"    VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_OMP_NUM"   VARCHAR2(20 BYTE),
    "F_EKC_GROUP" VARCHAR2(20 BYTE),
    CONSTRAINT "PK_JOURNAL_OMP" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_JOURNAL_OMP_DELETED" CHECK (SYS_DELETED IN ('N', 'Y') ) ENABLE,
    CONSTRAINT "UN_JOURNAL_OMP_OMP_IN_JRNL" UNIQUE ("F_REF_OMP", "F_DEPART", "F_EKC_GROUP") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_JOURNAL_OMP_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_JOURNAL_OMP_REF_OMP" FOREIGN KEY ("F_REF_OMP") REFERENCES "EKC15"."T_SYS_OMP" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_JOURNAL_OMP"."F_REF_OMP"
IS
  'OMP reference';
  COMMENT ON COLUMN "EKC15"."T_SYS_JOURNAL_OMP"."F_DEPART"
IS
  'EKC department number';
CREATE UNIQUE INDEX "EKC15"."PK_JOURNAL_OMP" ON "EKC15"."T_SYS_JOURNAL_OMP"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
CREATE UNIQUE INDEX "EKC15"."UN_JOURNAL_OMP_OMP_IN_JRNL" ON "EKC15"."T_SYS_JOURNAL_OMP"
  (
    "F_REF_OMP", "F_DEPART", "F_EKC_GROUP"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
  CREATE INDEX "EKC15"."IE_JOURNAL_OMP_DEPART" ON "EKC15"."T_SYS_JOURNAL_OMP"
    (
      "F_DEPART"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_JOURNAL_OMP_UPDATE" BEFORE
  UPDATE ON T_SYS_JOURNAL_OMP REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                 VARCHAR2(512);
  fld_val_new                                                                                 VARCHAR2(512);
  table_code                                                                                  VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_JOURNAL_OMP';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REF_OMP
  IF( (:new.F_REF_OMP <> :old.F_REF_OMP) OR (:new.F_REF_OMP IS NULL AND :old.F_REF_OMP IS NOT NULL) OR (:new.F_REF_OMP IS NOT NULL AND :old.F_REF_OMP IS NULL) ) THEN
    fld_name          := 'T_SYS_JOURNAL_OMP.F_REF_OMP';
    fld_val_old       := TRUNCATE_STRING(:old.F_REF_OMP, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_REF_OMP, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DEPART
  IF( (:new.F_DEPART <> :old.F_DEPART) OR (:new.F_DEPART IS NULL AND :old.F_DEPART IS NOT NULL) OR (:new.F_DEPART IS NOT NULL AND :old.F_DEPART IS NULL) ) THEN
    fld_name         := 'T_SYS_JOURNAL_OMP.F_DEPART';
    fld_val_old      := TRUNCATE_STRING(:old.F_DEPART, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_DEPART, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OMP_NUM
  IF( (:new.F_OMP_NUM <> :old.F_OMP_NUM) OR (:new.F_OMP_NUM IS NULL AND :old.F_OMP_NUM IS NOT NULL) OR (:new.F_OMP_NUM IS NOT NULL AND :old.F_OMP_NUM IS NULL) ) THEN
    fld_name          := 'T_SYS_JOURNAL_OMP.F_OMP_NUM';
    fld_val_old       := TRUNCATE_STRING(:old.F_OMP_NUM, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_OMP_NUM, 510);
    P_AUDIT_POPULATE(:new.F_REF_OMP, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_JOURNAL_OMP_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_KEMVI"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"   VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_EXPERTZ" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_KEMVI_TYPE"  VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_PARAM_1"     VARCHAR2(32 BYTE),
    "F_PARAM_2"     VARCHAR2(32 BYTE),
    "F_PARAM_3"     VARCHAR2(32 BYTE),
    CONSTRAINT "PK_SYS_KEMVI" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_KEMVI_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_KEMVI_EXPERTZ" FOREIGN KEY ("F_REF_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE INDEX "EKC15"."IE_KEMVI" ON "EKC15"."T_SYS_KEMVI"
  (
    "F_REF_EXPERTZ"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE UNIQUE INDEX "EKC15"."PK_SYS_KEMVI" ON "EKC15"."T_SYS_KEMVI"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_NEWS"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_DATE" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "F_ORDER"    VARCHAR2(8 BYTE),
    "F_TEXT"     VARCHAR2(4000 BYTE),
    "FONT_SIZE"  VARCHAR2(4 BYTE) DEFAULT '16px' NOT NULL ENABLE,
    "FONT_COLOR" VARCHAR2(8 BYTE) DEFAULT 'black' NOT NULL ENABLE,
    CONSTRAINT "PK_NEWS_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "CK_NEWS_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "FK_NEWS_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_OMP"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_OMP_NUM"   VARCHAR2(20 BYTE),
    "F_OMP_TYPE"  VARCHAR2(10 BYTE) NOT NULL ENABLE,
    "F_OMP_DATE" DATE NOT NULL ENABLE,
    "F_TIME_OUT" TIMESTAMP (6),
    "F_TIME_BACK" TIMESTAMP (6),
    "F_SOG"        VARCHAR2(255 BYTE),
    "F_FABULA"     VARCHAR2(4000 BYTE),
    "F_SPOSOB"     VARCHAR2(10 BYTE),
    "F_DONE"       VARCHAR2(64 BYTE),
    "F_FABULA_REF" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_CORPSES"    NUMBER(2,0),
    CONSTRAINT "PK_T_SYS_OMP" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_OMP_DEL" CHECK (SYS_DELETED IN ('Y','N') ) ENABLE,
    CONSTRAINT "FK_FABULA_REF" FOREIGN KEY ("F_FABULA_REF") REFERENCES "EKC15"."T_SYS_FABULA" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_OMP_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE UNIQUE INDEX "EKC15"."PK_T_SYS_OMP" ON "EKC15"."T_SYS_OMP"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_OMP_FABULA_REF" ON "EKC15"."T_SYS_OMP"
    (
      "F_FABULA_REF"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_OMP_SYS_UPDATED" ON "EKC15"."T_SYS_OMP"
    (
      "SYS_UPDATED" DESC
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_OMP_UPDATE" BEFORE
  UPDATE ON T_SYS_OMP REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                         VARCHAR2(512);
  fld_val_new                                                                         VARCHAR2(512);
  table_code                                                                          VARCHAR2(40);
  BEGIN
    table_code := 'T_SYS_OMP';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_OMP_TYPE
    IF( (:new.F_OMP_TYPE <> :old.F_OMP_TYPE) OR (:new.F_OMP_TYPE IS NULL AND :old.F_OMP_TYPE IS NOT NULL) OR (:new.F_OMP_TYPE IS NOT NULL AND :old.F_OMP_TYPE IS NULL) ) THEN
      fld_name           := 'T_SYS_OMP.F_OMP_TYPE';
      fld_val_old        := GET_DICTIONARY_VALUE('Type-CD', :old.F_OMP_TYPE);
      fld_val_new        := GET_DICTIONARY_VALUE('Type-CD', :new.F_OMP_TYPE);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_OMP_DATE
    IF( (:new.F_OMP_DATE <> :old.F_OMP_DATE) OR (:new.F_OMP_DATE IS NULL AND :old.F_OMP_DATE IS NOT NULL) OR (:new.F_OMP_DATE IS NOT NULL AND :old.F_OMP_DATE IS NULL) ) THEN
      fld_name           := 'T_SYS_OMP.F_OMP_DATE';
      fld_val_old        := TO_CHAR(:old.F_OMP_DATE, 'DD.MM.YYYY');
      fld_val_new        := TO_CHAR(:new.F_OMP_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_TIME_OUT
    IF( (:new.F_TIME_OUT <> :old.F_TIME_OUT) OR (:new.F_TIME_OUT IS NULL AND :old.F_TIME_OUT IS NOT NULL) OR (:new.F_TIME_OUT IS NOT NULL AND :old.F_TIME_OUT IS NULL) ) THEN
      fld_name           := 'T_SYS_OMP.F_TIME_OUT';
      fld_val_old        := TO_CHAR(:old.F_TIME_OUT, 'HH24:MI');
      fld_val_new        := TO_CHAR(:new.F_TIME_OUT, 'HH24:MI');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_TIME_BACK
    IF( (:new.F_TIME_BACK <> :old.F_TIME_BACK) OR (:new.F_TIME_BACK IS NULL AND :old.F_TIME_BACK IS NOT NULL) OR (:new.F_TIME_BACK IS NOT NULL AND :old.F_TIME_BACK IS NULL) ) THEN
      fld_name            := 'T_SYS_OMP.F_TIME_BACK';
      fld_val_old         := TO_CHAR(:old.F_TIME_BACK, 'HH24:MI');
      fld_val_new         := TO_CHAR(:new.F_TIME_BACK, 'HH24:MI');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_SOG
    IF( (:new.F_SOG <> :old.F_SOG) OR (:new.F_SOG IS NULL AND :old.F_SOG IS NOT NULL) OR (:new.F_SOG IS NOT NULL AND :old.F_SOG IS NULL) ) THEN
      fld_name      := 'T_SYS_OMP.F_SOG';
      fld_val_old   := TRUNCATE_STRING(:old.F_SOG, 510);
      fld_val_new   := TRUNCATE_STRING(:new.F_SOG, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_FABULA
    IF( (:new.F_FABULA <> :old.F_FABULA) OR (:new.F_FABULA IS NULL AND :old.F_FABULA IS NOT NULL) OR (:new.F_FABULA IS NOT NULL AND :old.F_FABULA IS NULL) ) THEN
      fld_name         := 'T_SYS_OMP.F_FABULA';
      fld_val_old      := TRUNCATE_STRING(:old.F_FABULA, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_FABULA, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_DONE
    IF( (:new.F_DONE <> :old.F_DONE) OR (:new.F_DONE IS NULL AND :old.F_DONE IS NOT NULL) OR (:new.F_DONE IS NOT NULL AND :old.F_DONE IS NULL) ) THEN
      fld_name       := 'T_SYS_OMP.F_DONE';
      fld_val_old    := TRUNCATE_STRING(:old.F_DONE, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_DONE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_OMP_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_OMP_DACT"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_FIO"   VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_REF_OMP"   VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_CATEGORY"  VARCHAR2(20 BYTE) NOT NULL ENABLE,
    CONSTRAINT "PK_OMP_DACT" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_T_SYS_FIO_DACT" FOREIGN KEY ("F_REF_FIO") REFERENCES "EKC15"."T_SYS_PERSON" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_T_SYS_OMP_DACT" FOREIGN KEY ("F_REF_OMP") REFERENCES "EKC15"."T_SYS_OMP" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_OMP_DACT_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "USERS" ;



CREATE TABLE "EKC15"."T_SYS_OMP_SPEC"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_OMP"       VARCHAR2(32 BYTE),
    "F_OPERATOR"  VARCHAR2(32 BYTE),
    "F_TYPE"      VARCHAR2(1 BYTE) DEFAULT 'S' NOT NULL ENABLE,
    CONSTRAINT "CH_SYS_OMP_SPEC_TYPE" CHECK (F_TYPE IN ('S','H') ) ENABLE,
    CONSTRAINT "PK_SYS_OMP_SPEC" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_T_SYS_OMP" FOREIGN KEY ("F_OMP") REFERENCES "EKC15"."T_SYS_OMP" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_T_SYS_OPERATOR" FOREIGN KEY ("F_OPERATOR") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_OMP_SPEC_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_OMP_SPEC_UPDATE" BEFORE
  UPDATE ON T_SYS_OMP_SPEC REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                              VARCHAR2(512);
  fld_val_new                                                                              VARCHAR2(512);
  table_code                                                                               VARCHAR2(40);
  BEGIN
    table_code := 'T_SYS_OMP_SPEC';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_OMP
    IF( (:new.F_OMP <> :old.F_OMP) OR (:new.F_OMP IS NULL AND :old.F_OMP IS NOT NULL) OR (:new.F_OMP IS NOT NULL AND :old.F_OMP IS NULL) ) THEN
      fld_name      := 'T_SYS_OMP_SPEC.F_OMP';
      fld_val_old   := TRUNCATE_STRING(:old.F_OMP, 510);
      fld_val_new   := TRUNCATE_STRING(:new.F_OMP, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_OPERATOR
    IF( (:new.F_OPERATOR <> :old.F_OPERATOR) OR (:new.F_OPERATOR IS NULL AND :old.F_OPERATOR IS NOT NULL) OR (:new.F_OPERATOR IS NOT NULL AND :old.F_OPERATOR IS NULL) ) THEN
      fld_name           := 'T_SYS_OMP_SPEC.F_OPERATOR';
      fld_val_old        := TRUNCATE_STRING(:old.F_OPERATOR, 510);
      fld_val_new        := TRUNCATE_STRING(:new.F_OPERATOR, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_TYPE
    IF( (:new.F_TYPE <> :old.F_TYPE) OR (:new.F_TYPE IS NULL AND :old.F_TYPE IS NOT NULL) OR (:new.F_TYPE IS NOT NULL AND :old.F_TYPE IS NULL) ) THEN
      fld_name       := 'T_SYS_OMP_SPEC.F_TYPE';
      fld_val_old    := TRUNCATE_STRING(:old.F_TYPE, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_TYPE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_OMP_SPEC_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_OPERATORS"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"            VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_FIRST_NAME"           VARCHAR2(40 BYTE),
    "F_SECOND_NAME"          VARCHAR2(40 BYTE),
    "F_LAST_NAME"            VARCHAR2(40 BYTE),
    "F_LOGIN"                VARCHAR2(40 BYTE) NOT NULL ENABLE,
    "F_PWDHASH"              VARCHAR2(40 BYTE) NOT NULL ENABLE,
    "F_SIGN"                 VARCHAR2(40 BYTE),
    "F_DEPART"               VARCHAR2(20 BYTE),
    "F_GROUP"                VARCHAR2(20 BYTE),
    "F_POSITION"             VARCHAR2(20 BYTE),
    "F_RANK"                 VARCHAR2(20 BYTE),
    "F_SHTATN"               VARCHAR2(20 BYTE),
    "F_ATTEST"               VARCHAR2(20 BYTE),
    "F_POS_STATUS"           VARCHAR2(20 BYTE),
    "SYS_READONLY"           VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "SYS_TEMPORARY_PASSWORD" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "SYS_ACCOUNT_BLOCKED"    VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    CONSTRAINT "CK_OPERATORS_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_OPERATORS_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_OPERATORS_RO" CHECK (SYS_READONLY IN ('Y', 'N')
  AND SYS_TEMPORARY_PASSWORD                         IN ('Y', 'N')
  AND SYS_ACCOUNT_BLOCKED                            IN ('Y', 'N') ) ENABLE,
    CONSTRAINT "FK_OPERATORS_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_OPERATORS"."F_DEPART"
IS
  '?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_OPERATORS"."F_GROUP"
IS
  '??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_OPERATORS"."F_POSITION"
IS
  '?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_OPERATORS"."F_RANK"
IS
  '??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_OPERATORS"."F_SHTATN"
IS
  '????????? (???? - ?? ????)';
  COMMENT ON COLUMN "EKC15"."T_SYS_OPERATORS"."F_ATTEST"
IS
  '?????????? ?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_OPERATORS"."F_POS_STATUS"
IS
  '????????? ?????????';
CREATE OR REPLACE TRIGGER "EKC15"."TR_OPERATORS_UPDATE" BEFORE
  UPDATE ON T_SYS_OPERATORS REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                               VARCHAR2(512);
  fld_val_new                                                                               VARCHAR2(512);
  table_code                                                                                VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_OPERATORS';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_FIRST_NAME
  IF( (:new.F_FIRST_NAME <> :old.F_FIRST_NAME) OR (:new.F_FIRST_NAME IS NULL AND :old.F_FIRST_NAME IS NOT NULL) OR (:new.F_FIRST_NAME IS NOT NULL AND :old.F_FIRST_NAME IS NULL) ) THEN
    fld_name             := 'T_SYS_OPERATORS.F_FIRST_NAME';
    fld_val_old          := TRUNCATE_STRING(:old.F_FIRST_NAME, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_FIRST_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SECOND_NAME
  IF( (:new.F_SECOND_NAME <> :old.F_SECOND_NAME) OR (:new.F_SECOND_NAME IS NULL AND :old.F_SECOND_NAME IS NOT NULL) OR (:new.F_SECOND_NAME IS NOT NULL AND :old.F_SECOND_NAME IS NULL) ) THEN
    fld_name              := 'T_SYS_OPERATORS.F_SECOND_NAME';
    fld_val_old           := TRUNCATE_STRING(:old.F_SECOND_NAME, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_SECOND_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_LAST_NAME
  IF( (:new.F_LAST_NAME <> :old.F_LAST_NAME) OR (:new.F_LAST_NAME IS NULL AND :old.F_LAST_NAME IS NOT NULL) OR (:new.F_LAST_NAME IS NOT NULL AND :old.F_LAST_NAME IS NULL) ) THEN
    fld_name            := 'T_SYS_OPERATORS.F_LAST_NAME';
    fld_val_old         := TRUNCATE_STRING(:old.F_LAST_NAME, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_LAST_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_LOGIN
  IF( (:new.F_LOGIN <> :old.F_LOGIN) OR (:new.F_LOGIN IS NULL AND :old.F_LOGIN IS NOT NULL) OR (:new.F_LOGIN IS NOT NULL AND :old.F_LOGIN IS NULL) ) THEN
    fld_name        := 'T_SYS_OPERATORS.F_LOGIN';
    fld_val_old     := TRUNCATE_STRING(:old.F_LOGIN, 510);
    fld_val_new     := TRUNCATE_STRING(:new.F_LOGIN, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_PWDHASH
  IF( (:new.F_PWDHASH <> :old.F_PWDHASH) OR (:new.F_PWDHASH IS NULL AND :old.F_PWDHASH IS NOT NULL) OR (:new.F_PWDHASH IS NOT NULL AND :old.F_PWDHASH IS NULL) ) THEN
    fld_name          := 'T_SYS_OPERATORS.F_PWDHASH';
    fld_val_old       := ' ';
    fld_val_new       := ' ';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SIGN
  IF( (:new.F_SIGN <> :old.F_SIGN) OR (:new.F_SIGN IS NULL AND :old.F_SIGN IS NOT NULL) OR (:new.F_SIGN IS NOT NULL AND :old.F_SIGN IS NULL) ) THEN
    fld_name       := 'T_SYS_OPERATORS.F_SIGN';
    fld_val_old    := TRUNCATE_STRING(:old.F_SIGN, 510);
    fld_val_new    := TRUNCATE_STRING(:new.F_SIGN, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DEPART
  IF( (:new.F_DEPART <> :old.F_DEPART) OR (:new.F_DEPART IS NULL AND :old.F_DEPART IS NOT NULL) OR (:new.F_DEPART IS NOT NULL AND :old.F_DEPART IS NULL) ) THEN
    fld_name         := 'T_SYS_OPERATORS.F_DEPART';
    fld_val_old      := GET_DICTIONARY_VALUE('Regions-EKC', :old.F_DEPART);
    fld_val_new      := GET_DICTIONARY_VALUE('Regions-EKC', :new.F_DEPART);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_GROUP
  IF( (:new.F_GROUP <> :old.F_GROUP) OR (:new.F_GROUP IS NULL AND :old.F_GROUP IS NOT NULL) OR (:new.F_GROUP IS NOT NULL AND :old.F_GROUP IS NULL) ) THEN
    fld_name        := 'T_SYS_OPERATORS.F_GROUP';
    fld_val_old     := GET_DICTIONARY_VALUE('EKC-Groups', :old.F_GROUP);
    fld_val_new     := GET_DICTIONARY_VALUE('EKC-Groups', :new.F_GROUP);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_POSITION
  IF( (:new.F_POSITION <> :old.F_POSITION) OR (:new.F_POSITION IS NULL AND :old.F_POSITION IS NOT NULL) OR (:new.F_POSITION IS NOT NULL AND :old.F_POSITION IS NULL) ) THEN
    fld_name           := 'T_SYS_OPERATORS.F_POSITION';
    fld_val_old        := GET_DICTIONARY_VALUE('Position', :old.F_POSITION);
    fld_val_new        := GET_DICTIONARY_VALUE('Position', :new.F_POSITION);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_RANK
  IF( (:new.F_RANK <> :old.F_RANK) OR (:new.F_RANK IS NULL AND :old.F_RANK IS NOT NULL) OR (:new.F_RANK IS NOT NULL AND :old.F_RANK IS NULL) ) THEN
    fld_name       := 'T_SYS_OPERATORS.F_RANK';
    fld_val_old    := TRUNCATE_STRING(:old.F_RANK, 510);
    fld_val_new    := TRUNCATE_STRING(:new.F_RANK, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SHTATN
  IF( (:new.F_SHTATN <> :old.F_SHTATN) OR (:new.F_SHTATN IS NULL AND :old.F_SHTATN IS NOT NULL) OR (:new.F_SHTATN IS NOT NULL AND :old.F_SHTATN IS NULL) ) THEN
    fld_name         := 'T_SYS_OPERATORS.F_SHTATN';
    fld_val_old      := GET_DICTIONARY_VALUE('Shtatnost', :old.F_SHTATN);
    fld_val_new      := GET_DICTIONARY_VALUE('Shtatnost', :new.F_SHTATN);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_ATTEST
  IF( (:new.F_ATTEST <> :old.F_ATTEST) OR (:new.F_ATTEST IS NULL AND :old.F_ATTEST IS NOT NULL) OR (:new.F_ATTEST IS NOT NULL AND :old.F_ATTEST IS NULL) ) THEN
    fld_name         := 'T_SYS_OPERATORS.F_ATTEST';
    fld_val_old      := GET_DICTIONARY_VALUE('PosAttest', :old.F_ATTEST);
    fld_val_new      := GET_DICTIONARY_VALUE('PosAttest', :new.F_ATTEST);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_POS_STATUS
  IF( (:new.F_POS_STATUS <> :old.F_POS_STATUS) OR (:new.F_POS_STATUS IS NULL AND :old.F_POS_STATUS IS NOT NULL) OR (:new.F_POS_STATUS IS NOT NULL AND :old.F_POS_STATUS IS NULL) ) THEN
    fld_name             := 'T_SYS_OPERATORS.F_POS_STATUS';
    fld_val_old          := GET_DICTIONARY_VALUE('PosStatus', :old.F_POS_STATUS);
    fld_val_new          := GET_DICTIONARY_VALUE('PosStatus', :new.F_POS_STATUS);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- SYS_READONLY
  IF( (:new.SYS_READONLY <> :old.SYS_READONLY) OR (:new.SYS_READONLY IS NULL AND :old.SYS_READONLY IS NOT NULL) OR (:new.SYS_READONLY IS NOT NULL AND :old.SYS_READONLY IS NULL) ) THEN
    fld_name             := 'T_SYS_OPERATORS.SYS_READONLY';
    fld_val_old          := TRUNCATE_STRING(:old.SYS_READONLY, 510);
    fld_val_new          := TRUNCATE_STRING(:new.SYS_READONLY, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- SYS_TEMPORARY_PASSWORD
  IF( (:new.SYS_TEMPORARY_PASSWORD <> :old.SYS_TEMPORARY_PASSWORD) OR (:new.SYS_TEMPORARY_PASSWORD IS NULL AND :old.SYS_TEMPORARY_PASSWORD IS NOT NULL) OR (:new.SYS_TEMPORARY_PASSWORD IS NOT NULL AND :old.SYS_TEMPORARY_PASSWORD IS NULL) ) THEN
    fld_name                       := 'T_SYS_OPERATORS.SYS_TEMPORARY_PASSWORD';
    fld_val_old                    := TRUNCATE_STRING(:old.SYS_TEMPORARY_PASSWORD, 510);
    fld_val_new                    := TRUNCATE_STRING(:new.SYS_TEMPORARY_PASSWORD, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- SYS_ACCOUNT_BLOCKED
  IF( (:new.SYS_ACCOUNT_BLOCKED <> :old.SYS_ACCOUNT_BLOCKED) OR (:new.SYS_ACCOUNT_BLOCKED IS NULL AND :old.SYS_ACCOUNT_BLOCKED IS NOT NULL) OR (:new.SYS_ACCOUNT_BLOCKED IS NOT NULL AND :old.SYS_ACCOUNT_BLOCKED IS NULL) ) THEN
    fld_name                    := 'T_SYS_OPERATORS.SYS_ACCOUNT_BLOCKED';
    fld_val_old                 := TRUNCATE_STRING(:old.SYS_ACCOUNT_BLOCKED, 510);
    fld_val_new                 := TRUNCATE_STRING(:new.SYS_ACCOUNT_BLOCKED, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_OPERATORS_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_OPERATORS_ADMITT"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"   VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_OPERATOR"    VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_ADMITT_CODE" VARCHAR2(20 BYTE) NOT NULL ENABLE,
    CONSTRAINT "PK_SYS_OPERATORS_ADMITT" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_OPERATORS_ADMITT_USER" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_OPERATORS_ADMITT_OPER" FOREIGN KEY ("F_OPERATOR") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_OPERATORS_ADMITT"."F_OPERATOR"
IS
  '?????? ?? ?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_OPERATORS_ADMITT"."F_ADMITT_CODE"
IS
  '??? ???????';
CREATE OR REPLACE TRIGGER "EKC15"."TR_OPERATORS_ADMITT_UPDATE" BEFORE
  UPDATE ON T_SYS_OPERATORS_ADMITT REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                      VARCHAR2(512);
  fld_val_new                                                                                      VARCHAR2(512);
  table_code                                                                                       VARCHAR2(40);
BEGIN
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    table_code       := 'T_SYS_OPERATORS';
    fld_name         := 'T_SYS_OPERATORS.ADMITT_DELETED';
    fld_val_old      := GET_DICTIONARY_VALUE('Admittance', :old.F_ADMITT_CODE);
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.F_OPERATOR, fld_name, fld_val_old, fld_val_new);
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_OPERATORS_ADMITT_UPDATE" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_OPERATORS_ADMITT_DELETE" BEFORE
  DELETE ON T_SYS_OPERATORS_ADMITT REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                      VARCHAR2(512);
  fld_val_new                                                                                      VARCHAR2(512);
  table_code                                                                                       VARCHAR2(40);
  BEGIN
    table_code  := 'T_SYS_OPERATORS';
    fld_name    := 'T_SYS_OPERATORS.ADMITT_DELETED';
    fld_val_old := GET_DICTIONARY_VALUE('Admittance', :old.F_ADMITT_CODE);
    fld_val_new := '';
    P_AUDIT_POPULATE(:old.SYS_USER_ID, table_code, :old.F_OPERATOR, fld_name, fld_val_old, fld_val_new);
  END;
  /
  ALTER TRIGGER "EKC15"."TR_OPERATORS_ADMITT_DELETE" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_OPERATORS_ADMITT_INSERT" BEFORE
  INSERT ON T_SYS_OPERATORS_ADMITT REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2
    (
      80
    );
  fld_val_old VARCHAR2
  (
    512
  )
  ;
  fld_val_new VARCHAR2
  (
    512
  )
  ;
  table_code VARCHAR2
  (
    40
  )
  ;
  BEGIN
    table_code  := 'T_SYS_OPERATORS';
    fld_name    := 'T_SYS_OPERATORS.ADMITT_ADDED';
    fld_val_old := '';
    fld_val_new := GET_DICTIONARY_VALUE
    (
      'Admittance', :new.F_ADMITT_CODE
    )
    ;
    P_AUDIT_POPULATE
    (
      :new.SYS_USER_ID, table_code, :new.F_OPERATOR, fld_name, fld_val_old, fld_val_new
    )
    ;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_OPERATORS_ADMITT_INSERT" ENABLE;



CREATE TABLE "EKC15"."T_SYS_PERSON"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_FIRST_NAME" VARCHAR2(50 BYTE),
    "F_MID_NAME"   VARCHAR2(50 BYTE),
    "F_LAST_NAME"  VARCHAR2(50 BYTE),
    "F_BIRTH_YEAR" VARCHAR2(4 BYTE),
    "F_BIRTH_DATE" DATE,
    "F_BIRTH_PLACE" VARCHAR2(100 BYTE),
    "F_TOHN"        VARCHAR2(10 BYTE),
    "F_BIN"         VARCHAR2(20 BYTE),
    "F_BIN_DATE" DATE,
    "F_COMMENT"      VARCHAR2(255 BYTE),
    "F_IS_CORPSE"    VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_CNT"          VARCHAR2(1 BYTE),
    "F_OLDKEY"       VARCHAR2(20 BYTE),
    "F_CORPSE_PLACE" VARCHAR2(255 BYTE),
    "F_NUM_DELA"     VARCHAR2(10 BYTE),
    "F_DATA_DELA" DATE,
    "F_DACTIL_EKC" VARCHAR2(20 BYTE),
    "F_DACTIL_DATE" DATE,
    "F_DACTIL_WHO" VARCHAR2(64 BYTE),
    "F_KUSP"       VARCHAR2(16 BYTE),
    "F_KUSP_DATE" DATE,
    "F_FIND_DATE" DATE,
    "F_MVD" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    CONSTRAINT "PK_PERSON" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 23068672 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_PERSON_DEL" CHECK (SYS_DELETED    IN ('N','Y') ) ENABLE,
    CONSTRAINT "CK_PERSON_CORPSE" CHECK (F_IS_CORPSE IN ('N', 'Y') ) ENABLE,
    CONSTRAINT "FK_PERSON_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 25165824 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_TOHN"
IS
  '???????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_BIN"
IS
  '???????????, ??????? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_BIN_DATE"
IS
  '???? ???????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_IS_CORPSE"
IS
  '???????? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_CNT"
IS
  '??????????, ??? ?????????? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_OLDKEY"
IS
  '?????? ???? ????????? ??? ????????????? ? ??? ???????? ??????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_NUM_DELA"
IS
  '????? ??????????? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_DATA_DELA"
IS
  '????? ?????????? ???? (??? ?????)';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_DACTIL_EKC"
IS
  '???? ?????????? ???? (??? ?????)';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_DACTIL_DATE"
IS
  '????? ??????????????????? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON"."F_DACTIL_WHO"
IS
  '???? ??????????????????? ?????';
CREATE UNIQUE INDEX "EKC15"."PK_PERSON" ON "EKC15"."T_SYS_PERSON"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 23068672 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_PERSON_OLDKEY" ON "EKC15"."T_SYS_PERSON"
    (
      "F_OLDKEY"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_CORPSE" ON "EKC15"."T_SYS_PERSON"
    (
      "F_IS_CORPSE"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_PERSON_UPDATED" ON "EKC15"."T_SYS_PERSON"
    (
      "SYS_UPDATED" DESC,
      "SYS_ID"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_PERSON_UPDATE" BEFORE
  UPDATE ON T_SYS_PERSON REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                            VARCHAR2(512);
  fld_val_new                                                                            VARCHAR2(512);
  table_code                                                                             VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_PERSON';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_FIRST_NAME
  IF( (:new.F_FIRST_NAME <> :old.F_FIRST_NAME) OR (:new.F_FIRST_NAME IS NULL AND :old.F_FIRST_NAME IS NOT NULL) OR (:new.F_FIRST_NAME IS NOT NULL AND :old.F_FIRST_NAME IS NULL) ) THEN
    fld_name             := 'T_SYS_PERSON.F_FIRST_NAME';
    fld_val_old          := TRUNCATE_STRING(:old.F_FIRST_NAME, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_FIRST_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_MID_NAME
  IF( (:new.F_MID_NAME <> :old.F_MID_NAME) OR (:new.F_MID_NAME IS NULL AND :old.F_MID_NAME IS NOT NULL) OR (:new.F_MID_NAME IS NOT NULL AND :old.F_MID_NAME IS NULL) ) THEN
    fld_name           := 'T_SYS_PERSON.F_MID_NAME';
    fld_val_old        := TRUNCATE_STRING(:old.F_MID_NAME, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_MID_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_LAST_NAME
  IF( (:new.F_LAST_NAME <> :old.F_LAST_NAME) OR (:new.F_LAST_NAME IS NULL AND :old.F_LAST_NAME IS NOT NULL) OR (:new.F_LAST_NAME IS NOT NULL AND :old.F_LAST_NAME IS NULL) ) THEN
    fld_name            := 'T_SYS_PERSON.F_LAST_NAME';
    fld_val_old         := TRUNCATE_STRING(:old.F_LAST_NAME, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_LAST_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_BIRTH_YEAR
  IF( (:new.F_BIRTH_YEAR <> :old.F_BIRTH_YEAR) OR (:new.F_BIRTH_YEAR IS NULL AND :old.F_BIRTH_YEAR IS NOT NULL) OR (:new.F_BIRTH_YEAR IS NOT NULL AND :old.F_BIRTH_YEAR IS NULL) ) THEN
    fld_name             := 'T_SYS_PERSON.F_BIRTH_YEAR';
    fld_val_old          := TRUNCATE_STRING(:old.F_BIRTH_YEAR, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_BIRTH_YEAR, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_BIRTH_DATE
  IF( (:new.F_BIRTH_DATE <> :old.F_BIRTH_DATE) OR (:new.F_BIRTH_DATE IS NULL AND :old.F_BIRTH_DATE IS NOT NULL) OR (:new.F_BIRTH_DATE IS NOT NULL AND :old.F_BIRTH_DATE IS NULL) ) THEN
    fld_name             := 'T_SYS_PERSON.F_BIRTH_DATE';
    fld_val_old          := TO_CHAR(:old.F_BIRTH_DATE, 'DD.MM.YYYY');
    fld_val_new          := TO_CHAR(:new.F_BIRTH_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_BIRTH_PLACE
  IF( (:new.F_BIRTH_PLACE <> :old.F_BIRTH_PLACE) OR (:new.F_BIRTH_PLACE IS NULL AND :old.F_BIRTH_PLACE IS NOT NULL) OR (:new.F_BIRTH_PLACE IS NOT NULL AND :old.F_BIRTH_PLACE IS NULL) ) THEN
    fld_name              := 'T_SYS_PERSON.F_BIRTH_PLACE';
    fld_val_old           := TRUNCATE_STRING(:old.F_BIRTH_PLACE, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_BIRTH_PLACE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_TOHN
  IF( (:new.F_TOHN <> :old.F_TOHN) OR (:new.F_TOHN IS NULL AND :old.F_TOHN IS NOT NULL) OR (:new.F_TOHN IS NOT NULL AND :old.F_TOHN IS NULL) ) THEN
    fld_name       := 'T_SYS_PERSON.F_TOHN';
    fld_val_old    := TRUNCATE_STRING(:old.F_TOHN, 510);
    fld_val_new    := TRUNCATE_STRING(:new.F_TOHN, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_BIN
  IF( (:new.F_BIN <> :old.F_BIN) OR (:new.F_BIN IS NULL AND :old.F_BIN IS NOT NULL) OR (:new.F_BIN IS NOT NULL AND :old.F_BIN IS NULL) ) THEN
    fld_name      := 'T_SYS_PERSON.F_BIN';
    fld_val_old   := TRUNCATE_STRING(:old.F_BIN, 510);
    fld_val_new   := TRUNCATE_STRING(:new.F_BIN, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_BIN_DATE
  IF( (:new.F_BIN_DATE <> :old.F_BIN_DATE) OR (:new.F_BIN_DATE IS NULL AND :old.F_BIN_DATE IS NOT NULL) OR (:new.F_BIN_DATE IS NOT NULL AND :old.F_BIN_DATE IS NULL) ) THEN
    fld_name           := 'T_SYS_PERSON.F_BIN_DATE';
    fld_val_old        := TO_CHAR(:old.F_BIN_DATE, 'DD.MM.YYYY');
    fld_val_new        := TO_CHAR(:new.F_BIN_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COMMENT
  IF( (:new.F_COMMENT <> :old.F_COMMENT) OR (:new.F_COMMENT IS NULL AND :old.F_COMMENT IS NOT NULL) OR (:new.F_COMMENT IS NOT NULL AND :old.F_COMMENT IS NULL) ) THEN
    fld_name          := 'T_SYS_PERSON.F_COMMENT';
    fld_val_old       := TRUNCATE_STRING(:old.F_COMMENT, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_COMMENT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_IS_CORPSE
  IF( (:new.F_IS_CORPSE <> :old.F_IS_CORPSE) OR (:new.F_IS_CORPSE IS NULL AND :old.F_IS_CORPSE IS NOT NULL) OR (:new.F_IS_CORPSE IS NOT NULL AND :old.F_IS_CORPSE IS NULL) ) THEN
    fld_name            := 'T_SYS_PERSON.F_IS_CORPSE';
    fld_val_old         := TRUNCATE_STRING(:old.F_IS_CORPSE, 510);
    fld_val_new         := TRUNCATE_STRING(:new.F_IS_CORPSE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_CNT
  IF( (:new.F_CNT <> :old.F_CNT) OR (:new.F_CNT IS NULL AND :old.F_CNT IS NOT NULL) OR (:new.F_CNT IS NOT NULL AND :old.F_CNT IS NULL) ) THEN
    fld_name      := 'T_SYS_PERSON.F_CNT';
    fld_val_old   := TRUNCATE_STRING(:old.F_CNT, 510);
    fld_val_new   := TRUNCATE_STRING(:new.F_CNT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OLDKEY
  IF( (:new.F_OLDKEY <> :old.F_OLDKEY) OR (:new.F_OLDKEY IS NULL AND :old.F_OLDKEY IS NOT NULL) OR (:new.F_OLDKEY IS NOT NULL AND :old.F_OLDKEY IS NULL) ) THEN
    fld_name         := 'T_SYS_PERSON.F_OLDKEY';
    fld_val_old      := TRUNCATE_STRING(:old.F_OLDKEY, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_OLDKEY, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_CORPSE_PLACE
  IF( (:new.F_CORPSE_PLACE <> :old.F_CORPSE_PLACE) OR (:new.F_CORPSE_PLACE IS NULL AND :old.F_CORPSE_PLACE IS NOT NULL) OR (:new.F_CORPSE_PLACE IS NOT NULL AND :old.F_CORPSE_PLACE IS NULL) ) THEN
    fld_name               := 'T_SYS_PERSON.F_CORPSE_PLACE';
    fld_val_old            := TRUNCATE_STRING(:old.F_CORPSE_PLACE, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_CORPSE_PLACE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_NUM_DELA
  IF( (:new.F_NUM_DELA <> :old.F_NUM_DELA) OR (:new.F_NUM_DELA IS NULL AND :old.F_NUM_DELA IS NOT NULL) OR (:new.F_NUM_DELA IS NOT NULL AND :old.F_NUM_DELA IS NULL) ) THEN
    fld_name           := 'T_SYS_PERSON.F_NUM_DELA';
    fld_val_old        := TRUNCATE_STRING(:old.F_NUM_DELA, 510);
    fld_val_new        := TRUNCATE_STRING(:new.F_NUM_DELA, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DATA_DELA
  IF( (:new.F_DATA_DELA <> :old.F_DATA_DELA) OR (:new.F_DATA_DELA IS NULL AND :old.F_DATA_DELA IS NOT NULL) OR (:new.F_DATA_DELA IS NOT NULL AND :old.F_DATA_DELA IS NULL) ) THEN
    fld_name            := 'T_SYS_PERSON.F_DATA_DELA';
    fld_val_old         := TO_CHAR(:old.F_DATA_DELA, 'DD.MM.YYYY');
    fld_val_new         := TO_CHAR(:new.F_DATA_DELA, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_KUSP
  IF( (:new.F_KUSP <> :old.F_KUSP) OR (:new.F_KUSP IS NULL AND :old.F_KUSP IS NOT NULL) OR (:new.F_KUSP IS NOT NULL AND :old.F_KUSP IS NULL) ) THEN
    fld_name       := 'T_SYS_PERSON.F_KUSP';
    fld_val_old    := TRUNCATE_STRING(:old.F_KUSP, 510);
    fld_val_new    := TRUNCATE_STRING(:new.F_KUSP, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_KUSP_DATE
  IF( (:new.F_KUSP_DATE <> :old.F_KUSP_DATE) OR (:new.F_KUSP_DATE IS NULL AND :old.F_KUSP_DATE IS NOT NULL) OR (:new.F_KUSP_DATE IS NOT NULL AND :old.F_KUSP_DATE IS NULL) ) THEN
    fld_name            := 'T_SYS_PERSON.F_KUSP_DATE';
    fld_val_old         := TO_CHAR(:old.F_KUSP_DATE, 'DD.MM.YYYY');
    fld_val_new         := TO_CHAR(:new.F_KUSP_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_FIND_DATE
  IF( (:new.F_FIND_DATE <> :old.F_FIND_DATE) OR (:new.F_FIND_DATE IS NULL AND :old.F_FIND_DATE IS NOT NULL) OR (:new.F_FIND_DATE IS NOT NULL AND :old.F_FIND_DATE IS NULL) ) THEN
    fld_name            := 'T_SYS_PERSON.F_FIND_DATE';
    fld_val_old         := TO_CHAR(:old.F_FIND_DATE, 'DD.MM.YYYY');
    fld_val_new         := TO_CHAR(:new.F_FIND_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_PERSON_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_PERSON_DACT"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE),
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_PERSON" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_DACT"       VARCHAR2(32 BYTE),
    "F_OLDKEY"     VARCHAR2(20 BYTE),
    "F_COMMENT"    VARCHAR2(256 BYTE),
    "F_DACT_DATE" DATE,
    "F_DACT_PLACE" VARCHAR2(64 BYTE),
    "REV_COUNT"    NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    "DOU_COUNT"    NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    CONSTRAINT "PK_PERSON_DACT" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 6291456 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_PERSON_DACT_PERSON" FOREIGN KEY ("F_REF_PERSON") REFERENCES "EKC15"."T_SYS_PERSON" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PERSON_DACT_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 14680064 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_DACT"."F_REF_PERSON"
IS
  '?????? ?? ????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_DACT"."F_DACT"
IS
  '????? ? ?????????';
CREATE UNIQUE INDEX "EKC15"."PK_PERSON_DACT" ON "EKC15"."T_SYS_PERSON_DACT"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 6291456 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_PERSON_DACT_OLDKEY" ON "EKC15"."T_SYS_PERSON_DACT"
    (
      "F_OLDKEY"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_PERSON_DACT_REF_PERSON" ON "EKC15"."T_SYS_PERSON_DACT"
    (
      "F_REF_PERSON"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_PERSON_DACT_DACTNUM" ON "EKC15"."T_SYS_PERSON_DACT"
    (
      "F_DACT"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_PERSON_DACT_UPDATE" BEFORE
  UPDATE ON T_SYS_PERSON_DACT REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                 VARCHAR2(512);
  fld_val_new                                                                                 VARCHAR2(512);
  table_code                                                                                  VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_PERSON_DACT';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REF_PERSON
  IF( (:new.F_REF_PERSON <> :old.F_REF_PERSON) OR (:new.F_REF_PERSON IS NULL AND :old.F_REF_PERSON IS NOT NULL) OR (:new.F_REF_PERSON IS NOT NULL AND :old.F_REF_PERSON IS NULL) ) THEN
    fld_name             := 'T_SYS_PERSON_DACT.F_REF_PERSON';
    fld_val_old          := TRUNCATE_STRING(:old.F_REF_PERSON, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_REF_PERSON, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DACT
  IF( (:new.F_DACT <> :old.F_DACT) OR (:new.F_DACT IS NULL AND :old.F_DACT IS NOT NULL) OR (:new.F_DACT IS NOT NULL AND :old.F_DACT IS NULL) ) THEN
    fld_name       := 'T_SYS_PERSON_DACT.F_DACT';
    fld_val_old    := TRUNCATE_STRING(:old.F_DACT, 510);
    fld_val_new    := TRUNCATE_STRING(:new.F_DACT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OLDKEY
  IF( (:new.F_OLDKEY <> :old.F_OLDKEY) OR (:new.F_OLDKEY IS NULL AND :old.F_OLDKEY IS NOT NULL) OR (:new.F_OLDKEY IS NOT NULL AND :old.F_OLDKEY IS NULL) ) THEN
    fld_name         := 'T_SYS_PERSON_DACT.F_OLDKEY';
    fld_val_old      := TRUNCATE_STRING(:old.F_OLDKEY, 510);
    fld_val_new      := TRUNCATE_STRING(:new.F_OLDKEY, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COMMENT
  IF( (:new.F_COMMENT <> :old.F_COMMENT) OR (:new.F_COMMENT IS NULL AND :old.F_COMMENT IS NOT NULL) OR (:new.F_COMMENT IS NOT NULL AND :old.F_COMMENT IS NULL) ) THEN
    fld_name          := 'T_SYS_PERSON_DACT.F_COMMENT';
    fld_val_old       := TRUNCATE_STRING(:old.F_COMMENT, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_COMMENT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DACT_DATE
  IF( (:new.F_DACT_DATE <> :old.F_DACT_DATE) OR (:new.F_DACT_DATE IS NULL AND :old.F_DACT_DATE IS NOT NULL) OR (:new.F_DACT_DATE IS NOT NULL AND :old.F_DACT_DATE IS NULL) ) THEN
    fld_name            := 'T_SYS_PERSON_DACT.F_DACT_DATE';
    fld_val_old         := TO_CHAR(:old.F_DACT_DATE, 'DD.MM.YYYY');
    fld_val_new         := TO_CHAR(:new.F_DACT_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DACT_PLACE
  IF( (:new.F_DACT_PLACE <> :old.F_DACT_PLACE) OR (:new.F_DACT_PLACE IS NULL AND :old.F_DACT_PLACE IS NOT NULL) OR (:new.F_DACT_PLACE IS NOT NULL AND :old.F_DACT_PLACE IS NULL) ) THEN
    fld_name             := 'T_SYS_PERSON_DACT.F_DACT_PLACE';
    fld_val_old          := TRUNCATE_STRING(:old.F_DACT_PLACE, 510);
    fld_val_new          := TRUNCATE_STRING(:new.F_DACT_PLACE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_PERSON_DACT_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_PERSON_DACT_IN_FOLDER"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE),
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_DACT"   VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_REF_FOLDER" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_FOLD_N"     NUMBER(9,0),
    "F_DATE" DATE,
    "F_PLACE" VARCHAR2(256 BYTE),
    CONSTRAINT "CK_PERSON_DACT_IN_FOLDER_DEL" CHECK (SYS_DELETED IN ('N','Y') ) ENABLE,
    CONSTRAINT "PK_PERSON_DACT_IN_FOLDER" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_PERSON_DACT_IN_FOLDER_FOLD" FOREIGN KEY ("F_REF_FOLDER") REFERENCES "EKC15"."T_SYS_DACT_FOLDER" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PERSON_DACT_IN_FOLDER_DACT" FOREIGN KEY ("F_REF_DACT") REFERENCES "EKC15"."T_SYS_PERSON_DACT" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_DACT_IN_FOLDER_USER" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_DACT_IN_FOLDER"."F_REF_DACT"
IS
  '?????? ?? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_DACT_IN_FOLDER"."F_REF_FOLDER"
IS
  '?????? ?? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_DACT_IN_FOLDER"."F_FOLD_N"
IS
  '????? ? ?????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_DACT_IN_FOLDER"."F_DATE"
IS
  '???? ???????????????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_DACT_IN_FOLDER"."F_PLACE"
IS
  '????? ???????????????????';
CREATE UNIQUE INDEX "EKC15"."PK_PERSON_DACT_IN_FOLDER" ON "EKC15"."T_SYS_PERSON_DACT_IN_FOLDER"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_REF_DACT" ON "EKC15"."T_SYS_PERSON_DACT_IN_FOLDER"
    (
      "F_REF_DACT"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_REF_FOLDER" ON "EKC15"."T_SYS_PERSON_DACT_IN_FOLDER"
    (
      "F_REF_FOLDER"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;



CREATE TABLE "EKC15"."T_SYS_PERSON_PHOTO"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_PERSON" VARCHAR2(32 BYTE),
    "F_TYPE"       VARCHAR2(32 BYTE),
    "F_REG_AREA"   VARCHAR2(64 BYTE),
    "F_REG_DATE" DATE DEFAULT SYSDATE,
    "F_CATEGORY" VARCHAR2(128 BYTE),
    "F_MALE"     VARCHAR2(1 BYTE),
    "F_REG_CB_DATE" DATE,
    "F_ARCHIVED"       VARCHAR2(1 BYTE),
    "F_REG_NUMBER"     VARCHAR2(16 BYTE),
    "F_NONE_PERSON"    VARCHAR2(1 BYTE),
    "F_REG_DEPARTMENT" VARCHAR2(20 BYTE),
    "REV_COUNT"        NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    "DOU_COUNT"        NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    CONSTRAINT "PK_SYS_PERSON_PHOTO" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_PERSON_PHOTO_USER" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PERSON_PHOTO_PERSON" FOREIGN KEY ("F_REF_PERSON") REFERENCES "EKC15"."T_SYS_PERSON" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_PERSON_PHOTO_UPDATE" BEFORE
  UPDATE ON T_SYS_PERSON_PHOTO REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                  VARCHAR2(512);
  fld_val_new                                                                                  VARCHAR2(512);
  table_code                                                                                   VARCHAR2(40);
  BEGIN
    table_code := 'T_SYS_PERSON_PHOTO';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_TYPE
    IF( (:new.F_TYPE <> :old.F_TYPE) OR (:new.F_TYPE IS NULL AND :old.F_TYPE IS NOT NULL) OR (:new.F_TYPE IS NOT NULL AND :old.F_TYPE IS NULL) ) THEN
      fld_name       := 'T_SYS_PERSON_PHOTO.F_TYPE';
      fld_val_old    := TRUNCATE_STRING(:old.F_TYPE, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_TYPE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REG_AREA
    IF( (:new.F_REG_AREA <> :old.F_REG_AREA) OR (:new.F_REG_AREA IS NULL AND :old.F_REG_AREA IS NOT NULL) OR (:new.F_REG_AREA IS NOT NULL AND :old.F_REG_AREA IS NULL) ) THEN
      fld_name           := 'T_SYS_PERSON_PHOTO.F_REG_AREA';
      fld_val_old        := TRUNCATE_STRING(:old.F_REG_AREA, 510);
      fld_val_new        := TRUNCATE_STRING(:new.F_REG_AREA, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REG_DATE
    IF( (:new.F_REG_DATE <> :old.F_REG_DATE) OR (:new.F_REG_DATE IS NULL AND :old.F_REG_DATE IS NOT NULL) OR (:new.F_REG_DATE IS NOT NULL AND :old.F_REG_DATE IS NULL) ) THEN
      fld_name           := 'T_SYS_PERSON_PHOTO.F_REG_DATE';
      fld_val_old        := TO_CHAR(:old.F_REG_DATE, 'DD.MM.YYYY');
      fld_val_new        := TO_CHAR(:new.F_REG_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_MALE
    IF( (:new.F_MALE <> :old.F_MALE) OR (:new.F_MALE IS NULL AND :old.F_MALE IS NOT NULL) OR (:new.F_MALE IS NOT NULL AND :old.F_MALE IS NULL) ) THEN
      fld_name       := 'T_SYS_PERSON_PHOTO.F_MALE';
      fld_val_old    := TRUNCATE_STRING(:old.F_MALE, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_MALE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REG_CB_DATE
    IF( (:new.F_REG_CB_DATE <> :old.F_REG_CB_DATE) OR (:new.F_REG_CB_DATE IS NULL AND :old.F_REG_CB_DATE IS NOT NULL) OR (:new.F_REG_CB_DATE IS NOT NULL AND :old.F_REG_CB_DATE IS NULL) ) THEN
      fld_name              := 'T_SYS_PERSON_PHOTO.F_REG_CB_DATE';
      fld_val_old           := TO_CHAR(:old.F_REG_CB_DATE, 'DD.MM.YYYY');
      fld_val_new           := TO_CHAR(:new.F_REG_CB_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_PERSON_PHOTO_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_PERSON_SAMPLE"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE),
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"   VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_PERSON"  VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_REF_FOLDER"  VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_SAMPLE_NAME" VARCHAR2(32 BYTE),
    "F_COMMENT"     VARCHAR2(256 BYTE),
    "F_SAMPLE_DATE" DATE,
    "F_SAMPLE_PLACE" VARCHAR2(64 BYTE),
    "REV_COUNT"      NUMBER(5,0) DEFAULT 0 NOT NULL ENABLE,
    CONSTRAINT "PK_PERSON_SAMPLE" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 6291456 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "USERS" ENABLE,
    CONSTRAINT "FK_PERSON_SAMPLE_USER" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PERSON_SAMPLE_PERSON" FOREIGN KEY ("F_REF_PERSON") REFERENCES "EKC15"."T_SYS_PERSON" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PERSON_SAMPLE_FOLDER" FOREIGN KEY ("F_REF_FOLDER") REFERENCES "EKC15"."T_SYS_SAMPLE_FOLDER" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 14680064 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "USERS" ;
COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_SAMPLE"."F_REF_PERSON"
IS
  '  ';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_SAMPLE"."F_REF_FOLDER"
IS
  '  ';
  COMMENT ON COLUMN "EKC15"."T_SYS_PERSON_SAMPLE"."F_SAMPLE_NAME"
IS
  ' ';
  CREATE INDEX "EKC15"."IE_PERSON_SAMPLE_REF_FOLDER" ON "EKC15"."T_SYS_PERSON_SAMPLE"
    (
      "F_REF_FOLDER"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "USERS" ;
CREATE UNIQUE INDEX "EKC15"."PK_PERSON_SAMPLE" ON "EKC15"."T_SYS_PERSON_SAMPLE"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 6291456 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "USERS" ;
  CREATE INDEX "EKC15"."IE_PERSON_SAMPLE_SAMPLENUM" ON "EKC15"."T_SYS_PERSON_SAMPLE"
    (
      "F_SAMPLE_NAME"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "USERS" ;
  CREATE INDEX "EKC15"."IE_PERSON_SAMPLE_REF_PERSON" ON "EKC15"."T_SYS_PERSON_SAMPLE"
    (
      "F_REF_PERSON"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "USERS" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_PERSON_SAMPLE_UPDATE" BEFORE
  UPDATE ON T_SYS_PERSON_SAMPLE REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                   VARCHAR2(512);
  fld_val_new                                                                                   VARCHAR2(512);
  table_code                                                                                    VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_PERSON_SAMPLE';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SAMPLE_NAME
  IF( (:new.F_SAMPLE_NAME <> :old.F_SAMPLE_NAME) OR (:new.F_SAMPLE_NAME IS NULL AND :old.F_SAMPLE_NAME IS NOT NULL) OR (:new.F_SAMPLE_NAME IS NOT NULL AND :old.F_SAMPLE_NAME IS NULL) ) THEN
    fld_name              := 'T_SYS_PERSON_SAMPLE.F_SAMPLE_NAME';
    fld_val_old           := TRUNCATE_STRING(:old.F_SAMPLE_NAME, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_SAMPLE_NAME, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COMMENT
  IF( (:new.F_COMMENT <> :old.F_COMMENT) OR (:new.F_COMMENT IS NULL AND :old.F_COMMENT IS NOT NULL) OR (:new.F_COMMENT IS NOT NULL AND :old.F_COMMENT IS NULL) ) THEN
    fld_name          := 'T_SYS_PERSON_SAMPLE.F_COMMENT';
    fld_val_old       := TRUNCATE_STRING(:old.F_COMMENT, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_COMMENT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SAMPLE_DATE
  IF( (:new.F_SAMPLE_DATE <> :old.F_SAMPLE_DATE) OR (:new.F_SAMPLE_DATE IS NULL AND :old.F_SAMPLE_DATE IS NOT NULL) OR (:new.F_SAMPLE_DATE IS NOT NULL AND :old.F_SAMPLE_DATE IS NULL) ) THEN
    fld_name              := 'T_SYS_PERSON_SAMPLE.F_SAMPLE_DATE';
    fld_val_old           := TO_CHAR(:old.F_SAMPLE_DATE, 'DD.MM.YYYY');
    fld_val_new           := TO_CHAR(:new.F_SAMPLE_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_SAMPLE_PLACE
  IF( (:new.F_SAMPLE_PLACE <> :old.F_SAMPLE_PLACE) OR (:new.F_SAMPLE_PLACE IS NULL AND :old.F_SAMPLE_PLACE IS NOT NULL) OR (:new.F_SAMPLE_PLACE IS NOT NULL AND :old.F_SAMPLE_PLACE IS NULL) ) THEN
    fld_name               := 'T_SYS_PERSON_SAMPLE.F_SAMPLE_PLACE';
    fld_val_old            := TRUNCATE_STRING(:old.F_SAMPLE_PLACE, 510);
    fld_val_new            := TRUNCATE_STRING(:new.F_SAMPLE_PLACE, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_PERSON_SAMPLE_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_PERSON_TED"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"   VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_OLDKEY"      VARCHAR2(16 BYTE),
    "F_SOURCE_CODE" VARCHAR2(16 BYTE),
    "F_EKC"         VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_AREA"        VARCHAR2(20 BYTE),
    "F_REF_PERSON"  VARCHAR2(32 BYTE),
    "F_IS_MONEY"    VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_CATEGORY"    VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_NAME"        VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_COUNTRY"     VARCHAR2(20 BYTE),
    "F_NOMINAL"     VARCHAR2(20 BYTE),
    "F_SERIAL_NUM"  VARCHAR2(20 BYTE),
    "F_SERIAL"      VARCHAR2(16 BYTE),
    "F_NUMBER"      VARCHAR2(16 BYTE),
    "F_YEAR_SER"    VARCHAR2(16 BYTE),
    "F_YEAR_MOD"    VARCHAR2(16 BYTE),
    "F_BANK"        VARCHAR2(20 BYTE),
    "F_CONTROL"     VARCHAR2(4 BYTE),
    "F_CLISHE"      VARCHAR2(16 BYTE),
    "F_SIZE"        NUMBER(8,0),
    "F_METHOD"      VARCHAR2(20 BYTE),
    "F_INTERPOL"    VARCHAR2(16 BYTE),
    "F_REC_DATE" DATE,
    "F_EXP_DATE" DATE,
    "F_EXP_NUMBER"   VARCHAR2(16 BYTE),
    "F_EXPERT"       VARCHAR2(32 BYTE),
    "F_N_DELA"       VARCHAR2(20 BYTE),
    "F_REF_EXPERTZ"  VARCHAR2(32 BYTE),
    "F_REF_EVIDENCE" VARCHAR2(32 BYTE),
    "F_N_KUSP"       VARCHAR2(20 BYTE),
    "F_DATE_KUSP" DATE,
    CONSTRAINT "PK_SYS_PERSON_TED" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_PERSON_TED_USER" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PERSON_TED_PERSON" FOREIGN KEY ("F_REF_PERSON") REFERENCES "EKC15"."T_SYS_PERSON" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PERSON_TED_EXPERTZ" FOREIGN KEY ("F_REF_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PERSON_TED_EVIDENCE" FOREIGN KEY ("F_REF_EVIDENCE") REFERENCES "EKC15"."T_SYS_EVIDENCE" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_PERSON_TED_UPDATE" BEFORE
  UPDATE ON T_SYS_PERSON_TED REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                VARCHAR2(512);
  fld_val_new                                                                                VARCHAR2(512);
  table_code                                                                                 VARCHAR2(40);
  BEGIN
    table_code := 'T_SYS_PERSON_TED';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_OLDKEY
    IF( (:new.F_OLDKEY <> :old.F_OLDKEY) OR (:new.F_OLDKEY IS NULL AND :old.F_OLDKEY IS NOT NULL) OR (:new.F_OLDKEY IS NOT NULL AND :old.F_OLDKEY IS NULL) ) THEN
      fld_name         := 'T_SYS_PERSON_TED.F_OLDKEY';
      fld_val_old      := TRUNCATE_STRING(:old.F_OLDKEY, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_OLDKEY, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_SOURCE_CODE
    IF( (:new.F_SOURCE_CODE <> :old.F_SOURCE_CODE) OR (:new.F_SOURCE_CODE IS NULL AND :old.F_SOURCE_CODE IS NOT NULL) OR (:new.F_SOURCE_CODE IS NOT NULL AND :old.F_SOURCE_CODE IS NULL) ) THEN
      fld_name              := 'T_SYS_PERSON_TED.F_SOURCE_CODE';
      fld_val_old           := GET_DICTIONARY_VALUE('SourceCodes', :old.F_SOURCE_CODE);
      fld_val_new           := GET_DICTIONARY_VALUE('SourceCodes', :new.F_SOURCE_CODE);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_AREA
    IF( (:new.F_AREA <> :old.F_AREA) OR (:new.F_AREA IS NULL AND :old.F_AREA IS NOT NULL) OR (:new.F_AREA IS NOT NULL AND :old.F_AREA IS NULL) ) THEN
      fld_name       := 'T_SYS_PERSON_TED.F_AREA';
      fld_val_old    := GET_DICTIONARY_VALUE('Area', :old.F_AREA);
      fld_val_new    := GET_DICTIONARY_VALUE('Area', :new.F_AREA);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_IS_MONEY
    IF( (:new.F_IS_MONEY <> :old.F_IS_MONEY) OR (:new.F_IS_MONEY IS NULL AND :old.F_IS_MONEY IS NOT NULL) OR (:new.F_IS_MONEY IS NOT NULL AND :old.F_IS_MONEY IS NULL) ) THEN
      fld_name           := 'T_SYS_PERSON_TED.F_IS_MONEY';
      fld_val_old        := TRUNCATE_STRING(:old.F_IS_MONEY, 510);
      fld_val_new        := TRUNCATE_STRING(:new.F_IS_MONEY, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_CATEGORY
    IF( (:new.F_CATEGORY <> :old.F_CATEGORY) OR (:new.F_CATEGORY IS NULL AND :old.F_CATEGORY IS NOT NULL) OR (:new.F_CATEGORY IS NOT NULL AND :old.F_CATEGORY IS NULL) ) THEN
      fld_name           := 'T_SYS_PERSON_TED.F_CATEGORY';
      fld_val_old        := GET_DICTIONARY_VALUE('Documents', :old.F_CATEGORY);
      fld_val_new        := GET_DICTIONARY_VALUE('Documents', :new.F_CATEGORY);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_NAME
    IF( (:new.F_NAME <> :old.F_NAME) OR (:new.F_NAME IS NULL AND :old.F_NAME IS NOT NULL) OR (:new.F_NAME IS NOT NULL AND :old.F_NAME IS NULL) ) THEN
      fld_name       := 'T_SYS_PERSON_TED.F_NAME';
      fld_val_old    := GET_DICTIONARY_VALUE('PrecisedDocuments', :old.F_NAME);
      fld_val_new    := GET_DICTIONARY_VALUE('PrecisedDocuments', :new.F_NAME);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_COUNTRY
    IF( (:new.F_COUNTRY <> :old.F_COUNTRY) OR (:new.F_COUNTRY IS NULL AND :old.F_COUNTRY IS NOT NULL) OR (:new.F_COUNTRY IS NOT NULL AND :old.F_COUNTRY IS NULL) ) THEN
      fld_name          := 'T_SYS_PERSON_TED.F_COUNTRY';
      fld_val_old       := GET_DICTIONARY_VALUE('Countries', :old.F_COUNTRY);
      fld_val_new       := GET_DICTIONARY_VALUE('Countries', :new.F_COUNTRY);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_NOMINAL
    IF( (:new.F_NOMINAL <> :old.F_NOMINAL) OR (:new.F_NOMINAL IS NULL AND :old.F_NOMINAL IS NOT NULL) OR (:new.F_NOMINAL IS NOT NULL AND :old.F_NOMINAL IS NULL) ) THEN
      fld_name          := 'T_SYS_PERSON_TED.F_NOMINAL';
      fld_val_old       := TRUNCATE_STRING(:old.F_NOMINAL, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_NOMINAL, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_SERIAL_NUM
    IF( (:new.F_SERIAL_NUM <> :old.F_SERIAL_NUM) OR (:new.F_SERIAL_NUM IS NULL AND :old.F_SERIAL_NUM IS NOT NULL) OR (:new.F_SERIAL_NUM IS NOT NULL AND :old.F_SERIAL_NUM IS NULL) ) THEN
      fld_name             := 'T_SYS_PERSON_TED.F_SERIAL_NUM';
      fld_val_old          := TRUNCATE_STRING(:old.F_SERIAL_NUM, 510);
      fld_val_new          := TRUNCATE_STRING(:new.F_SERIAL_NUM, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_SERIAL
    IF( (:new.F_SERIAL <> :old.F_SERIAL) OR (:new.F_SERIAL IS NULL AND :old.F_SERIAL IS NOT NULL) OR (:new.F_SERIAL IS NOT NULL AND :old.F_SERIAL IS NULL) ) THEN
      fld_name         := 'T_SYS_PERSON_TED.F_SERIAL';
      fld_val_old      := TRUNCATE_STRING(:old.F_SERIAL, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_SERIAL, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_NUMBER
    IF( (:new.F_NUMBER <> :old.F_NUMBER) OR (:new.F_NUMBER IS NULL AND :old.F_NUMBER IS NOT NULL) OR (:new.F_NUMBER IS NOT NULL AND :old.F_NUMBER IS NULL) ) THEN
      fld_name         := 'T_SYS_PERSON_TED.F_NUMBER';
      fld_val_old      := TRUNCATE_STRING(:old.F_NUMBER, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_NUMBER, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_YEAR_SER
    IF( (:new.F_YEAR_SER <> :old.F_YEAR_SER) OR (:new.F_YEAR_SER IS NULL AND :old.F_YEAR_SER IS NOT NULL) OR (:new.F_YEAR_SER IS NOT NULL AND :old.F_YEAR_SER IS NULL) ) THEN
      fld_name           := 'T_SYS_PERSON_TED.F_YEAR_SER';
      fld_val_old        := TRUNCATE_STRING(:old.F_YEAR_SER, 510);
      fld_val_new        := TRUNCATE_STRING(:new.F_YEAR_SER, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_YEAR_MOD
    IF( (:new.F_YEAR_MOD <> :old.F_YEAR_MOD) OR (:new.F_YEAR_MOD IS NULL AND :old.F_YEAR_MOD IS NOT NULL) OR (:new.F_YEAR_MOD IS NOT NULL AND :old.F_YEAR_MOD IS NULL) ) THEN
      fld_name           := 'T_SYS_PERSON_TED.F_YEAR_MOD';
      fld_val_old        := TRUNCATE_STRING(:old.F_YEAR_MOD, 510);
      fld_val_new        := TRUNCATE_STRING(:new.F_YEAR_MOD, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_BANK
    IF( (:new.F_BANK <> :old.F_BANK) OR (:new.F_BANK IS NULL AND :old.F_BANK IS NOT NULL) OR (:new.F_BANK IS NOT NULL AND :old.F_BANK IS NULL) ) THEN
      fld_name       := 'T_SYS_PERSON_TED.F_BANK';
      fld_val_old    := TRUNCATE_STRING(:old.F_BANK, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_BANK, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_CONTROL
    IF( (:new.F_CONTROL <> :old.F_CONTROL) OR (:new.F_CONTROL IS NULL AND :old.F_CONTROL IS NOT NULL) OR (:new.F_CONTROL IS NOT NULL AND :old.F_CONTROL IS NULL) ) THEN
      fld_name          := 'T_SYS_PERSON_TED.F_CONTROL';
      fld_val_old       := TRUNCATE_STRING(:old.F_CONTROL, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_CONTROL, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_CLISHE
    IF( (:new.F_CLISHE <> :old.F_CLISHE) OR (:new.F_CLISHE IS NULL AND :old.F_CLISHE IS NOT NULL) OR (:new.F_CLISHE IS NOT NULL AND :old.F_CLISHE IS NULL) ) THEN
      fld_name         := 'T_SYS_PERSON_TED.F_CLISHE';
      fld_val_old      := TRUNCATE_STRING(:old.F_CLISHE, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_CLISHE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_SIZE
    IF( (:new.F_SIZE <> :old.F_SIZE) OR (:new.F_SIZE IS NULL AND :old.F_SIZE IS NOT NULL) OR (:new.F_SIZE IS NOT NULL AND :old.F_SIZE IS NULL) ) THEN
      fld_name       := 'T_SYS_PERSON_TED.F_SIZE';
      fld_val_old    := TRUNCATE_STRING(:old.F_SIZE, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_SIZE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_METHOD
    IF( (:new.F_METHOD <> :old.F_METHOD) OR (:new.F_METHOD IS NULL AND :old.F_METHOD IS NOT NULL) OR (:new.F_METHOD IS NOT NULL AND :old.F_METHOD IS NULL) ) THEN
      fld_name         := 'T_SYS_PERSON_TED.F_METHOD';
      fld_val_old      := GET_DICTIONARY_VALUE('ResumeTED', :old.F_METHOD);
      fld_val_new      := GET_DICTIONARY_VALUE('ResumeTED', :new.F_METHOD);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_INTERPOL
    IF( (:new.F_INTERPOL <> :old.F_INTERPOL) OR (:new.F_INTERPOL IS NULL AND :old.F_INTERPOL IS NOT NULL) OR (:new.F_INTERPOL IS NOT NULL AND :old.F_INTERPOL IS NULL) ) THEN
      fld_name           := 'T_SYS_PERSON_TED.F_INTERPOL';
      fld_val_old        := TRUNCATE_STRING(:old.F_INTERPOL, 510);
      fld_val_new        := TRUNCATE_STRING(:new.F_INTERPOL, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REC_DATE
    IF( (:new.F_REC_DATE <> :old.F_REC_DATE) OR (:new.F_REC_DATE IS NULL AND :old.F_REC_DATE IS NOT NULL) OR (:new.F_REC_DATE IS NOT NULL AND :old.F_REC_DATE IS NULL) ) THEN
      fld_name           := 'T_SYS_PERSON_TED.F_REC_DATE';
      fld_val_old        := TO_CHAR(:old.F_REC_DATE, 'DD.MM.YYYY');
      fld_val_new        := TO_CHAR(:new.F_REC_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_EXP_DATE
    IF( (:new.F_EXP_DATE <> :old.F_EXP_DATE) OR (:new.F_EXP_DATE IS NULL AND :old.F_EXP_DATE IS NOT NULL) OR (:new.F_EXP_DATE IS NOT NULL AND :old.F_EXP_DATE IS NULL) ) THEN
      fld_name           := 'T_SYS_PERSON_TED.F_EXP_DATE';
      fld_val_old        := TO_CHAR(:old.F_EXP_DATE, 'DD.MM.YYYY');
      fld_val_new        := TO_CHAR(:new.F_EXP_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_EXP_NUMBER
    IF( (:new.F_EXP_NUMBER <> :old.F_EXP_NUMBER) OR (:new.F_EXP_NUMBER IS NULL AND :old.F_EXP_NUMBER IS NOT NULL) OR (:new.F_EXP_NUMBER IS NOT NULL AND :old.F_EXP_NUMBER IS NULL) ) THEN
      fld_name             := 'T_SYS_PERSON_TED.F_EXP_NUMBER';
      fld_val_old          := TRUNCATE_STRING(:old.F_EXP_NUMBER, 510);
      fld_val_new          := TRUNCATE_STRING(:new.F_EXP_NUMBER, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_EXPERT
    IF( (:new.F_EXPERT <> :old.F_EXPERT) OR (:new.F_EXPERT IS NULL AND :old.F_EXPERT IS NOT NULL) OR (:new.F_EXPERT IS NOT NULL AND :old.F_EXPERT IS NULL) ) THEN
      fld_name         := 'T_SYS_PERSON_TED.F_EXPERT';
      fld_val_old      := TRUNCATE_STRING(:old.F_EXPERT, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_EXPERT, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_N_DELA
    IF( (:new.F_N_DELA <> :old.F_N_DELA) OR (:new.F_N_DELA IS NULL AND :old.F_N_DELA IS NOT NULL) OR (:new.F_N_DELA IS NOT NULL AND :old.F_N_DELA IS NULL) ) THEN
      fld_name         := 'T_SYS_PERSON_TED.F_N_DELA';
      fld_val_old      := TRUNCATE_STRING(:old.F_N_DELA, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_N_DELA, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_N_KUSP
    IF( (:new.F_N_KUSP <> :old.F_N_KUSP) OR (:new.F_N_KUSP IS NULL AND :old.F_N_KUSP IS NOT NULL) OR (:new.F_N_KUSP IS NOT NULL AND :old.F_N_KUSP IS NULL) ) THEN
      fld_name         := 'T_SYS_PERSON_TED.F_N_KUSP';
      fld_val_old      := TRUNCATE_STRING(:old.F_N_KUSP, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_N_KUSP, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_DATE_KUSP
    IF( (:new.F_DATE_KUSP <> :old.F_DATE_KUSP) OR (:new.F_DATE_KUSP IS NULL AND :old.F_DATE_KUSP IS NOT NULL) OR (:new.F_DATE_KUSP IS NOT NULL AND :old.F_DATE_KUSP IS NULL) ) THEN
      fld_name            := 'T_SYS_PERSON_TED.F_DATE_KUSP';
      fld_val_old         := TO_CHAR(:old.F_DATE_KUSP, 'DD.MM.YYYY');
      fld_val_new         := TO_CHAR(:new.F_DATE_KUSP, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_PERSON_TED_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_PHOTO_AND_CP_IN_FOLDER"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_FOLDER" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_REF_PHOTO"  VARCHAR2(32 BYTE),
    "F_REF_CP"     VARCHAR2(32 BYTE),
    CONSTRAINT "PK_SYS_PHOTO_CP_FOLDER" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_PHOTOCP_FOLDER_USER" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PHOTOCP_FOLDER_FOLDER" FOREIGN KEY ("F_REF_FOLDER") REFERENCES "EKC15"."T_SYS_PHOTO_FOLDER" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PHOTOCP_FOLDER_PHOTO" FOREIGN KEY ("F_REF_PHOTO") REFERENCES "EKC15"."T_SYS_PERSON_PHOTO" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PHOTOCP_FOLDER_CP" FOREIGN KEY ("F_REF_CP") REFERENCES "EKC15"."T_SYS_INFO_CARD_CP" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_PHOTO_FOLDER"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_RECEIVE_DATE" DATE,
    "F_REGION"     VARCHAR2(20 BYTE),
    "F_DEPART"     VARCHAR2(20 BYTE),
    "F_INIT_NAME"  VARCHAR2(50 BYTE),
    "F_INIT_PHONE" VARCHAR2(20 BYTE),
    "F_EXEC_NAME"  VARCHAR2(50 BYTE),
    "F_EXEC_PHONE" VARCHAR2(20 BYTE),
    "F_COMMENT"    VARCHAR2(255 BYTE),
    "F_OUT_NUM"    VARCHAR2(32 BYTE),
    "F_OUT_DATE" DATE,
    "F_CHECK_NUM" VARCHAR2(32 BYTE),
    "F_IN_NUM"    VARCHAR2(32 BYTE),
    "F_IN_DATE" DATE,
    "F_INPUT_EKC"   VARCHAR2(20 BYTE),
    "F_INPUT_GROUP" VARCHAR2(20 BYTE),
    "F_RESULT"      VARCHAR2(20 BYTE),
    "F_OPERATOR"    VARCHAR2(32 BYTE),
    CONSTRAINT "PK_SYS_PHOTO_FOLDER" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "DATA" ENABLE,
    CONSTRAINT "FK_PHOTO_FOLDER_USER" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_PHOTO_CHECK_OPERATOR" FOREIGN KEY ("F_OPERATOR") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_PHOTO_FOLDER_UPDATE" BEFORE
  UPDATE ON T_SYS_PHOTO_FOLDER REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                  VARCHAR2(512);
  fld_val_new                                                                                  VARCHAR2(512);
  table_code                                                                                   VARCHAR2(40);
  BEGIN
    table_code := 'T_SYS_PHOTO_FOLDER';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_RECEIVE_DATE
    IF( (:new.F_RECEIVE_DATE <> :old.F_RECEIVE_DATE) OR (:new.F_RECEIVE_DATE IS NULL AND :old.F_RECEIVE_DATE IS NOT NULL) OR (:new.F_RECEIVE_DATE IS NOT NULL AND :old.F_RECEIVE_DATE IS NULL) ) THEN
      fld_name               := 'T_SYS_PHOTO_FOLDER.F_RECEIVE_DATE';
      fld_val_old            := TO_CHAR(:old.F_RECEIVE_DATE, 'DD.MM.YYYY');
      fld_val_new            := TO_CHAR(:new.F_RECEIVE_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REGION
    IF( (:new.F_REGION <> :old.F_REGION) OR (:new.F_REGION IS NULL AND :old.F_REGION IS NOT NULL) OR (:new.F_REGION IS NOT NULL AND :old.F_REGION IS NULL) ) THEN
      fld_name         := 'T_SYS_PHOTO_FOLDER.F_REGION';
      fld_val_old      := GET_DICTIONARY_VALUE('Area', :old.F_REGION);
      fld_val_new      := GET_DICTIONARY_VALUE('Area', :new.F_REGION);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_DEPART
    IF( (:new.F_DEPART <> :old.F_DEPART) OR (:new.F_DEPART IS NULL AND :old.F_DEPART IS NOT NULL) OR (:new.F_DEPART IS NOT NULL AND :old.F_DEPART IS NULL) ) THEN
      fld_name         := 'T_SYS_PHOTO_FOLDER.F_DEPART';
      fld_val_old      := GET_DICTIONARY_VALUE('Departments', :old.F_DEPART);
      fld_val_new      := GET_DICTIONARY_VALUE('Departments', :new.F_DEPART);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_INIT_NAME
    IF( (:new.F_INIT_NAME <> :old.F_INIT_NAME) OR (:new.F_INIT_NAME IS NULL AND :old.F_INIT_NAME IS NOT NULL) OR (:new.F_INIT_NAME IS NOT NULL AND :old.F_INIT_NAME IS NULL) ) THEN
      fld_name            := 'T_SYS_INFO_CARD_CP.F_INIT_NAME';
      fld_val_old         := TRUNCATE_STRING(:old.F_INIT_NAME, 510);
      fld_val_new         := TRUNCATE_STRING(:new.F_INIT_NAME, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_INIT_PHONE
    IF( (:new.F_INIT_PHONE <> :old.F_INIT_PHONE) OR (:new.F_INIT_PHONE IS NULL AND :old.F_INIT_PHONE IS NOT NULL) OR (:new.F_INIT_PHONE IS NOT NULL AND :old.F_INIT_PHONE IS NULL) ) THEN
      fld_name             := 'T_SYS_INFO_CARD_CP.F_INIT_PHONE';
      fld_val_old          := TRUNCATE_STRING(:old.F_INIT_PHONE, 510);
      fld_val_new          := TRUNCATE_STRING(:new.F_INIT_PHONE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_EXEC_NAME
    IF( (:new.F_EXEC_NAME <> :old.F_EXEC_NAME) OR (:new.F_EXEC_NAME IS NULL AND :old.F_EXEC_NAME IS NOT NULL) OR (:new.F_EXEC_NAME IS NOT NULL AND :old.F_EXEC_NAME IS NULL) ) THEN
      fld_name            := 'T_SYS_INFO_CARD_CP.F_EXEC_NAME';
      fld_val_old         := TRUNCATE_STRING(:old.F_EXEC_NAME, 510);
      fld_val_new         := TRUNCATE_STRING(:new.F_EXEC_NAME, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_EXEC_PHONE
    IF( (:new.F_EXEC_PHONE <> :old.F_EXEC_PHONE) OR (:new.F_EXEC_PHONE IS NULL AND :old.F_EXEC_PHONE IS NOT NULL) OR (:new.F_EXEC_PHONE IS NOT NULL AND :old.F_EXEC_PHONE IS NULL) ) THEN
      fld_name             := 'T_SYS_INFO_CARD_CP.F_EXEC_PHONE';
      fld_val_old          := TRUNCATE_STRING(:old.F_EXEC_PHONE, 510);
      fld_val_new          := TRUNCATE_STRING(:new.F_EXEC_PHONE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_COMMENT
    IF( (:new.F_COMMENT <> :old.F_COMMENT) OR (:new.F_COMMENT IS NULL AND :old.F_COMMENT IS NOT NULL) OR (:new.F_COMMENT IS NOT NULL AND :old.F_COMMENT IS NULL) ) THEN
      fld_name          := 'T_SYS_INFO_CARD_CP.F_COMMENT';
      fld_val_old       := TRUNCATE_STRING(:old.F_COMMENT, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_COMMENT, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_OUT_NUM
    IF( (:new.F_OUT_NUM <> :old.F_OUT_NUM) OR (:new.F_OUT_NUM IS NULL AND :old.F_OUT_NUM IS NOT NULL) OR (:new.F_OUT_NUM IS NOT NULL AND :old.F_OUT_NUM IS NULL) ) THEN
      fld_name          := 'T_SYS_INFO_CARD_CP.F_OUT_NUM';
      fld_val_old       := TRUNCATE_STRING(:old.F_OUT_NUM, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_OUT_NUM, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_OUT_DATE
    IF( (:new.F_OUT_DATE <> :old.F_OUT_DATE) OR (:new.F_OUT_DATE IS NULL AND :old.F_OUT_DATE IS NOT NULL) OR (:new.F_OUT_DATE IS NOT NULL AND :old.F_OUT_DATE IS NULL) ) THEN
      fld_name           := 'T_SYS_PHOTO_FOLDER.F_OUT_DATE';
      fld_val_old        := TO_CHAR(:old.F_OUT_DATE, 'DD.MM.YYYY');
      fld_val_new        := TO_CHAR(:new.F_OUT_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_CHECK_NUM
    IF( (:new.F_CHECK_NUM <> :old.F_CHECK_NUM) OR (:new.F_CHECK_NUM IS NULL AND :old.F_CHECK_NUM IS NOT NULL) OR (:new.F_CHECK_NUM IS NOT NULL AND :old.F_CHECK_NUM IS NULL) ) THEN
      fld_name            := 'T_SYS_INFO_CARD_CP.F_CHECK_NUM';
      fld_val_old         := TRUNCATE_STRING(:old.F_CHECK_NUM, 510);
      fld_val_new         := TRUNCATE_STRING(:new.F_CHECK_NUM, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_IN_NUM
    IF( (:new.F_IN_NUM <> :old.F_IN_NUM) OR (:new.F_IN_NUM IS NULL AND :old.F_IN_NUM IS NOT NULL) OR (:new.F_IN_NUM IS NOT NULL AND :old.F_IN_NUM IS NULL) ) THEN
      fld_name         := 'T_SYS_INFO_CARD_CP.F_IN_NUM';
      fld_val_old      := TRUNCATE_STRING(:old.F_IN_NUM, 510);
      fld_val_new      := TRUNCATE_STRING(:new.F_IN_NUM, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_IN_DATE
    IF( (:new.F_IN_DATE <> :old.F_IN_DATE) OR (:new.F_IN_DATE IS NULL AND :old.F_IN_DATE IS NOT NULL) OR (:new.F_IN_DATE IS NOT NULL AND :old.F_IN_DATE IS NULL) ) THEN
      fld_name          := 'T_SYS_PHOTO_FOLDER.F_IN_DATE';
      fld_val_old       := TO_CHAR(:old.F_IN_DATE, 'DD.MM.YYYY');
      fld_val_new       := TO_CHAR(:new.F_IN_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_RESULT
    IF( (:new.F_RESULT <> :old.F_RESULT) OR (:new.F_RESULT IS NULL AND :old.F_RESULT IS NOT NULL) OR (:new.F_RESULT IS NOT NULL AND :old.F_RESULT IS NULL) ) THEN
      fld_name         := 'T_SYS_PHOTO_FOLDER.F_RESULT';
      fld_val_old      := GET_DICTIONARY_VALUE('OperCheck', :old.F_RESULT);
      fld_val_new      := GET_DICTIONARY_VALUE('OperCheck', :new.F_RESULT);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_OPERATOR
    IF( (:new.F_OPERATOR <> :old.F_OPERATOR) OR (:new.F_OPERATOR IS NULL AND :old.F_OPERATOR IS NOT NULL) OR (:new.F_OPERATOR IS NOT NULL AND :old.F_OPERATOR IS NULL) ) THEN
      fld_name           := 'T_SYS_INFO_CARD_CP.F_OPERATOR';
      fld_val_old        := GET_OPERATOR_NAME(:old.F_OPERATOR);
      fld_val_new        := GET_OPERATOR_NAME(:new.F_OPERATOR);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_PHOTO_FOLDER_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_REVELATION"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE),
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REVEL_TYPE" VARCHAR2(1 BYTE) NOT NULL ENABLE,
    "F_REVEL_HOW"  VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_REF_DACT"   VARCHAR2(32 BYTE),
    "F_REF_DACT2"  VARCHAR2(32 BYTE),
    "F_DATE" DATE,
    "F_COMMENT"        VARCHAR2(256 BYTE),
    "F_REF_INFO_CARD"  VARCHAR2(32 BYTE),
    "F_REF_INFO_CARD2" VARCHAR2(32 BYTE),
    "F_REG_AREA"       VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_FINGERS"        NUMBER(9,0),
    "F_PALMS"          NUMBER(9,0),
    "F_POST_NUMBER"    VARCHAR2(10 BYTE),
    "F_POST_DATE" DATE,
    "F_REF_SAMPLE" VARCHAR2(32 BYTE),
    "F_OPERATOR"   VARCHAR2(32 BYTE),
    CONSTRAINT "CK_REVELATION_TYPE" CHECK (F_REVEL_TYPE IN ('R', 'D', 'U', 'S') ) ENABLE,
    CONSTRAINT "PK_SYS_REVELATION" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_SYS_REVELATION_DEL" CHECK (SYS_DELETED IN ('N', 'Y') ) ENABLE,
    CONSTRAINT "FK_REVELATION_DACT2" FOREIGN KEY ("F_REF_DACT2") REFERENCES "EKC15"."T_SYS_PERSON_DACT" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_REVELATION_SAMPLE" FOREIGN KEY ("F_REF_SAMPLE") REFERENCES "EKC15"."T_SYS_PERSON_SAMPLE" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_REVELATION_OPER_ID" FOREIGN KEY ("F_OPERATOR") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_INFO_CARD1" FOREIGN KEY ("F_REF_INFO_CARD") REFERENCES "EKC15"."T_SYS_INFO_CARD" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_INFO_CARD2" FOREIGN KEY ("F_REF_INFO_CARD2") REFERENCES "EKC15"."T_SYS_INFO_CARD" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_REVELATION_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_REVELATION_DACT" FOREIGN KEY ("F_REF_DACT") REFERENCES "EKC15"."T_SYS_PERSON_DACT" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_REVELATION"."F_REVEL_TYPE"
IS
  '??? ?????????: ''R'' - ?????, ''D'' - ???????, ''U'' - ??????????? ???';
  COMMENT ON COLUMN "EKC15"."T_SYS_REVELATION"."F_REVEL_HOW"
IS
  '?????? ?? ??????? ???? ?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_REVELATION"."F_REF_DACT"
IS
  '????????? ????? ???????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_REVELATION"."F_REF_DACT2"
IS
  '? ?????? ???? ??????? - ?????? ??????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_REVELATION"."F_DATE"
IS
  '???? ?????????';
  COMMENT ON COLUMN "EKC15"."T_SYS_REVELATION"."F_COMMENT"
IS
  '???????????';
  CREATE INDEX "EKC15"."IE_REVEL_REF_IK" ON "EKC15"."T_SYS_REVELATION"
    (
      "F_REF_INFO_CARD"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "DATA" ;
CREATE UNIQUE INDEX "EKC15"."PK_SYS_REVELATION" ON "EKC15"."T_SYS_REVELATION"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_REVEL_REF_DACT" ON "EKC15"."T_SYS_REVELATION"
    (
      "F_REF_DACT"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_REVEL_REF_SAMPLE" ON "EKC15"."T_SYS_REVELATION"
    (
      "F_REF_SAMPLE"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_REVELATION_STATUSES_INSERT" AFTER
  INSERT ON T_SYS_REVELATION REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE BEGIN INCRIMENT_REVELATION
    (
      1,
      :new.F_REVEL_TYPE,
      :new.F_REF_INFO_CARD,
      :new.F_REF_INFO_CARD2,
      :new.F_REF_DACT,
      :new.F_REF_DACT2,
      :new.F_REF_SAMPLE
    );
END;
/
ALTER TRIGGER "EKC15"."TR_REVELATION_STATUSES_INSERT" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_REVELATION_STATUSES_UPDATE" AFTER
  UPDATE ON T_SYS_REVELATION REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE BEGIN IF (:old.SYS_DELETED = 'N'
  AND :new.SYS_DELETED                                                                                         = 'Y') THEN INCRIMENT_REVELATION(-1, :new.F_REVEL_TYPE, :new.F_REF_INFO_CARD, :new.F_REF_INFO_CARD2, :new.F_REF_DACT, :new.F_REF_DACT2, :new.F_REF_SAMPLE);
ELSE
  IF (:old.SYS_DELETED = 'Y' AND :new.SYS_DELETED = 'N') THEN
    INCRIMENT_REVELATION(1, :new.F_REVEL_TYPE, :new.F_REF_INFO_CARD, :new.F_REF_INFO_CARD2, :new.F_REF_DACT, :new.F_REF_DACT2, :new.F_REF_SAMPLE);
  END IF;
END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_REVELATION_STATUSES_UPDATE" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_REVELATION_UPDATE" BEFORE
  UPDATE ON T_SYS_REVELATION REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                                VARCHAR2(512);
  fld_val_new                                                                                VARCHAR2(512);
  table_code                                                                                 VARCHAR2(40);
BEGIN
  table_code := 'T_SYS_REVELATION';
  IF NOT UPDATING ('SYS_USER_ID') THEN
    raise_application_error (-20100, 'No user ID defined for logging');
  END IF;
  -- item was deleted
  IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
    fld_name         := 'DELETED';
    fld_val_old      := '';
    fld_val_new      := '';
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_REVEL_HOW
  IF( (:new.F_REVEL_HOW <> :old.F_REVEL_HOW) OR (:new.F_REVEL_HOW IS NULL AND :old.F_REVEL_HOW IS NOT NULL) OR (:new.F_REVEL_HOW IS NOT NULL AND :old.F_REVEL_HOW IS NULL) ) THEN
    fld_name            := 'T_SYS_REVELATION.F_REVEL_HOW';
    fld_val_old         := GET_DICTIONARY_VALUE('RevelationGenus', :old.F_REVEL_HOW);
    fld_val_new         := GET_DICTIONARY_VALUE('RevelationGenus', :new.F_REVEL_HOW);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_DATE
  IF( (:new.F_DATE <> :old.F_DATE) OR (:new.F_DATE IS NULL AND :old.F_DATE IS NOT NULL) OR (:new.F_DATE IS NOT NULL AND :old.F_DATE IS NULL) ) THEN
    fld_name       := 'T_SYS_REVELATION.F_DATE';
    fld_val_old    := TO_CHAR(:old.F_DATE, 'DD.MM.YYYY');
    fld_val_new    := TO_CHAR(:new.F_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_COMMENT
  IF( (:new.F_COMMENT <> :old.F_COMMENT) OR (:new.F_COMMENT IS NULL AND :old.F_COMMENT IS NOT NULL) OR (:new.F_COMMENT IS NOT NULL AND :old.F_COMMENT IS NULL) ) THEN
    fld_name          := 'T_SYS_REVELATION.F_COMMENT';
    fld_val_old       := TRUNCATE_STRING(:old.F_COMMENT, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_COMMENT, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_FINGERS
  IF( (:new.F_FINGERS <> :old.F_FINGERS) OR (:new.F_FINGERS IS NULL AND :old.F_FINGERS IS NOT NULL) OR (:new.F_FINGERS IS NOT NULL AND :old.F_FINGERS IS NULL) ) THEN
    fld_name          := 'T_SYS_REVELATION.F_FINGERS';
    fld_val_old       := TRUNCATE_STRING(:old.F_FINGERS, 510);
    fld_val_new       := TRUNCATE_STRING(:new.F_FINGERS, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_PALMS
  IF( (:new.F_PALMS <> :old.F_PALMS) OR (:new.F_PALMS IS NULL AND :old.F_PALMS IS NOT NULL) OR (:new.F_PALMS IS NOT NULL AND :old.F_PALMS IS NULL) ) THEN
    fld_name        := 'T_SYS_REVELATION.F_PALMS';
    fld_val_old     := TRUNCATE_STRING(:old.F_PALMS, 510);
    fld_val_new     := TRUNCATE_STRING(:new.F_PALMS, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_POST_NUMBER
  IF( (:new.F_POST_NUMBER <> :old.F_POST_NUMBER) OR (:new.F_POST_NUMBER IS NULL AND :old.F_POST_NUMBER IS NOT NULL) OR (:new.F_POST_NUMBER IS NOT NULL AND :old.F_POST_NUMBER IS NULL) ) THEN
    fld_name              := 'T_SYS_REVELATION.F_POST_NUMBER';
    fld_val_old           := TRUNCATE_STRING(:old.F_POST_NUMBER, 510);
    fld_val_new           := TRUNCATE_STRING(:new.F_POST_NUMBER, 510);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_POST_DATE
  IF( (:new.F_POST_DATE <> :old.F_POST_DATE) OR (:new.F_POST_DATE IS NULL AND :old.F_POST_DATE IS NOT NULL) OR (:new.F_POST_DATE IS NOT NULL AND :old.F_POST_DATE IS NULL) ) THEN
    fld_name            := 'T_SYS_REVELATION.F_POST_DATE';
    fld_val_old         := TO_CHAR(:old.F_POST_DATE, 'DD.MM.YYYY');
    fld_val_new         := TO_CHAR(:new.F_POST_DATE, 'DD.MM.YYYY');
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  -- F_OPERATOR
  IF( (:new.F_OPERATOR <> :old.F_OPERATOR) OR (:new.F_OPERATOR IS NULL AND :old.F_OPERATOR IS NOT NULL) OR (:new.F_OPERATOR IS NOT NULL AND :old.F_OPERATOR IS NULL) ) THEN
    fld_name           := 'T_SYS_REVELATION.F_OPERATOR';
    fld_val_old        := GET_OPERATOR_NAME(:old.F_OPERATOR);
    fld_val_new        := GET_OPERATOR_NAME(:new.F_OPERATOR);
    P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
  END IF;
  IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
    :new.SYS_USER_ID  := :old.SYS_USER_ID;
  END IF;
END;
/
ALTER TRIGGER "EKC15"."TR_REVELATION_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_REVELATION_IN_EXPERTZ"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"      VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_REF_REVELATION" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_REF_EXPERTZ"    VARCHAR2(32 BYTE) NOT NULL ENABLE,
    CONSTRAINT "PK_REVELATION_IN_EXPERTZ" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_REVELATION_IN_EXPERTZ_DEL" CHECK (SYS_DELETED IN ('N', 'Y') ) ENABLE,
    CONSTRAINT "FK_REV_EXPERTIZ_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_REV_IN_EXP_REV" FOREIGN KEY ("F_REF_REVELATION") REFERENCES "EKC15"."T_SYS_REVELATION" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_REV_IN_EXP_EXPTZ" FOREIGN KEY ("F_REF_EXPERTZ") REFERENCES "EKC15"."T_SYS_EXPERTZ" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_REVELATION_IN_EXPERTZ"."F_REF_REVELATION"
IS
  '?????????...';
  COMMENT ON COLUMN "EKC15"."T_SYS_REVELATION_IN_EXPERTZ"."F_REF_EXPERTZ"
IS
  '... ? ??????????';
CREATE UNIQUE INDEX "EKC15"."PK_REVELATION_IN_EXPERTZ" ON "EKC15"."T_SYS_REVELATION_IN_EXPERTZ"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_REVEL_IN_EXPERTZ_REV" ON "EKC15"."T_SYS_REVELATION_IN_EXPERTZ"
    (
      "F_REF_REVELATION"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_REVEL_IN_EXPERTZ_EXPERTZ" ON "EKC15"."T_SYS_REVELATION_IN_EXPERTZ"
    (
      "F_REF_EXPERTZ"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;



CREATE TABLE "EKC15"."T_SYS_ROLE_ATOMS"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE),
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_NAME"      VARCHAR2(40 BYTE) NOT NULL ENABLE,
    "F_TITLE"     VARCHAR2(40 BYTE) NOT NULL ENABLE,
    CONSTRAINT "CK_ROLE_ATOMS_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_ROLE_ATOMS_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_ROLE_ATOMS_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_ROLE_LINKS"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE),
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_ROLE_ID"   VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_ATOM_ID"   VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_CAN_WRITE" NUMBER(1,0) NOT NULL ENABLE,
    CONSTRAINT "CK_ROLE_LINKS_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_ROLE_LINKS_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_ROLE_LINKS_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_ROLE_LINKS_ATOM_ID" FOREIGN KEY ("F_ATOM_ID") REFERENCES "EKC15"."T_SYS_ROLE_ATOMS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_ROLE_LINKS_ROLE_ID" FOREIGN KEY ("F_ROLE_ID") REFERENCES "EKC15"."T_SYS_ROLE_PLAIN" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_ROLE_OPER"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE),
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"   VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_ROLE_ID"     VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_OPERATOR_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_DEPART"      VARCHAR2(20 BYTE),
    "F_EXPIRE_DATE" DATE,
    CONSTRAINT "CK_ROLE_OPERATOR_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_ROLE_OPERATOR_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_ROLE_OPERATOR_OPER_ID" FOREIGN KEY ("F_OPERATOR_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_ROLE_OPERATOR_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_ROLE_OPERATOR_ROLE_ID" FOREIGN KEY ("F_ROLE_ID") REFERENCES "EKC15"."T_SYS_ROLE_PLAIN" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_ROLE_OPER"."F_DEPART"
IS
  '?????, ? ???????? ???????? ????????? ????';
CREATE UNIQUE INDEX "EKC15"."PK_ROLE_OPERATOR_ID" ON "EKC15"."T_SYS_ROLE_OPER"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_ROLE_OPER_OPID" ON "EKC15"."T_SYS_ROLE_OPER"
    (
      "F_OPERATOR_ID"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "INDEX" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_ROLE_OPER_DELETE" BEFORE
  DELETE ON T_SYS_ROLE_OPER REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                               VARCHAR2(512);
  fld_val_new                                                                               VARCHAR2(512);
  table_code                                                                                VARCHAR2(40);
BEGIN
  table_code  := 'T_SYS_OPERATORS';
  fld_name    := 'T_SYS_OPERATORS.ROLE_DELETED';
  fld_val_old := GET_ROLE_DISPLAYNAME(:old.F_ROLE_ID);
  fld_val_new := '';
  P_AUDIT_POPULATE(:old.SYS_USER_ID, table_code, :old.F_OPERATOR_ID, fld_name, fld_val_old, fld_val_new);
END;
/
ALTER TRIGGER "EKC15"."TR_ROLE_OPER_DELETE" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_ROLE_OPER_UPDATE" BEFORE
  UPDATE ON T_SYS_ROLE_OPER REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                               VARCHAR2(512);
  fld_val_new                                                                               VARCHAR2(512);
  table_code                                                                                VARCHAR2(40);
  BEGIN
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      table_code       := 'T_SYS_OPERATORS';
      fld_name         := 'T_SYS_OPERATORS.ROLE_DELETED';
      fld_val_old      := GET_ROLE_DISPLAYNAME(:old.F_ROLE_ID);
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.F_OPERATOR_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_ROLE_OPER_UPDATE" ENABLE;
CREATE OR REPLACE TRIGGER "EKC15"."TR_ROLE_OPER_INSERT" BEFORE
  INSERT ON T_SYS_ROLE_OPER REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2
    (
      80
    );
  fld_val_old VARCHAR2
  (
    512
  )
  ;
  fld_val_new VARCHAR2
  (
    512
  )
  ;
  table_code VARCHAR2
  (
    40
  )
  ;
  BEGIN
    table_code  := 'T_SYS_OPERATORS';
    fld_name    := 'T_SYS_OPERATORS.ROLE_ADDED';
    fld_val_old := '';
    fld_val_new := GET_ROLE_DISPLAYNAME
    (
      :new.F_ROLE_ID
    )
    ;
    P_AUDIT_POPULATE
    (
      :new.SYS_USER_ID, table_code, :new.F_OPERATOR_ID, fld_name, fld_val_old, fld_val_new
    )
    ;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_ROLE_OPER_INSERT" ENABLE;



CREATE TABLE "EKC15"."T_SYS_ROLE_PLAIN"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_TITLE"      VARCHAR2(40 BYTE) NOT NULL ENABLE,
    "SYS_READONLY" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    CONSTRAINT "CK_ROLE_PLAIN_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_ROLE_PLAIN_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_ROLE_PLAIN_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_ROLE_PLAIN"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"  VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_TITLE"      VARCHAR2(40 BYTE) NOT NULL ENABLE,
    "SYS_READONLY" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    CONSTRAINT "CK_ROLE_PLAIN_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "PK_ROLE_PLAIN_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_ROLE_PLAIN_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;



CREATE TABLE "EKC15"."T_SYS_SD_ORM"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED" VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_TYPE"      VARCHAR2(1 BYTE) NOT NULL ENABLE,
    "F_REG_NUM"   VARCHAR2(40 BYTE),
    "F_REG_AREA"  VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_SD_TYPE"   VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_EXEC_DATE" DATE NOT NULL ENABLE,
    "F_EKC_EXECTR"      VARCHAR2(32 BYTE),
    "F_RESPONSIBLE"     VARCHAR2(128 BYTE),
    "F_RESP_POSITION"   VARCHAR2(20 BYTE),
    "F_RESP_DEPARTMENT" VARCHAR2(20 BYTE),
    "F_PLACE"           VARCHAR2(256 BYTE),
    "F_REF_FABULA"      VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "F_WHAT_DONE"       VARCHAR2(512 BYTE),
    "F_EKC_GROUP"       VARCHAR2(20 BYTE),
    "F_INITIATOR"       VARCHAR2(20 BYTE),
    "F_RECEPIENT"       VARCHAR2(20 BYTE),
    "F_SIZE"            NUMBER(9,0),
    "F_NUMBERS_SP"      VARCHAR2(80 BYTE),
    CONSTRAINT "PK_SD_ORM_ID" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "CK_SD_ORM_DEL" CHECK (SYS_DELETED IN ('Y','N')) ENABLE,
    CONSTRAINT "CK_SD_ORM_TYPE" CHECK (F_TYPE     IN ('S','O')) ENABLE,
    CONSTRAINT "FK_SD_ORN_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_SD_ORM_FABULA" FOREIGN KEY ("F_REF_FABULA") REFERENCES "EKC15"."T_SYS_FABULA" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_SD_ORM_EXECUTOR" FOREIGN KEY ("F_EKC_EXECTR") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
CREATE OR REPLACE TRIGGER "EKC15"."TR_SD_ORM_UPDATE" BEFORE
  UPDATE ON T_SYS_SD_ORM REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW DECLARE fld_name VARCHAR2(80);
  fld_val_old                                                                            VARCHAR2(512);
  fld_val_new                                                                            VARCHAR2(512);
  table_code                                                                             VARCHAR2(40);
  BEGIN
    table_code := 'T_SYS_SD_ORM';
    IF NOT UPDATING ('SYS_USER_ID') THEN
      raise_application_error (-20100, 'No user ID defined for logging');
    END IF;
    -- item was deleted
    IF(:old.SYS_DELETED = 'N' AND :new.SYS_DELETED = 'Y') THEN
      fld_name         := 'DELETED';
      fld_val_old      := '';
      fld_val_new      := '';
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_TYPE
    IF( (:new.F_TYPE <> :old.F_TYPE) OR (:new.F_TYPE IS NULL AND :old.F_TYPE IS NOT NULL) OR (:new.F_TYPE IS NOT NULL AND :old.F_TYPE IS NULL) ) THEN
      fld_name       := 'T_SYS_SD_ORM.F_TYPE';
      fld_val_old    := TRUNCATE_STRING(:old.F_TYPE, 510);
      fld_val_new    := TRUNCATE_STRING(:new.F_TYPE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REG_NUM
    IF( (:new.F_REG_NUM <> :old.F_REG_NUM) OR (:new.F_REG_NUM IS NULL AND :old.F_REG_NUM IS NOT NULL) OR (:new.F_REG_NUM IS NOT NULL AND :old.F_REG_NUM IS NULL) ) THEN
      fld_name          := 'T_SYS_SD_ORM.F_REG_NUM';
      fld_val_old       := TRUNCATE_STRING(:old.F_REG_NUM, 510);
      fld_val_new       := TRUNCATE_STRING(:new.F_REG_NUM, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REG_AREA
    IF( (:new.F_REG_AREA <> :old.F_REG_AREA) OR (:new.F_REG_AREA IS NULL AND :old.F_REG_AREA IS NOT NULL) OR (:new.F_REG_AREA IS NOT NULL AND :old.F_REG_AREA IS NULL) ) THEN
      fld_name           := 'T_SYS_SD_ORM.F_REG_AREA';
      fld_val_old        := TRUNCATE_STRING(:old.F_REG_AREA, 510);
      fld_val_new        := TRUNCATE_STRING(:new.F_REG_AREA, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_SD_TYPE
    IF( (:new.F_SD_TYPE <> :old.F_SD_TYPE) OR (:new.F_SD_TYPE IS NULL AND :old.F_SD_TYPE IS NOT NULL) OR (:new.F_SD_TYPE IS NOT NULL AND :old.F_SD_TYPE IS NULL) ) THEN
      fld_name          := 'T_SYS_SD_ORM.F_SD_TYPE';
      IF ( :new.F_TYPE   ='S' ) THEN
        fld_val_old     := GET_DICTIONARY_VALUE('OtherSD', :old.F_SD_TYPE);
        fld_val_new     := GET_DICTIONARY_VALUE('OtherSD', :new.F_SD_TYPE);
      ELSE
        fld_val_old := GET_DICTIONARY_VALUE('OtherORM', :old.F_SD_TYPE);
        fld_val_new := GET_DICTIONARY_VALUE('OtherORM', :new.F_SD_TYPE);
      END IF;
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_EXEC_DATE
    IF( (:new.F_EXEC_DATE <> :old.F_EXEC_DATE) OR (:new.F_EXEC_DATE IS NULL AND :old.F_EXEC_DATE IS NOT NULL) OR (:new.F_EXEC_DATE IS NOT NULL AND :old.F_EXEC_DATE IS NULL) ) THEN
      fld_name            := 'T_SYS_SD_ORM.F_EXEC_DATE';
      fld_val_old         := TO_CHAR(:old.F_EXEC_DATE, 'DD.MM.YYYY');
      fld_val_new         := TO_CHAR(:new.F_EXEC_DATE, 'DD.MM.YYYY');
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_EKC_EXECTR
    IF( (:new.F_EKC_EXECTR <> :old.F_EKC_EXECTR) OR (:new.F_EKC_EXECTR IS NULL AND :old.F_EKC_EXECTR IS NOT NULL) OR (:new.F_EKC_EXECTR IS NOT NULL AND :old.F_EKC_EXECTR IS NULL) ) THEN
      fld_name             := 'T_SYS_SD_ORM.F_EKC_EXECTR';
      fld_val_old          := GET_OPERATOR_NAME(:old.F_EKC_EXECTR);
      fld_val_new          := GET_OPERATOR_NAME(:new.F_EKC_EXECTR);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_RESPONSIBLE
    IF( (:new.F_RESPONSIBLE <> :old.F_RESPONSIBLE) OR (:new.F_RESPONSIBLE IS NULL AND :old.F_RESPONSIBLE IS NOT NULL) OR (:new.F_RESPONSIBLE IS NOT NULL AND :old.F_RESPONSIBLE IS NULL) ) THEN
      fld_name              := 'T_SYS_SD_ORM.F_RESPONSIBLE';
      fld_val_old           := TRUNCATE_STRING(:old.F_RESPONSIBLE, 510);
      fld_val_new           := TRUNCATE_STRING(:new.F_RESPONSIBLE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_RESP_POSITION
    IF( (:new.F_RESP_POSITION <> :old.F_RESP_POSITION) OR (:new.F_RESP_POSITION IS NULL AND :old.F_RESP_POSITION IS NOT NULL) OR (:new.F_RESP_POSITION IS NOT NULL AND :old.F_RESP_POSITION IS NULL) ) THEN
      fld_name                := 'T_SYS_SD_ORM.F_RESP_POSITION';
      fld_val_old             := TRUNCATE_STRING(:old.F_RESP_POSITION, 510);
      fld_val_new             := TRUNCATE_STRING(:new.F_RESP_POSITION, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_RESP_DEPARTMENT
    IF( (:new.F_RESP_DEPARTMENT <> :old.F_RESP_DEPARTMENT) OR (:new.F_RESP_DEPARTMENT IS NULL AND :old.F_RESP_DEPARTMENT IS NOT NULL) OR (:new.F_RESP_DEPARTMENT IS NOT NULL AND :old.F_RESP_DEPARTMENT IS NULL) ) THEN
      fld_name                  := 'T_SYS_SD_ORM.F_RESP_DEPARTMENT';
      fld_val_old               := TRUNCATE_STRING(:old.F_RESP_DEPARTMENT, 510);
      fld_val_new               := TRUNCATE_STRING(:new.F_RESP_DEPARTMENT, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_PLACE
    IF( (:new.F_PLACE <> :old.F_PLACE) OR (:new.F_PLACE IS NULL AND :old.F_PLACE IS NOT NULL) OR (:new.F_PLACE IS NOT NULL AND :old.F_PLACE IS NULL) ) THEN
      fld_name        := 'T_SYS_SD_ORM.F_PLACE';
      fld_val_old     := TRUNCATE_STRING(:old.F_PLACE, 510);
      fld_val_new     := TRUNCATE_STRING(:new.F_PLACE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_REF_FABULA
    IF( (:new.F_REF_FABULA <> :old.F_REF_FABULA) OR (:new.F_REF_FABULA IS NULL AND :old.F_REF_FABULA IS NOT NULL) OR (:new.F_REF_FABULA IS NOT NULL AND :old.F_REF_FABULA IS NULL) ) THEN
      fld_name             := 'T_SYS_SD_ORM.F_REF_FABULA';
      fld_val_old          := TRUNCATE_STRING(:old.F_REF_FABULA, 510);
      fld_val_new          := TRUNCATE_STRING(:new.F_REF_FABULA, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    -- F_WHAT_DONE
    IF( (:new.F_WHAT_DONE <> :old.F_WHAT_DONE) OR (:new.F_WHAT_DONE IS NULL AND :old.F_WHAT_DONE IS NOT NULL) OR (:new.F_WHAT_DONE IS NOT NULL AND :old.F_WHAT_DONE IS NULL) ) THEN
      fld_name            := 'T_SYS_SD_ORM.F_WHAT_DONE';
      fld_val_old         := TRUNCATE_STRING(:old.F_WHAT_DONE, 510);
      fld_val_new         := TRUNCATE_STRING(:new.F_WHAT_DONE, 510);
      P_AUDIT_POPULATE(:new.SYS_USER_ID, table_code, :old.SYS_ID, fld_name, fld_val_old, fld_val_new);
    END IF;
    IF(:new.SYS_USER_ID <> :old.SYS_USER_ID) THEN
      :new.SYS_USER_ID  := :old.SYS_USER_ID;
    END IF;
  END;
  /
  ALTER TRIGGER "EKC15"."TR_SD_ORM_UPDATE" ENABLE;



CREATE TABLE "EKC15"."T_SYS_UNDER_EXP"
  (
    "SYS_ID"      VARCHAR2(32 BYTE) DEFAULT SYS_GUID() NOT NULL ENABLE,
    "SYS_USER_ID" VARCHAR2(32 BYTE) NOT NULL ENABLE,
    "SYS_UPDATED" DATE DEFAULT SYSDATE NOT NULL ENABLE,
    "SYS_DELETED"   VARCHAR2(1 BYTE) DEFAULT 'N' NOT NULL ENABLE,
    "F_EXP_KIND"    VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_EXP_EXHIBIT" VARCHAR2(20 BYTE) NOT NULL ENABLE,
    "F_EVIDENCE"    VARCHAR2(32 BYTE) NOT NULL ENABLE,
    CONSTRAINT "PK_UNDER_EXP" PRIMARY KEY ("SYS_ID") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "INDEX" ENABLE,
    CONSTRAINT "FK_UNDER_EXP_USER_ID" FOREIGN KEY ("SYS_USER_ID") REFERENCES "EKC15"."T_SYS_OPERATORS" ("SYS_ID") ENABLE,
    CONSTRAINT "FK_UNDER_EXP_EVIDENCE" FOREIGN KEY ("F_EVIDENCE") REFERENCES "EKC15"."T_SYS_EVIDENCE" ("SYS_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "DATA" ;
COMMENT ON COLUMN "EKC15"."T_SYS_UNDER_EXP"."F_EXP_KIND"
IS
  '??? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_UNDER_EXP"."F_EXP_EXHIBIT"
IS
  '??????? ????? ? ???????';
  COMMENT ON COLUMN "EKC15"."T_SYS_UNDER_EXP"."F_EVIDENCE"
IS
  '?????? ?? T_SYS_EVIDENCE';
CREATE UNIQUE INDEX "EKC15"."PK_UNDER_EXP" ON "EKC15"."T_SYS_UNDER_EXP"
  (
    "SYS_ID"
  )
  PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "INDEX" ;
  CREATE INDEX "EKC15"."IE_UNDER_EXP" ON "EKC15"."T_SYS_UNDER_EXP"
    (
      "F_EVIDENCE"
    )
    PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE
    (
      INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
    )
    TABLESPACE "DATA" ;



CREATE OR REPLACE FORCE VIEW "EKC15"."BAK_V_EXPERTZ_RESLT_DACT" ("SYS_ID", "SYS_USER_ID", "RESULT_CONVNNC", "RESULT_OWNER", "RESULT_COMMENT")
AS
  SELECT SYS_ID,
    SYS_USER_ID,
    F_RESLT_DIC1,
    F_RESLT_DIC2,
    F_RESLT_TEXT1
  FROM T_SYS_EXPERTZ
  WHERE SYS_DELETED = 'N'
  AND F_EXPRT_GENUS = '09' ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_ADDRESS" ("SYS_ID", "V_STR_ADDRESS")
AS
  (SELECT A.SYS_ID SYS_ID,
    (SELECT F_MEAN FROM T_DIC_MAIN WHERE f_domain = 'Region' AND f_code=f_region
    )
    ||', '
    || f_town
    ||', '
    ||
    (SELECT F_MEAN FROM T_DIC_MAIN WHERE f_domain = 'Area' AND f_code=f_area
    )
    ||', '
    || f_street
    ||', '
    || A.F_DOM
    ||', '
    ||A.F_KORP
    ||', '
    ||A.F_KVART V_STR_ADDRESS
  FROM ADDRESS A
  WHERE A.sys_deleted = 'N'
  ) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_ADRESS_OLD" ("SYS_ID", "V_STR_ADDRESS")
AS
  SELECT A.SYS_ID,
    DIC_COUNTRY.F_MEAN
    || ', '
    || DIC_REGION.F_MEAN
    || ', '
    || DIC_TOWN.F_MEAN
    || ', '
    || DIC_AREA.F_MEAN
    || ', '
    || DIC_STREET.F_MEAN
    || ', '
    || A.F_DOM
    || ', '
    || A.F_KORP
    || ', '
    || A.F_KVART
  FROM ADDRESS A,
    (SELECT * FROM T_DIC_MAIN WHERE f_domain = 'Countries'
    ) DIC_COUNTRY,
    (SELECT * FROM T_DIC_MAIN WHERE f_domain = 'Region'
    ) DIC_REGION,
    (SELECT * FROM T_DIC_MAIN WHERE f_domain = 'Cities'
    ) DIC_TOWN,
    (SELECT * FROM T_DIC_MAIN WHERE f_domain = 'Area'
    ) DIC_AREA,
    (SELECT * FROM T_DIC_MAIN WHERE f_domain = 'Streets'
    ) DIC_STREET
  WHERE A.sys_deleted       = 'N'
  AND DIC_COUNTRY.f_code(+) = A.f_country
  AND DIC_REGION.f_code(+)  = A.f_region
  AND DIC_TOWN.f_code(+)    = A.f_town
  AND DIC_AREA.f_code(+)    = A.f_area
  AND DIC_STREET.f_code     = A.f_street ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_AUDIT" ("SYS_ID", "F_USERID", "F_MOD_STAMP", "F_TABLE_CODE", "F_DISPLAY_TABLE_NAME", "F_RECORD_SYS_ID", "F_FLD_NAME", "F_DISPLAY_FLD_NAME", "F_VALUE_OLD", "F_VALUE_NEW")
AS
  SELECT a.SYS_ID,
    a.F_USERID,
    a.F_MOD_STAMP,
    a.f_table_code,
    da.f_display_name,
    a.F_RECORD_SYS_ID,
    a.F_FLD_NAME,
    da2.f_display_name,
    CASE
      WHEN a.F_FLD_NAME='T_SYS_FABULA.F_ADDR'
      THEN
        (SELECT V_STR_ADDRESS FROM V_ADDRESS WHERE SYS_ID=a.F_VALUE_OLD
        )
      ELSE a.F_VALUE_OLD
    END,
    CASE
      WHEN a.F_FLD_NAME='T_SYS_FABULA.F_ADDR'
      THEN
        (SELECT V_STR_ADDRESS FROM V_ADDRESS WHERE SYS_ID=a.F_VALUE_NEW
        )
      ELSE a.F_VALUE_NEW
    END
  FROM T_SYS_AUDIT a,
    T_DIC_AUDIT_TABLES da,
    T_DIC_AUDIT_TABLES da2
  WHERE a.f_table_code=da.f_name
  AND da.f_type       = 'T'
  AND a.f_fld_name(+) = da2.f_name
  AND da2.f_type      = 'A' ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_DACT_IK_REPORT" ("SYS_ID", "F_REG_AREA", "F_REG_DATE", "F_REGION", "F_MAIN_VID_PREST", "P_NUM_TOTAL", "P_NUM_FINGER", "P_NUM_PALM", "P_NUM_PAPILON", "INCIDENT", "REGION_S", "R_ORDER")
AS
  (SELECT IK.SYS_ID SYS_ID,
    FAB.F_REG_AREA F_REG_AREA,
    FAB.F_REG_DATE F_REG_DATE,
    ADDR.F_AREA F_REGION,
    FAB.F_MAIN_VID_PREST F_MAIN_VID_PREST,
    IK.F_NUM_TOTAL P_NUM_TOTAL,
    IK.F_NUM_FINGER P_NUM_FINGER,
    IK.F_NUM_PALM P_NUM_PALM,
    (
    CASE
      WHEN IK.F_NUM_FINGER_PAPILON IS NULL
      THEN 0
      ELSE IK.F_NUM_FINGER_PAPILON
    END +
    CASE
      WHEN IK.F_NUM_PALM_PAPILON IS NULL
      THEN 0
      ELSE IK.F_NUM_PALM_PAPILON
    END) P_NUM_PAPILON,
    CASE
      WHEN FAB.F_MAIN_VID_PREST IS NULL
      THEN ' '
      ELSE
        (SELECT D.F_MEAN
        FROM T_DIC_MAIN D
        WHERE D.SYS_DELETED='N'
        AND D.F_DOMAIN     ='Incident'
        AND D.F_CODE       =FAB.F_MAIN_VID_PREST
        )
    END INCIDENT,
    CASE
      WHEN ADDR.F_AREA IS NULL
      THEN ' '
      ELSE
        (SELECT D.F_MEAN
        FROM T_DIC_MAIN D
        WHERE D.SYS_DELETED='N'
        AND D.F_DOMAIN     ='Area'
        AND D.F_CODE       =ADDR.F_AREA
        )
    END REGION_S,
    CASE
      WHEN ADDR.F_AREA IS NULL
      THEN '99'
      ELSE
        (SELECT D.F_ORDER
        FROM T_DIC_MAIN D
        WHERE D.SYS_DELETED='N'
        AND D.F_DOMAIN     ='Area'
        AND D.F_CODE       =ADDR.F_AREA
        )
    END R_ORDER
  FROM T_SYS_INFO_CARD IK,
    T_SYS_EXPERTZ EX,
    T_SYS_FABULA FAB,
    T_DIC_ADDRESS ADDR
  WHERE IK.SYS_DELETED = 'N'
  AND FAB.SYS_DELETED  = 'N'
  AND EX.SYS_DELETED   = 'N'
  AND IK.F_REF_EXPERTZ = EX.SYS_ID
  AND EX.F_REF_FABULA  = FAB.sys_id
  AND FAB.F_ADDR       = ADDR.SYS_ID
  );



CREATE OR REPLACE FORCE VIEW "EKC15"."V_DACT_MONTH_REPORT" ("SYS_ID", "REGION", "EKC_NUMBER", "REGION_ORDER", "REGION_CODE", "REG_AREA", "REG_YEAR", "REG_MONTH", "REG_DAY", "FLG_DCARD", "FLG_DCARD_07", "FLG_IK", "TRACES", "REVELS", "CORPSES", "DETECTS", "CRIME_YEAR", "IS_FLINT", "IS_CDS")
AS
  (SELECT F.SYS_ID,
    CASE
      WHEN EXISTS
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      THEN
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      ELSE ''
    END,
    (SELECT R.F_REF_DOMAIN
    FROM T_DIC_MAIN R
    WHERE (F.F_REGION  = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    (SELECT R.F_ORDER
    FROM T_DIC_MAIN R
    WHERE (F.F_REGION  = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    F.F_REGION,
    F.F_INPUT_EKC,
    TO_CHAR(F.F_RECEIVE_DATE,'YYYY'),
    TO_CHAR(F.F_RECEIVE_DATE,'MM'),
    TO_CHAR(F.F_RECEIVE_DATE,'DD'),
    (SELECT COUNT(*)
    FROM T_SYS_PERSON_DACT_IN_FOLDER D,
      T_SYS_PERSON_DACT K,
      T_SYS_PERSON P
    WHERE D.F_REF_FOLDER = F.SYS_ID
    AND D.SYS_DELETED    = 'N'
    AND K.SYS_DELETED    = 'N'
    AND P.SYS_DELETED    = 'N'
    AND P.F_IS_CORPSE    = 'N'
    AND K.SYS_ID         = D.F_REF_DACT
    AND P.SYS_ID         = K.F_REF_PERSON
    ),
    CASE
      WHEN F.F_INPUT_EKC = '07'
      THEN 1
      ELSE 0
    END,
    0,
    0,
    0,
    (SELECT COUNT(*)
    FROM T_SYS_PERSON_DACT_IN_FOLDER D,
      T_SYS_PERSON_DACT K,
      T_SYS_PERSON P
    WHERE D.F_REF_FOLDER = F.SYS_ID
    AND D.SYS_DELETED    = 'N'
    AND K.SYS_DELETED    = 'N'
    AND P.SYS_DELETED    = 'N'
    AND P.F_IS_CORPSE    = 'Y'
    AND K.SYS_ID         = D.F_REF_DACT
    AND P.SYS_ID         = K.F_REF_PERSON
    ),
    0,
    '0000',
    CASE
      WHEN F.F_OLDKEY IS NULL
      THEN 0
      ELSE 1
    END,
    0
  FROM T_SYS_DACT_FOLDER F
  WHERE F.SYS_DELETED = 'N'
  UNION
  SELECT P.SYS_ID,
    CASE
      WHEN EXISTS
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      THEN
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      ELSE ''
    END,
    (SELECT R.F_REF_DOMAIN
    FROM T_DIC_MAIN R
    WHERE (F.F_REGION  = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    (SELECT R.F_ORDER
    FROM T_DIC_MAIN R
    WHERE (F.F_REGION  = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    F.F_REGION,
    F.F_INPUT_EKC,
    TO_CHAR(REV.F_DATE,'YYYY'),
    TO_CHAR(REV.F_DATE,'MM'),
    TO_CHAR(REV.F_DATE,'DD'),
    0,
    CASE
      WHEN F.F_INPUT_EKC = '07'
      THEN 1
      ELSE 0
    END,
    0,
    0,
    0,
    0,
    1,
    '0000',
    CASE
      WHEN F.F_OLDKEY IS NULL
      THEN 0
      ELSE 1
    END,
    0
  FROM T_SYS_DACT_FOLDER F,
    T_SYS_PERSON_DACT_IN_FOLDER D,
    T_SYS_PERSON_DACT K,
    T_SYS_PERSON P,
    T_SYS_REVELATION REV
  WHERE F.SYS_DELETED  = 'N'
  AND D.F_REF_FOLDER   = F.SYS_ID
  AND D.SYS_DELETED    = 'N'
  AND K.SYS_DELETED    = 'N'
  AND K.SYS_ID         = D.F_REF_DACT
  AND P.SYS_DELETED    = 'N'
  AND P.SYS_ID         = K.F_REF_PERSON
  AND P.F_IS_CORPSE    = 'Y'
  AND REV.SYS_DELETED  = 'N'
  AND REV.F_REVEL_TYPE = 'D'
  AND (REV.F_REF_DACT  = K.SYS_ID
  OR REV.F_REF_DACT2   = K.SYS_ID)
  UNION
  SELECT IK.SYS_ID,
    CASE
      WHEN EXISTS
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (A.F_AREA    = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      THEN
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (A.F_AREA    = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      ELSE ''
    END,
    (SELECT R.F_REF_DOMAIN
    FROM T_DIC_MAIN R
    WHERE (A.F_AREA    = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    (SELECT R.F_ORDER
    FROM T_DIC_MAIN R
    WHERE (A.F_AREA    = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    A.F_AREA,
    IK.F_EKC_DEPART,
    TO_CHAR(IK.F_EKC_REG_DATE,'YYYY'),
    TO_CHAR(IK.F_EKC_REG_DATE,'MM'),
    TO_CHAR(IK.F_EKC_REG_DATE,'DD'),
    0,
    0,
    1,
    CASE
      WHEN IK.F_NUM_FINGER_PAPILON IS NOT NULL
      THEN IK.F_NUM_FINGER_PAPILON
      ELSE 0
    END +
    CASE
      WHEN IK.F_NUM_PALM_PAPILON IS NOT NULL
      THEN IK.F_NUM_PALM_PAPILON
      ELSE 0
    END,
    0,
    0,
    0,
    TO_CHAR(F.F_DATE,'YYYY'),
    CASE
      WHEN IK.F_OLDKEY IS NULL
      THEN 0
      ELSE 1
    END,
    CASE
      WHEN (IK.F_GIACP_FIO LIKE 'Y%')
      OR (IK.F_GIACP_NUMBER LIKE 'Y%')
      THEN 1
      ELSE 0
    END
  FROM T_SYS_INFO_CARD IK,
    T_SYS_EXPERTZ E,
    T_SYS_FABULA F,
    T_DIC_ADDRESS A
  WHERE IK.SYS_DELETED  = 'N'
  AND IK.F_TYPE         = '01'
  AND IK.F_SUBTYPE      = '01'
  AND IK.F_EKC_REG_NUM IS NOT NULL
  AND E.SYS_DELETED     = 'N'
  AND E.SYS_ID          = IK.F_REF_EXPERTZ
  AND F.SYS_DELETED     = 'N'
  AND F.SYS_ID          = E.F_REF_FABULA
  AND A.SYS_DELETED     = 'N'
  AND A.SYS_ID          = F.F_ADDR
  UNION
  SELECT REV.SYS_ID,
    CASE
      WHEN EXISTS
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (A.F_AREA    = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      THEN
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (A.F_AREA    = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      ELSE ''
    END,
    (SELECT R.F_REF_DOMAIN
    FROM T_DIC_MAIN R
    WHERE (A.F_AREA    = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    (SELECT R.F_ORDER
    FROM T_DIC_MAIN R
    WHERE (A.F_AREA    = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    A.F_AREA,
    IK.F_EKC_DEPART,
    TO_CHAR(REV.F_DATE,'YYYY'),
    TO_CHAR(REV.F_DATE,'MM'),
    TO_CHAR(REV.F_DATE,'DD'),
    0,
    0,
    0,
    0,
    1,
    0,
    0,
    TO_CHAR(F.F_DATE,'YYYY'),
    CASE
      WHEN IK.F_OLDKEY IS NULL
      THEN 0
      ELSE 1
    END,
    0
  FROM T_SYS_INFO_CARD IK,
    T_SYS_EXPERTZ E,
    T_SYS_FABULA F,
    T_DIC_ADDRESS A,
    T_SYS_REVELATION REV
  WHERE IK.SYS_DELETED   = 'N'
  AND IK.F_TYPE          = '01'
  AND IK.F_SUBTYPE       = '01'
  AND E.SYS_DELETED      = 'N'
  AND E.SYS_ID           = IK.F_REF_EXPERTZ
  AND F.SYS_DELETED      = 'N'
  AND F.SYS_ID           = E.F_REF_FABULA
  AND A.SYS_DELETED      = 'N'
  AND A.SYS_ID           = F.F_ADDR
  AND REV.SYS_DELETED    = 'N'
  AND REV.F_REVEL_TYPE   = 'R'
  AND REV.F_REF_INFO_CARD=IK.SYS_ID
  );



CREATE OR REPLACE FORCE VIEW "EKC15"."V_EVERYDAY_DACTIL" ("SYS_ID", "EKC", "CNT_REV", "CNT_UNION", "CNT_DUPL", "F_DATE", "CNT_DK", "CNT_IK")
AS
  (SELECT R.SYS_ID,
    R.F_REG_AREA,
    0,
    CASE
      WHEN (R.F_REVEL_TYPE='U')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN (R.F_REVEL_TYPE='D'
      AND (((SELECT P.F_IS_CORPSE
        FROM T_SYS_PERSON P,
          T_SYS_PERSON_DACT D
        WHERE D.SYS_DELETED = 'N'
        AND D.SYS_ID        = R.F_REF_DACT
        AND P.SYS_DELETED   = 'N'
        AND P.SYS_ID        = D.F_REF_PERSON) = 'Y')
      OR ((SELECT P.F_IS_CORPSE
        FROM T_SYS_PERSON P,
          T_SYS_PERSON_DACT D
        WHERE D.SYS_DELETED = 'N'
        AND D.SYS_ID        = R.F_REF_DACT2
        AND P.SYS_DELETED   = 'N'
        AND P.SYS_ID        = D.F_REF_PERSON) = 'Y')))
      THEN 1
      ELSE 0
    END,
    R.F_DATE,
    0,
    0
  FROM T_SYS_REVELATION R
  WHERE R.SYS_DELETED='N'
  UNION
  SELECT I.SYS_ID,
    R.F_REG_AREA,
    1,
    0,
    0,
    R.F_DATE,
    0,
    0
  FROM T_SYS_INFO_CARD I,
    T_SYS_REVELATION R
  WHERE I.SYS_DELETED='N'
  AND I.F_TYPE       ='01'
  AND I.SYS_ID       =R.F_REF_INFO_CARD
  AND R.SYS_DELETED  ='N'
  AND R.F_REVEL_TYPE ='R'
  UNION
  SELECT F.SYS_ID,
    F.F_INPUT_EKC,
    0,
    0,
    0,
    F.F_RECEIVE_DATE,
    (SELECT COUNT(*)
    FROM T_SYS_PERSON_DACT D,
      T_SYS_PERSON_DACT_IN_FOLDER L
    WHERE D.SYS_DELETED='N'
    AND L.SYS_DELETED  ='N'
    AND L.F_REF_FOLDER =F.SYS_ID
    AND L.F_REF_DACT   =D.SYS_ID
    ),
    0
  FROM T_SYS_DACT_FOLDER F
  WHERE F.SYS_DELETED='N'
  UNION
  SELECT I.SYS_ID,
    I.F_EKC_DEPART,
    0,
    0,
    0,
    I.F_EKC_REG_DATE,
    0,
    CASE
      WHEN I.F_NUM_FINGER_PAPILON IS NULL
      THEN 0
      ELSE I.F_NUM_FINGER_PAPILON
    END +
    CASE
      WHEN I.F_NUM_PALM_PAPILON IS NULL
      THEN 0
      ELSE I.F_NUM_PALM_PAPILON
    END
  FROM T_SYS_INFO_CARD I
  WHERE I.SYS_DELETED  ='N'
  AND I.F_TYPE         ='01'
  AND I.F_EKC_REG_NUM IS NOT NULL
  );



CREATE OR REPLACE FORCE VIEW "EKC15"."V_EVIDENCE_DETAILS" ("SYS_ID", "F_FABULA", "F_TITLE", "F_COMMENT", "F_NUM", "F_IMPRSMT_OMP", "F_IMPRSMT_WHOM", "OMP_DISPLAY", "F_INPUT_TYPE", "F_REF_FIO")
AS
  SELECT "E"."SYS_ID",
    "E"."F_FABULA",
    "E"."F_TITLE",
    "E"."F_COMMENT",
    "E"."F_NUM",
    "E"."F_IMPRSMT_OMP",
    "E"."F_IMPRSMT_WHOM",
    "OMP"."F_OMP_NUM"
    ||' '
    ||TO_CHAR("OMP"."F_OMP_DATE", 'DD.MM.YYYY'),
    "E"."F_INPUT_TYPE",
    "E"."F_REF_FIO"
  FROM "T_SYS_EVIDENCE" "E",
    "T_SYS_OMP" "OMP"
  WHERE "E"."SYS_DELETED"    = 'N'
  AND "OMP"."SYS_DELETED"(+) = 'N'
  AND "OMP"."SYS_ID"(+)      = "E"."F_IMPRSMT_OMP"
  ORDER BY "E"."SYS_UPDATED" ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_EXPERTS_REPORT" ("SYS_ID", "USER_S", "REG_AREA", "REG_AREA_S", "A_ORDER", "REG_DATE", "IS_OMP", "IS_OMP_C", "IS_EXP", "IS_EXP_C", "IS_ISS", "IS_ISS_C", "IS_PROV", "IS_PROV_C", "IS_REVEL", "IS_UNION", "IS_SD", "IS_ORM", "REG_GROUP", "USER_ID", "PLUS_REZ")
                  AS
  SELECT T.sys_id AS SYS_ID,
    (O.F_LAST_NAME
    || ' '
    || O.F_FIRST_NAME
    || ' '
    || O.F_SECOND_NAME) AS USER_S,
    O.f_depart          AS REG_AREA,
    CASE
      WHEN O.f_depart IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN O.f_depart IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END            AS A_ORDER,
    OMP.F_OMP_DATE AS REG_DATE,
    CASE
      WHEN T.F_TYPE='S'
      THEN 1
      ELSE 0
    END AS IS_OMP,
    CASE
      WHEN T.F_TYPE='H'
      THEN 1
      ELSE 0
    END       AS IS_OMP_C,
    0         AS IS_EXP,
    0         AS IS_EXP_C,
    0         AS IS_ISS,
    0         AS IS_ISS_C,
    0         AS IS_PROV,
    0         AS IS_PROV_C,
    0         AS IS_REVEL,
    0         AS IS_UNION,
    0         AS IS_SD,
    0         AS IS_ORM,
    O.f_group AS REG_GROUP,
    O.SYS_ID  AS USER_ID,
    0         AS PLUS_REZ
  FROM T_SYS_OMP OMP,
    T_SYS_OMP_SPEC T,
    T_SYS_OPERATORS O
  WHERE OMP.sys_deleted = 'N'
  AND O.sys_deleted     = 'N'
  AND T.sys_deleted     = 'N'
  AND T.f_omp           = OMP.sys_id
  AND O.sys_id          = T.F_OPERATOR
  UNION
  SELECT EO.sys_id AS SYS_ID,
    (O.F_LAST_NAME
    || ' '
    || O.F_FIRST_NAME
    || ' '
    || O.F_SECOND_NAME) AS USER_S,
    O.f_depart          AS REG_AREA,
    CASE
      WHEN O.f_depart IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN O.f_depart IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END              AS A_ORDER,
    E.f_arrival_date AS REG_DATE,
    0                AS IS_OMP,
    0                AS IS_OMP_C,
    CASE
      WHEN E.F_EXPRT_TYPE='01'
      THEN 1
      ELSE 0
    END AS IS_EXP,
    CASE
      WHEN E.F_EXPRT_TYPE='01'
      AND E.F_END_DATE  IS NOT NULL
      THEN 1
      ELSE 0
    END AS IS_EXP_C,
    CASE
      WHEN E.F_EXPRT_TYPE='02'
      THEN 1
      ELSE 0
    END AS IS_ISS,
    CASE
      WHEN E.F_EXPRT_TYPE='02'
      AND E.F_END_DATE  IS NOT NULL
      THEN 1
      ELSE 0
    END       AS IS_ISS_C,
    0         AS IS_PROV,
    0         AS IS_PROV_C,
    0         AS IS_REVEL,
    0         AS IS_UNION,
    0         AS IS_SD,
    0         AS IS_ORM,
    O.f_group AS REG_GROUP,
    O.SYS_ID  AS USER_ID,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM T_SYS_EXPERTZ_FIO_LINKS L
        WHERE L.SYS_DELETED='N'
        AND L.F_LINK_TYPE <> 'N'
        AND L.F_REF_EXPERTZ=E.SYS_ID
        )
      THEN 1
      ELSE 0
    END AS PLUS_REZ
  FROM T_SYS_EXPERTZ E,
    T_SYS_OPERATORS O,
    T_SYS_EXPERTZ_SPEC EO
  WHERE E.sys_deleted = 'N'
  AND O.sys_deleted   = 'N'
  AND EO.sys_deleted  = 'N'
  AND O.sys_id        = EO.f_operator
  AND E.sys_id        = EO.f_ref_expertz
  UNION
  SELECT REV.sys_id AS SYS_ID,
    (O.F_LAST_NAME
    || ' '
    || O.F_FIRST_NAME
    || ' '
    || O.F_SECOND_NAME) AS USER_S,
    O.f_depart          AS REG_AREA,
    CASE
      WHEN O.f_depart IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN O.f_depart IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END        AS A_ORDER,
    REV.f_date AS REG_DATE,
    0          AS IS_OMP,
    0          AS IS_OMP_C,
    0          AS IS_EXP,
    0          AS IS_EXP_C,
    0          AS IS_ISS,
    0          AS IS_ISS_C,
    0          AS IS_PROV,
    0          AS IS_PROV_C,
    CASE
      WHEN REV.F_REVEL_TYPE='U'
      THEN 0
      ELSE 1
    END AS IS_REVEL,
    CASE
      WHEN REV.F_REVEL_TYPE='U'
      THEN 1
      ELSE 0
    END       AS IS_UNION,
    0         AS IS_SD,
    0         AS IS_ORM,
    O.f_group AS REG_GROUP,
    O.SYS_ID  AS USER_ID,
    0         AS PLUS_REZ
  FROM T_SYS_REVELATION REV,
    T_SYS_OPERATORS O
  WHERE REV.sys_deleted = 'N'
  AND O.sys_deleted     = 'N'
  AND O.sys_id          = REV.f_operator
  UNION
  SELECT REVCP.sys_id AS SYS_ID,
    (O.F_LAST_NAME
    || ' '
    || O.F_FIRST_NAME
    || ' '
    || O.F_SECOND_NAME) AS USER_S,
    O.f_depart          AS REG_AREA,
    CASE
      WHEN O.f_depart IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN O.f_depart IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END          AS A_ORDER,
    REVCP.f_date AS REG_DATE,
    0            AS IS_OMP,
    0            AS IS_OMP_C,
    0            AS IS_EXP,
    0            AS IS_EXP_C,
    0            AS IS_ISS,
    0            AS IS_ISS_C,
    0            AS IS_PROV,
    0            AS IS_PROV_C,
    CASE
      WHEN REVCP.F_REVEL_TYPE='U'
      THEN 0
      ELSE 1
    END AS IS_REVEL,
    CASE
      WHEN REVCP.F_REVEL_TYPE='U'
      THEN 1
      ELSE 0
    END       AS IS_UNION,
    0         AS IS_SD,
    0         AS IS_ORM,
    O.f_group AS REG_GROUP,
    O.SYS_ID  AS USER_ID,
    0         AS PLUS_REZ
  FROM T_SYS_CP_REVELATION REVCP,
    T_SYS_OPERATORS O
  WHERE REVCP.sys_deleted = 'N'
  AND O.sys_deleted       = 'N'
  AND O.sys_id            = REVCP.f_operator
  UNION
  SELECT SDORM.sys_id AS SYS_ID,
    (O.F_LAST_NAME
    || ' '
    || O.F_FIRST_NAME
    || ' '
    || O.F_SECOND_NAME) AS USER_S,
    O.f_depart          AS REG_AREA,
    CASE
      WHEN O.f_depart IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN O.f_depart IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END               AS A_ORDER,
    SDORM.f_exec_date AS REG_DATE,
    0                 AS IS_OMP,
    0                 AS IS_OMP_C,
    0                 AS IS_EXP,
    0                 AS IS_EXP_C,
    0                 AS IS_ISS,
    0                 AS IS_ISS_C,
    0                 AS IS_PROV,
    0                 AS IS_PROV_C,
    0                 AS IS_REVEL,
    0                 AS IS_UNION,
    CASE
      WHEN SDORM.F_TYPE = 'S'
      THEN 1
      ELSE 0
    END AS IS_SD,
    CASE
      WHEN SDORM.F_TYPE = 'O'
      THEN 1
      ELSE 0
    END       AS IS_ORM,
    O.f_group AS REG_GROUP,
    O.SYS_ID  AS USER_ID,
    0         AS PLUS_REZ
  FROM T_SYS_SD_ORM SDORM,
    T_SYS_OPERATORS O
  WHERE SDORM.sys_deleted = 'N'
  AND O.sys_deleted       = 'N'
  AND O.sys_id            = SDORM.f_ekc_exectr
  UNION
  SELECT CH.sys_id AS SYS_ID,
    (O.F_LAST_NAME
    || ' '
    || O.F_FIRST_NAME
    || ' '
    || O.F_SECOND_NAME) AS USER_S,
    O.f_depart          AS REG_AREA,
    CASE
      WHEN O.f_depart IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN O.f_depart IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END               AS A_ORDER,
    CH.f_receive_date AS REG_DATE,
    0                 AS IS_OMP,
    0                 AS IS_OMP_C,
    0                 AS IS_EXP,
    0                 AS IS_EXP_C,
    0                 AS IS_ISS,
    0                 AS IS_ISS_C,
    1                 AS IS_PROV,
    0                 AS IS_PROV_C,
    0                 AS IS_REVEL,
    0                 AS IS_UNION,
    0                 AS IS_SD,
    0                 AS IS_ORM,
    O.f_group         AS REG_GROUP,
    O.SYS_ID          AS USER_ID,
    0                 AS PLUS_REZ
  FROM T_SYS_PHOTO_FOLDER CH,
    T_SYS_OPERATORS O
  WHERE CH.sys_deleted = 'N'
  AND O.sys_deleted    = 'N'
  AND O.sys_id         = CH.f_operator
  UNION
  SELECT CP.sys_id AS SYS_ID,
    (O.F_LAST_NAME
    || ' '
    || O.F_FIRST_NAME
    || ' '
    || O.F_SECOND_NAME) AS USER_S,
    O.f_depart          AS REG_AREA,
    CASE
      WHEN O.f_depart IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN O.f_depart IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE O.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END AS A_ORDER,
    CASE
      WHEN O.f_depart='07'
      THEN CP.f_ekc_ch_date
      ELSE CP.f_ekp_ch_date
    END       AS REG_DATE,
    0         AS IS_OMP,
    0         AS IS_OMP_C,
    0         AS IS_EXP,
    0         AS IS_EXP_C,
    0         AS IS_ISS,
    0         AS IS_ISS_C,
    0         AS IS_PROV,
    1         AS IS_PROV_C,
    0         AS IS_REVEL,
    0         AS IS_UNION,
    0         AS IS_SD,
    0         AS IS_ORM,
    O.f_group AS REG_GROUP,
    O.SYS_ID  AS USER_ID,
    0         AS PLUS_REZ
  FROM T_SYS_INFO_CARD_CP CP,
    T_SYS_OPERATORS O
  WHERE CP.sys_deleted = 'N'
  AND O.sys_deleted    = 'N'
  AND (O.sys_id        = CP.f_ekc_checker
  OR O.sys_id          = CP.f_ekp_checker);



CREATE OR REPLACE FORCE VIEW "EKC15"."V_EXPERTZ_RESLT_DACT" ("SYS_ID", "SYS_USER_ID", "F_NO_USEFUL", "F_USEFUL_N", "F_VICTIM_N", "F_VICTIM_TEXT", "F_SUSPECTED_N", "F_SUSPECTED_TEXT", "F_UNKNOWN_N", "RESULT_TEXT")
AS
  SELECT e.sys_id,
    e.sys_user_id,
    e.f_reslt_flag1,
    e.f_reslt_number1,
    e.f_reslt_number2,
    e.f_reslt_text2,
    e.f_reslt_number3,
    e.f_reslt_text3,
    e.f_reslt_number1 - (
    CASE
      WHEN EXISTS
        (SELECT *
        FROM t_sys_expertz_fio_links l
        WHERE l.f_ref_expertz = e.sys_id
        AND l.sys_deleted     = 'N'
        )
      THEN
        (SELECT SUM (l.f_number_traces)
        FROM t_sys_expertz_fio_links l
        WHERE l.f_ref_expertz = e.sys_id
        AND l.sys_deleted     = 'N'
        )
      ELSE 0
    END ),
    e.f_reslt_text1
  FROM t_sys_expertz e
  WHERE e.sys_deleted = 'N'
  AND e.f_exprt_genus = '09' ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_EXPERTZ_RESLT_TRACE" ("SYS_ID", "SYS_USER_ID", "RESULT_TEXT", "DICT_VID", "F_NO_USEFUL", "F_USEFUL_N", "NUM_CATEGORY1", "NUM_CATEGORY2", "NUM_CATEGORY3", "F_NPV", "F_FLAG_LIST")
AS
  SELECT sys_id,
    sys_user_id,
    f_reslt_text1,
    f_reslt_dic1,
    F_RESLT_FLAG1,
    F_RESLT_NUMBER1,
    F_RESLT_NUMBER2,
    F_RESLT_NUMBER3,
    F_RESLT_NUMBER4,
    F_RESLT_TEXT2,
    F_RESLT_TEXT3
  FROM t_sys_expertz
  WHERE sys_deleted = 'N'
  AND f_exprt_genus = '16' ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_EXPERTZ_SUMMARY" ("FABULA_ID", "EXP_GENUS", "EXP_GENUS_S", "C1", "C2", "C3", "C4", "IK")
AS
  SELECT FAB.SYS_ID,
    D.F_CODE,
    D.F_MEAN,
    (SELECT COUNT(*) CNT
    FROM T_SYS_EXPERTZ E1
    WHERE E1.f_ref_fabula     = FAB.SYS_ID
    AND E1.F_EXPRT_GENUS      = D.F_CODE
    AND E1.f_arrival_date    IS NOT NULL
    AND E1.f_start_date      IS NULL
    AND E1.f_end_date        IS NULL
    AND E1.f_conclusion_date IS NULL
    ),
    (SELECT COUNT(*) CNT
    FROM T_SYS_EXPERTZ E1
    WHERE E1.f_ref_fabula     = FAB.SYS_ID
    AND E1.F_EXPRT_GENUS      = D.F_CODE
    AND E1.f_start_date      IS NOT NULL
    AND E1.f_end_date        IS NULL
    AND E1.f_conclusion_date IS NULL
    ),
    (SELECT COUNT(*) CNT
    FROM T_SYS_EXPERTZ E1
    WHERE E1.f_ref_fabula     = FAB.SYS_ID
    AND E1.F_EXPRT_GENUS      = D.F_CODE
    AND E1.f_end_date        IS NOT NULL
    AND E1.f_conclusion_date IS NULL
    ),
    (SELECT COUNT(*) CNT
    FROM T_SYS_EXPERTZ E1
    WHERE E1.f_ref_fabula     = FAB.SYS_ID
    AND E1.F_EXPRT_GENUS      = D.F_CODE
    AND E1.f_conclusion_date IS NOT NULL
    ),
    (SELECT COUNT(*) CNT
    FROM T_SYS_INFO_CARD I,
      T_SYS_EXPERTZ E1
    WHERE E1.F_REF_FABULA = FAB.SYS_ID
    AND E1.F_EXPRT_GENUS  = D.F_CODE
    AND I.F_REF_EXPERTZ   = E1.sys_id
    AND I.SYS_DELETED     = 'N'
    )
  FROM T_SYS_FABULA FAB,
    T_DIC_MAIN D
  WHERE FAB.SYS_DELETED = 'N'
  AND D.SYS_DELETED     = 'N'
  AND D.F_DOMAIN        = 'ImprssmntExprt'
  AND EXISTS
    (SELECT *
    FROM T_SYS_EXPERTZ EX
    WHERE EX.SYS_DELETED = 'N'
    AND EX.F_EXPRT_GENUS = D.F_CODE
    AND EX.F_REF_FABULA  = FAB.SYS_ID
    ) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_EXPERTZ_SUMMARY_NEW" ("FABULA_ID", "EXP_TYPE", "EXP_GENUS", "EXP_GENUS_S", "C1", "C2", "C3", "C4", "C5")
AS
  SELECT FAB.SYS_ID FABULA_ID,
    EX.f_exprt_type EXP_TYPE,
    D.F_CODE EXP_GENUS,
    D.F_MEAN EXP_GENUS_S,
    SUM(
    CASE
      WHEN (EX.F_ARRIVAL_DATE  IS NOT NULL
      AND EX.F_START_DATE      IS NULL
      AND EX.F_END_DATE        IS NULL
      AND EX.F_CONCLUSION_DATE IS NULL)
      THEN 1
      ELSE 0
    END) C1,
    SUM(
    CASE
      WHEN (EX.F_START_DATE    IS NOT NULL
      AND EX.F_END_DATE        IS NULL
      AND EX.F_CONCLUSION_DATE IS NULL)
      THEN 1
      ELSE 0
    END) C2,
    SUM(
    CASE
      WHEN (EX.F_END_DATE      IS NOT NULL
      AND EX.F_CONCLUSION_DATE IS NULL)
      THEN 1
      ELSE 0
    END) C3,
    SUM(
    CASE
      WHEN (EX.F_CONCLUSION_DATE IS NOT NULL)
      THEN 1
      ELSE 0
    END) C4,
    SUM(
    (SELECT COUNT(*)
    FROM T_SYS_INFO_CARD I
    WHERE I.F_REF_EXPERTZ=EX.sys_id
    AND I.SYS_DELETED    ='N'
    )) C5
  FROM T_SYS_FABULA FAB,
    T_DIC_MAIN D,
    T_SYS_EXPERTZ EX
  WHERE FAB.SYS_DELETED='N'
  AND D.F_DOMAIN       ='ImprssmntExprt'
  AND D.SYS_DELETED    ='N'
  AND EX.F_REF_FABULA  =FAB.SYS_ID
  AND EX.F_EXPRT_GENUS =D.F_CODE
  AND EX.SYS_DELETED   ='N'
  GROUP BY FAB.SYS_ID,
    EX.f_exprt_type,
    D.F_CODE,
    D.F_MEAN ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_EXPRTZ" ("SYS_ID", "F_REG_NUM", "F_ARRIVAL_DATE", "F_TYPE_S", "F_REF_FABULA", "F_EXPRT_GENUS", "F_GENUS_S", "F_STATUS_S", "NUM_IK")
AS
  SELECT e.sys_id,
    e.f_reg_num,
    e.f_arrival_date,
    type_dic.f_mean,
    e.f_ref_fabula,
    e.f_exprt_genus,
    genus_dic.f_mean,
    CASE
      WHEN e.F_CONCLUSION_DATE IS NOT NULL
      THEN
        (SELECT estatus.F_MEAN
        FROM t_dic_main estatus
        WHERE estatus.f_domain = 'ExperimentStatus'
        AND estatus.f_code     = '04'
        )
      ELSE
        CASE
          WHEN e.F_END_DATE IS NOT NULL
          THEN
            (SELECT estatus.F_MEAN
            FROM t_dic_main estatus
            WHERE estatus.f_domain = 'ExperimentStatus'
            AND estatus.f_code     = '03'
            )
          ELSE
            CASE
              WHEN e.F_START_DATE IS NOT NULL
              THEN
                (SELECT estatus.F_MEAN
                FROM t_dic_main estatus
                WHERE estatus.f_domain = 'ExperimentStatus'
                AND estatus.f_code     = '02'
                )
              ELSE
                (SELECT estatus.F_MEAN
                FROM t_dic_main estatus
                WHERE estatus.f_domain = 'ExperimentStatus'
                AND estatus.f_code     = '01'
                )
            END
        END
    END,
    (SELECT COUNT(*)
    FROM T_SYS_INFO_CARD
    WHERE F_REF_EXPERTZ=e.sys_id
    AND SYS_DELETED    ='N'
    )
  FROM t_sys_expertz e,
    t_dic_main type_dic,
    t_dic_main genus_dic
  WHERE e.sys_deleted        = 'N'
  AND (type_dic.f_domain(+)  = 'Type-explore'
  AND type_dic.f_code(+)     = e.f_exprt_type)
  AND (genus_dic.f_domain(+) = 'ImprssmntExprt'
  AND genus_dic.f_code(+)    = e.f_exprt_genus) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_FABULA" ("SYS_ID", "F_DATE", "F_NDELA", "F_OM", "F_KUSP", "F_FANCY_ADDR")
AS
  SELECT F.SYS_ID,
    F.F_DATE,
    F.F_N_DELA,
    F.F_OM,
    F.F_KUSP,
    D_TOWN.F_MEAN
    || ', '
    || D_AREA.F_MEAN
    || ', '
    || D_STREET.F_MEAN
    || ', '
    || A.F_DOM
    || '-'
    || A.F_KORP
    || '-'
    || A.F_KVART
  FROM FABULA F,
    ADDRESS A,
    DICTIONARIES D_TOWN,
    DICTIONARIES D_AREA,
    DICTIONARIES D_STREET
  WHERE F.SYS_DELETED        = 'N'
  AND F.F_ADDR               = A.SYS_ID
  AND ((D_TOWN.F_DOMAIN(+)   = 'Cities')
  AND (D_TOWN.F_CODE(+)      = A.F_TOWN))
  AND ((D_AREA.F_DOMAIN(+)   = 'Area')
  AND (D_AREA.F_CODE(+)      = A.F_AREA))
  AND ((D_STREET.F_DOMAIN(+) = 'Streets')
  AND (D_STREET.F_CODE(+)    = A.F_STREET)) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_FABULA_DETAILS" ("P_SYS_ID", "SYS_UPDATED", "P_REG_AREA", "P_KAT_DELA", "P_DATE_REG", "P_DATE_REG_S", "P_DATE_PREST", "P_DATE_PREST_S", "P_KUSP_DATE", "P_KUSP_DATE_S", "P_N_DELA", "P_OM", "P_KUSP", "P_ADDR_EXT", "P_ADDR_EXT_TEXT", "P_VID_PREST", "P4_VID_PREST", "P_REGION", "P_TOWN", "P_AREA", "P_STREET", "P_DOM", "P_KORP", "P_KVART", "P_COMMENT", "P_ADDR_SYS_ID", "P_UK_NUMBER", "P_IN_NUMBER", "P_IN_DATE", "P_IN_DATE_S", "P_USER_ID", "P_SPOSOB", "P_AREA_S", "P_VID_PREST_S", "P4_VID_PREST_S", "P_SPOSOB_S")
AS
  SELECT f.sys_id,
    f.sys_updated,
    f.f_reg_area,
    f.f_kat_dela,
    f.f_reg_date,
    TO_CHAR (f.f_reg_date, 'DD.MM.YYYY'),
    f.f_date,
    TO_CHAR (f.f_date, 'DD.MM.YYYY'),
    f.f_kusp_date,
    TO_CHAR (f.f_kusp_date, 'DD.MM.YYYY'),
    f.f_n_dela,
    f.f_om,
    f.f_kusp,
    f.f_addr_ext,
    f.f_addr_ext_text,
    f.f_vid_prest,
    f.f_main_vid_prest,
    a.f_region,
    a.f_town,
    a.f_area,
    a.f_street,
    a.f_dom,
    a.f_korp,
    a.f_kvart,
    f.f_comments,
    f.f_addr,
    f.f_uk_number,
    f.f_in_number,
    f.f_in_date,
    TO_CHAR (f.f_in_date, 'DD.MM.YYYY'),
    f.sys_user_id,
    f.f_sposob,
    (SELECT f_mean FROM t_dic_main WHERE f_domain='Area' AND f_code=a.f_area
    ),
    (SELECT f_mean
    FROM t_dic_main
    WHERE f_domain='PrecisedIncident'
    AND f_code    =f.f_vid_prest
    ),
    (SELECT f_mean
    FROM t_dic_main
    WHERE f_domain='Incident'
    AND f_code    =f.f_main_vid_prest
    ),
    (SELECT f_mean
    FROM t_dic_main
    WHERE f_domain='Enter_methods'
    AND f_code    =f.f_sposob
    )
  FROM fabula f,
    address a
  WHERE (f.sys_deleted = 'N')
  AND (f.f_addr        = a.sys_id) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_INFORMATION_CARD" ("SYS_ID", "SYS_DELETED", "SYS_USER_ID", "F_INIT_REG_DATE", "F_INIT_REG_NUM", "F_EKC_REG_DATE", "F_EKC_REG_NUM", "F_EKP_REG_DATE", "F_EKP_REG_NUM", "F_REF_EXPERTZ", "F_TYPE", "F_SUBTYPE", "F_OM", "F_KUSP", "F_N_DELA", "F_REGION", "F_REG_AREA", "F_VID_PREST", "F_MAIN_VID_PREST", "F_UK_NUMBER", "P_LINE_CODE", "P_OVD_CODE", "P_EKC_REG_YEAR", "P_EKP_REG_YEAR", "F_DATE", "F_TOWN", "F_STREET", "F_DOM", "F_KORP", "F_KVART", "P_EKCEKP_FIO", "P_EKCEKP_DATE", "P_EKCEKP_NUMBER", "P_GIACP_FIO", "P_GIACP_DATE", "P_GIACP_NUMBER", "P_SP_FIO", "P_SP_DATE", "P_SP_NUMBER", "P_UNREG_REASON", "P_UNREG_DATE", "P_UNREG_NUMBER", "F_EKP", "F_EKC", "F_DATE_IK", "F_EXP_NUM", "P_COMMENTS", "P_NUM_TOTAL", "P_NUM_FINGER", "P_NUM_PALM", "P_NUM_FINGER_PAPILON", "P_NUM_PALM_PAPILON", "P_FABULA_ID", "P_SEND_DEPART", "P_INIT_DEPART", "P_REF_OMP")
AS
  SELECT CARD.SYS_ID SYS_ID,
    CARD.SYS_DELETED SYS_DELETED,
    CARD.SYS_USER_ID SYS_USER_ID,
    CARD.F_PRODACTION_DATE F_INIT_REG_DATE,
    NVL(CARD.F_PRODACTION_NUM,' ') F_INIT_REG_NUM,
    CARD.F_EKC_REG_DATE F_EKC_REG_DATE,
    CARD.F_EKC_REG_NUM F_EKC_REG_NUM,
    CARD.F_EKP_REG_DATE F_EKP_REG_DATE,
    CARD.F_EKP_REG_NUM F_EKP_REG_NUM,
    CARD.F_REF_EXPERTZ F_REF_EXPERTZ,
    CARD.F_TYPE F_TYPE,
    CARD.F_SUBTYPE F_SUBTYPE,
    FAB.F_OM F_OM,
    FAB.F_KUSP F_KUSP,
    FAB.F_N_DELA F_N_DELA,
    ADDR.F_REGION F_REGION,
    FAB.F_REG_AREA F_REG_AREA,
    FAB.F_VID_PREST F_VID_PREST,
    FAB.F_MAIN_VID_PREST F_MAIN_VID_PREST,
    FAB.F_UK_NUMBER F_UK_NUMBER,
    CARD.F_LINE_CODE P_LINE_CODE,
    CARD.F_OVD_CODE P_OVD_CODE,
    CARD.F_EKC_REG_YEAR P_EKC_REG_YEAR,
    CARD.F_EKP_REG_YEAR P_EKP_REG_YEAR,
    TO_CHAR(FAB.F_DATE,'DD.MM.YYYY') F_DATE,
    ADDR.F_TOWN F_TOWN,
    ADDR.F_STREET F_STREET,
    ADDR.F_DOM F_DOM,
    ADDR.F_KORP F_KORP,
    ADDR.F_KVART F_KVART,
    CARD.F_EKCEKP_FIO P_EKCEKP_FIO,
    CARD.F_EKCEKP_DATE P_EKCEKP_DATE,
    CARD.F_EKCEKP_NUMBER P_EKCEKP_NUMBER,
    CARD.F_GIACP_FIO P_GIACP_FIO,
    CARD.F_GIACP_DATE P_GIACP_DATE,
    CARD.F_GIACP_NUMBER P_GIACP_NUMBER,
    CARD.F_SP_FIO P_SP_FIO,
    CARD.F_SP_DATE P_SP_DATE,
    CARD.F_SP_NUMBER P_SP_NUMBER,
    CARD.F_UNREG_REASON P_UNREG_REASON,
    CARD.F_UNREG_DATE P_UNREG_DATE,
    CARD.F_UNREG_NUMBER P_UNREG_NUMBER,
    CARD.F_EKP_DEPART F_EKP,
    CARD.F_EKC_DEPART F_EKC,
    TO_CHAR(EXPZ.F_END_DATE,'DD.MM.YYYY') F_DATE_IK,
    EXPZ.F_REG_NUM F_EXP_NUM,
    CARD.F_COMMENTS P_COMMENTS,
    CARD.F_NUM_TOTAL P_NUM_TOTAL,
    CARD.F_NUM_FINGER P_NUM_FINGER,
    CARD.F_NUM_PALM P_NUM_PALM,
    CARD.F_NUM_FINGER_PAPILON P_NUM_FINGER_PAPILON,
    CARD.F_NUM_PALM_PAPILON P_NUM_PALM_PAPILON,
    FAB.SYS_ID P_FABULA_ID,
    CASE
      WHEN to_number(EXPZ.F_EKC_AREA)<11
      THEN CARD.F_EKP_DEPART
      ELSE CARD.F_EKC_DEPART
    END P_SEND_DEPART,
    CASE
      WHEN to_number(EXPZ.F_EKC_AREA)<11
      THEN CARD.F_EKC_DEPART
      ELSE CARD.F_EKP_DEPART
    END P_INIT_DEPART,
    CARD.F_REF_OMP P_REF_OMP
  FROM T_SYS_INFO_CARD CARD,
    T_SYS_EXPERTZ EXPZ,
    T_SYS_FABULA FAB,
    T_DIC_ADDRESS ADDR
  WHERE CARD.SYS_DELETED = 'N'
  AND FAB.SYS_DELETED    = 'N'
  AND EXPZ.SYS_DELETED   = 'N'
  AND CARD.F_REF_EXPERTZ = EXPZ.SYS_ID
  AND EXPZ.F_REF_FABULA  = FAB.sys_id
  AND FAB.F_ADDR         = ADDR.SYS_ID ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_INPUTS_REPORT" ("SYS_ID", "USER_S", "REG_AREA", "REG_AREA_S", "A_ORDER", "REG_DATE", "IS_FABULA", "IS_OMP", "IS_EXP", "IS_ISS", "IS_IK", "IS_REVEL")
                  AS
  SELECT F.sys_id AS SYS_ID,
    (SELECT O.F_LAST_NAME
      || ' '
      || O.F_FIRST_NAME
      || ' '
      || O.F_SECOND_NAME
    FROM T_SYS_OPERATORS O
    WHERE O.sys_id = F.SYS_USER_ID
    )            AS USER_S,
    F.f_reg_area AS REG_AREA,
    CASE
      WHEN F.f_reg_area IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE F.f_reg_area=D.f_code
        AND D.f_domain    ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN F.f_reg_area IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE F.f_reg_area=D.f_code
        AND D.f_domain    ='Regions-EKC'
        )
    END           AS A_ORDER,
    F.sys_updated AS REG_DATE,
    1             AS IS_FABULA,
    0             AS IS_OMP,
    0             AS IS_EXP,
    0             AS IS_ISS,
    0             AS IS_IK,
    0             AS IS_REVEL
  FROM T_SYS_FABULA F
  WHERE F.sys_deleted = 'N'
  UNION
  SELECT L.sys_id AS SYS_ID,
    (SELECT O.F_LAST_NAME
      || ' '
      || O.F_FIRST_NAME
      || ' '
      || O.F_SECOND_NAME
    FROM T_SYS_OPERATORS O
    WHERE O.sys_id = OMP.SYS_USER_ID
    )          AS USER_S,
    L.f_depart AS REG_AREA,
    CASE
      WHEN L.f_depart IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE L.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN L.f_depart IS NULL
      THEN ''
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE L.f_depart=D.f_code
        AND D.f_domain  ='Regions-EKC'
        )
    END           AS A_ORDER,
    L.sys_updated AS REG_DATE,
    0             AS IS_FABULA,
    1             AS IS_OMP,
    0             AS IS_EXP,
    0             AS IS_ISS,
    0             AS IS_IK,
    0             AS IS_REVEL
  FROM T_SYS_OMP OMP,
    T_SYS_JOURNAL_OMP L
  WHERE OMP.sys_deleted = 'N'
  AND L.sys_deleted     = 'N'
  AND L.f_ref_omp       = OMP.sys_id
  UNION
  SELECT E.sys_id AS SYS_ID,
    (SELECT O.F_LAST_NAME
      || ' '
      || O.F_FIRST_NAME
      || ' '
      || O.F_SECOND_NAME
    FROM T_SYS_OPERATORS O
    WHERE O.sys_id = E.SYS_USER_ID
    )            AS USER_S,
    E.f_ekc_area AS REG_AREA,
    CASE
      WHEN E.f_ekc_area IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE E.f_ekc_area=D.f_code
        AND D.f_domain    ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN E.f_ekc_area IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE E.f_ekc_area=D.f_code
        AND D.f_domain    ='Regions-EKC'
        )
    END           AS A_ORDER,
    E.sys_updated AS REG_DATE,
    0             AS IS_FABULA,
    0             AS IS_OMP,
    CASE
      WHEN E.f_exprt_type='01'
      THEN 1
      ELSE 0
    END AS IS_EXP,
    CASE
      WHEN E.f_exprt_type='02'
      THEN 1
      ELSE 0
    END AS IS_ISS,
    0   AS IS_IK,
    0   AS IS_REVEL
  FROM T_SYS_EXPERTZ E
  WHERE E.sys_deleted = 'N'
  UNION
  SELECT IK.sys_id AS SYS_ID,
    (SELECT O.F_LAST_NAME
      || ' '
      || O.F_FIRST_NAME
      || ' '
      || O.F_SECOND_NAME
    FROM T_SYS_OPERATORS O
    WHERE O.sys_id = IK.SYS_USER_ID
    )               AS USER_S,
    IK.f_ekc_depart AS REG_AREA,
    (SELECT D.f_mean
    FROM T_DIC_MAIN D
    WHERE IK.f_ekc_depart=D.f_code
    AND D.f_domain       ='Regions-EKC'
    ) AS REG_AREA_S,
    (SELECT D.f_order
    FROM T_DIC_MAIN D
    WHERE IK.f_ekc_depart=D.f_code
    AND D.f_domain       ='Regions-EKC'
    )                 AS A_ORDER,
    IK.f_ekc_reg_date AS REG_DATE,
    0                 AS IS_FABULA,
    0                 AS IS_OMP,
    0                 AS IS_EXP,
    0                 AS IS_ISS,
    1                 AS IS_IK,
    0                 AS IS_REVEL
  FROM T_SYS_INFO_CARD IK
  WHERE IK.sys_deleted   = 'N'
  AND IK.f_ekc_reg_date IS NOT NULL
  AND IK.f_ekc_depart   IS NOT NULL
  UNION
  SELECT IK.sys_id AS SYS_ID,
    (SELECT O.F_LAST_NAME
      || ' '
      || O.F_FIRST_NAME
      || ' '
      || O.F_SECOND_NAME
    FROM T_SYS_OPERATORS O
    WHERE O.sys_id = IK.SYS_USER_ID
    )               AS USER_S,
    IK.f_ekp_depart AS REG_AREA,
    (SELECT D.f_mean
    FROM T_DIC_MAIN D
    WHERE IK.f_ekp_depart=D.f_code
    AND D.f_domain       ='Regions-EKC'
    ) AS REG_AREA_S,
    (SELECT D.f_order
    FROM T_DIC_MAIN D
    WHERE IK.f_ekp_depart=D.f_code
    AND D.f_domain       ='Regions-EKC'
    )                 AS A_ORDER,
    IK.f_ekp_reg_date AS REG_DATE,
    0                 AS IS_FABULA,
    0                 AS IS_OMP,
    0                 AS IS_EXP,
    0                 AS IS_ISS,
    1                 AS IS_IK,
    0                 AS IS_REVEL
  FROM T_SYS_INFO_CARD IK
  WHERE IK.sys_deleted   = 'N'
  AND IK.f_ekp_reg_date IS NOT NULL
  AND IK.f_ekp_depart   IS NOT NULL
  UNION
  SELECT IK.sys_id AS SYS_ID,
    (SELECT O.F_LAST_NAME
      || ' '
      || O.F_FIRST_NAME
      || ' '
      || O.F_SECOND_NAME
    FROM T_SYS_OPERATORS O
    WHERE O.sys_id = IK.SYS_USER_ID
    )             AS USER_S,
    IK.f_reg_area AS REG_AREA,
    CASE
      WHEN IK.f_reg_area IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE IK.f_reg_area=D.f_code
        AND D.f_domain     ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN IK.f_reg_area IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE IK.f_reg_area=D.f_code
        AND D.f_domain     ='Regions-EKC'
        )
    END           AS A_ORDER,
    IK.f_reg_date AS REG_DATE,
    0             AS IS_FABULA,
    0             AS IS_OMP,
    0             AS IS_EXP,
    0             AS IS_ISS,
    1             AS IS_IK,
    0             AS IS_REVEL
  FROM T_SYS_INFO_CARD_CP IK
  WHERE IK.sys_deleted = 'N'
  UNION
  SELECT REV.sys_id AS SYS_ID,
    (SELECT O.F_LAST_NAME
      || ' '
      || O.F_FIRST_NAME
      || ' '
      || O.F_SECOND_NAME
    FROM T_SYS_OPERATORS O
    WHERE O.sys_id = REV.SYS_USER_ID
    )              AS USER_S,
    REV.f_reg_area AS REG_AREA,
    CASE
      WHEN REV.f_reg_area IS NULL
      THEN ''
      ELSE
        (SELECT D.f_mean
        FROM T_DIC_MAIN D
        WHERE REV.f_reg_area=D.f_code
        AND D.f_domain      ='Regions-EKC'
        )
    END AS REG_AREA_S,
    CASE
      WHEN REV.f_reg_area IS NULL
      THEN '99'
      ELSE
        (SELECT D.f_order
        FROM T_DIC_MAIN D
        WHERE REV.f_reg_area=D.f_code
        AND D.f_domain      ='Regions-EKC'
        )
    END        AS A_ORDER,
    REV.f_date AS REG_DATE,
    0          AS IS_FABULA,
    0          AS IS_OMP,
    0          AS IS_EXP,
    0          AS IS_ISS,
    0          AS IS_IK,
    1          AS IS_REVEL
  FROM T_SYS_REVELATION REV
  WHERE REV.sys_deleted = 'N'
  AND REV.f_revel_type  = 'R' ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_OPERATORS" ("SYS_ID", "F_FIRST_NAME", "F_SECOND_NAME", "F_LAST_NAME", "F_LOGIN", "F_DEP", "F_GRP", "F_POS", "F_RNK")
AS
  SELECT so.sys_id,
    so.F_FIRST_NAME,
    so.F_SECOND_NAME,
    so.F_LAST_NAME,
    so.F_LOGIN,
    dic_dep.f_mean  AS f_DEP,
    dic_grp.f_mean  AS GRP,
    dic_pos.f_mean  AS POS,
    dic_rank.f_mean AS RNK
  FROM t_sys_operators so,
    t_dic_main dic_dep,
    t_dic_main dic_grp,
    t_dic_main dic_pos,
    t_dic_main dic_rank
  WHERE ((dic_dep.f_domain(+)='Regions-EKC')
  AND (dic_dep.f_code(+)     =so.f_depart))
  AND ((dic_grp.f_domain(+)  ='EKC-Groups')
  AND (dic_grp.f_code(+)     =so.f_group))
  AND ((dic_pos.f_domain(+)  ='Position')
  AND (dic_pos.f_code(+)     =so.f_position))
  AND ((dic_rank.f_domain(+) ='Rank')
  AND (dic_rank.f_code(+)    =so.f_rank))
  AND ((so.sys_readonly      ='N')
  AND (so.sys_deleted        ='N')) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_REGION_REPORT" ("SYS_ID", "REGION_CODE", "REGION", "EVENT_DATE", "ANOTHER_SD", "EXPERTIZE", "OMP_FILLED", "OMP_EMPTY", "OMP_EV_SPEC", "OMP_EV_09", "OMP_EV_16", "OMP_EV_02", "OMP_EV_INO", "OMP_EV_1601", "OMP_EV_160203", "OMP_EV_1606", "OMP_EV_1604", "OMP_EV_DRTR", "OMP_EV_02_12", "OMP_EV_02_345", "OMP_EV_02_6", "CRIME", "VID_58", "VID_5602", "VID_DTP", "NEXT_SD")
AS
  (
  -- Another SD:
  SELECT "SD"."SYS_ID",
    "D"."F_CODE",
    "D"."F_MEAN",
    "SD"."F_EXEC_DATE",
    1,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    CASE
      WHEN ("F"."F_N_DELA" IS NOT NULL
      AND "F"."F_KAT_DELA"  = '1')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_MAIN_VID_PREST" = '58')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_VID_PREST" = '56-02')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_MAIN_VID_PREST" = '40'
      OR "F"."F_MAIN_VID_PREST"    = '41'
      OR "F"."F_MAIN_VID_PREST"    = '42'
      OR "F"."F_MAIN_VID_PREST"    = '43'
      OR "F"."F_MAIN_VID_PREST"    = '44'
      OR "F"."F_MAIN_VID_PREST"    = '60')
      THEN 1
      ELSE 0
    END,
    0
  FROM "T_DIC_MAIN" "D",
    "T_SYS_SD_ORM" "SD",
    "T_SYS_FABULA" "F"
  WHERE ("D"."F_DOMAIN"    = 'Regions-EKC')
  AND ("D"."SYS_DELETED"   = 'N')
  AND ("SD"."F_TYPE"       = 'S')
  AND ("SD"."SYS_DELETED"  = 'N')
  AND ("SD"."F_REG_AREA"   = "D"."F_CODE")
  AND ("F"."SYS_DELETED"   = 'N')
  AND ("SD"."F_REF_FABULA" = "F"."SYS_ID")
  -- OMPs:
  UNION
  SELECT "SD"."SYS_ID",
    "D"."F_CODE",
    "D"."F_MEAN",
    "SD"."F_OMP_DATE",
    0,
    0,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        )
      THEN 0
      ELSE 1
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED"  = 'N')
        AND ("E"."F_IMPRSMT_OMP"  = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"    = 'N')
        AND ("U"."F_EVIDENCE"     = "E"."SYS_ID")
        AND ("U"."F_EXP_EXHIBIT" <> '09'
        AND "U"."F_EXP_EXHIBIT"  <> '16'
        AND "U"."F_EXP_EXHIBIT"  <> '14'
        AND "U"."F_EXP_EXHIBIT"  <> '15'
        AND "U"."F_EXP_EXHIBIT"  <> '02'
        AND "U"."F_EXP_EXHIBIT"  <> '21'
        AND "U"."F_EXP_EXHIBIT"  <> '12')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_EXHIBIT" = '09')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_EXHIBIT" = '16')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_EXHIBIT" = '02')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_EXHIBIT" = '14'
        OR "U"."F_EXP_EXHIBIT"   = '15'
        OR "U"."F_EXP_EXHIBIT"   = '21'
        OR "U"."F_EXP_EXHIBIT"   = '12')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_KIND"    = '16-01')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_KIND"    = '16-02'
        OR "U"."F_EXP_KIND"      = '16-03')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_KIND"    = '16-06')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_KIND"    = '16-04')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_EXHIBIT" = '16')
        AND ("U"."F_EXP_KIND"   <> '16-01')
        AND ("U"."F_EXP_KIND"   <> '16-02')
        AND ("U"."F_EXP_KIND"   <> '16-03')
        AND ("U"."F_EXP_KIND"   <> '16-04')
        AND ("U"."F_EXP_KIND"   <> '16-06')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_KIND"    = '02-01'
        OR "U"."F_EXP_KIND"      = '02-02')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_KIND"    = '02-03'
        OR "U"."F_EXP_KIND"      = '02-04'
        OR "U"."F_EXP_KIND"      = '02-05')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN EXISTS
        (SELECT *
        FROM "T_SYS_EVIDENCE" "E",
          "T_SYS_UNDER_EXP" "U"
        WHERE ("E"."SYS_DELETED" = 'N')
        AND ("E"."F_IMPRSMT_OMP" = "SD"."SYS_ID")
        AND ("U"."SYS_DELETED"   = 'N')
        AND ("U"."F_EVIDENCE"    = "E"."SYS_ID")
        AND ("U"."F_EXP_KIND"    = '02-06')
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_N_DELA" IS NOT NULL
      AND "F"."F_KAT_DELA"  = '1')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_MAIN_VID_PREST" = '58')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_VID_PREST" = '56-02')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_MAIN_VID_PREST" = '40'
      OR "F"."F_MAIN_VID_PREST"    = '41'
      OR "F"."F_MAIN_VID_PREST"    = '42'
      OR "F"."F_MAIN_VID_PREST"    = '43'
      OR "F"."F_MAIN_VID_PREST"    = '44'
      OR "F"."F_MAIN_VID_PREST"    = '60')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("SD"."F_OMP_TYPE" = '02')
      THEN 1
      ELSE 0
    END
  FROM "T_DIC_MAIN" "D",
    "T_SYS_OMP" "SD",
    "T_SYS_JOURNAL_OMP" "J",
    "T_SYS_FABULA" "F"
  WHERE ("D"."F_DOMAIN"    = 'Regions-EKC')
  AND ("D"."SYS_DELETED"   = 'N')
  AND ("SD"."SYS_DELETED"  = 'N')
  AND ("J"."SYS_DELETED"   = 'N')
  AND ("J"."F_DEPART"      = "D"."F_CODE")
  AND ("J"."F_REF_OMP"     = "SD"."SYS_ID")
  AND ("F"."SYS_DELETED"   = 'N')
  AND ("SD"."F_FABULA_REF" = "F"."SYS_ID")
  -- Expertizes:
  UNION
  SELECT "SD"."SYS_ID",
    "D"."F_CODE",
    "D"."F_MEAN",
    "SD"."F_ARRIVAL_DATE",
    0,
    1,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    CASE
      WHEN ("F"."F_N_DELA" IS NOT NULL
      AND "F"."F_KAT_DELA"  = '1')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_MAIN_VID_PREST" = '58')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_VID_PREST" = '56-02')
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN ("F"."F_MAIN_VID_PREST" = '40'
      OR "F"."F_MAIN_VID_PREST"    = '41'
      OR "F"."F_MAIN_VID_PREST"    = '42'
      OR "F"."F_MAIN_VID_PREST"    = '43'
      OR "F"."F_MAIN_VID_PREST"    = '44'
      OR "F"."F_MAIN_VID_PREST"    = '60')
      THEN 1
      ELSE 0
    END,
    0
  FROM "T_DIC_MAIN" "D",
    "T_SYS_EXPERTZ" "SD",
    "T_SYS_FABULA" "F"
  WHERE ("D"."F_DOMAIN"    = 'Regions-EKC')
  AND ("D"."SYS_DELETED"   = 'N')
  AND ("SD"."SYS_DELETED"  = 'N')
  AND ("SD"."F_EKC_AREA"   = "D"."F_CODE")
  AND ("SD"."F_EXPRT_TYPE" = '01')
  AND ("F"."SYS_DELETED"   = 'N')
  AND ("SD"."F_REF_FABULA" = "F"."SYS_ID")
  ) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_REPORT_DACT" ("SYS_ID", "REGION", "REGION_ORDER", "REGION_CODE", "REG_AREA", "RECIEVE_DATE", "FLG_DCARD", "FLG_CORPSE", "FLG_IDENT_CORPSE", "FLG_EVIDENCE")
AS
  (SELECT F.SYS_ID,
    CASE
      WHEN EXISTS
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      THEN
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      ELSE ''
    END,
    (SELECT R.F_ORDER
    FROM T_DIC_MAIN R
    WHERE (F.F_REGION  = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    F.F_REGION,
    F.F_INPUT_EKC,
    F.F_RECEIVE_DATE,
    (SELECT COUNT(*)
    FROM T_SYS_PERSON_DACT_IN_FOLDER D,
      T_SYS_PERSON_DACT K
    WHERE D.F_REF_FOLDER = F.SYS_ID
    AND D.SYS_DELETED    = 'N'
    AND K.SYS_DELETED    = 'N'
    AND K.SYS_ID         = D.F_REF_DACT
    ),
    (SELECT COUNT(*)
    FROM T_SYS_PERSON_DACT_IN_FOLDER D,
      T_SYS_PERSON_DACT K,
      T_SYS_PERSON P
    WHERE D.F_REF_FOLDER = F.SYS_ID
    AND D.SYS_DELETED    = 'N'
    AND K.SYS_DELETED    = 'N'
    AND K.SYS_ID         = D.F_REF_DACT
    AND P.SYS_DELETED    = 'N'
    AND P.SYS_ID         = K.F_REF_PERSON
    AND P.F_IS_CORPSE    = 'Y'
    ),
    0,
    0
  FROM T_SYS_DACT_FOLDER F
  WHERE F.SYS_DELETED = 'N'
  UNION
  SELECT K.SYS_ID,
    CASE
      WHEN EXISTS
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      THEN
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      ELSE ''
    END,
    (SELECT R.F_ORDER
    FROM T_DIC_MAIN R
    WHERE (F.F_REGION  = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    F.F_REGION,
    RV.F_REG_AREA,
    RV.F_DATE,
    0,
    0,
    CASE
      WHEN (RV.F_REVEL_TYPE = 'D')
      AND EXISTS
        (SELECT *
        FROM T_SYS_PERSON P
        WHERE P.SYS_DELETED = 'N'
        AND P.SYS_ID        = K.F_REF_PERSON
        AND P.F_IS_CORPSE   = 'Y'
        )
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN (RV.F_REVEL_TYPE = 'R')
      THEN 1
      ELSE 0
    END
  FROM T_SYS_PERSON_DACT K,
    T_SYS_REVELATION RV,
    T_SYS_PERSON_DACT_IN_FOLDER D,
    T_SYS_DACT_FOLDER F
  WHERE K.SYS_DELETED = 'N'
  AND RV.SYS_DELETED  = 'N'
  AND (RV.F_REF_DACT  = K.SYS_ID
  OR RV.F_REF_DACT2   = K.SYS_ID)
  AND D.SYS_DELETED   = 'N'
  AND K.SYS_ID        = D.F_REF_DACT
  AND F.SYS_DELETED   = 'N'
  AND F.SYS_ID        = D.F_REF_FOLDER
  ) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_REPORT_DACT_MAIN" ("REGION")
AS
  (SELECT "D"."F_MEAN"
  FROM "T_DIC_MAIN" "D"
  WHERE ("D"."F_DOMAIN"   = 'Regions-EKC')
  AND ("D"."SYS_DELETED"  = 'N')
  AND ("D"."F_REF_DOMAIN" = '2'
  OR "D"."F_REF_DOMAIN"   = '3')
  ) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_TRAS_MOUNTH_REPORT" ("SYS_ID", "EKC_NUMBER", "REGION", "REG_AREA", "REG_YEAR", "REG_MONTH", "FLG_SIMPLE", "FLG_REVEL", "FLG_IK", "CRIME_YEAR", "TYPE_02", "TYPE_03", "TYPE_04")
AS
  (SELECT F.SYS_ID,
    (SELECT R.F_REF_DOMAIN
    FROM T_DIC_MAIN R
    WHERE (F.F_REGION  = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    CASE
      WHEN EXISTS
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      THEN
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (F.F_REGION  = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      ELSE ''
    END,
    F.F_INPUT_EKC,
    TO_CHAR(F.F_RECEIVE_DATE,'YYYY'),
    TO_CHAR(F.F_RECEIVE_DATE,'MM'),
    (SELECT COUNT(*)
    FROM T_SYS_PERSON_SAMPLE
    WHERE F_REF_FOLDER = F.SYS_ID
    AND SYS_DELETED    = 'N'
    ),
    0,
    0,
    '0000',
    CASE
      WHEN F.F_TYPE = '02'
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN F.F_TYPE = '03'
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN F.F_TYPE = '04'
      THEN 1
      ELSE 0
    END
  FROM T_SYS_SAMPLE_FOLDER F
  WHERE F.SYS_DELETED = 'N'
  AND (F.F_TYPE       = '02'
  OR F.F_TYPE         = '03'
  OR F.F_TYPE         = '04')
  UNION
  SELECT IK.SYS_ID,
    (SELECT R.F_REF_DOMAIN
    FROM T_DIC_MAIN R
    WHERE (A.F_AREA    = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    CASE
      WHEN EXISTS
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (A.F_AREA    = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      THEN
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (A.F_AREA    = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      ELSE ''
    END,
    IK.F_EKC_DEPART,
    TO_CHAR(IK.F_EKC_REG_DATE,'YYYY'),
    TO_CHAR(IK.F_EKC_REG_DATE,'MM'),
    0,
    0,
    IK.F_NUM_TOTAL,
    TO_CHAR(F.F_DATE,'YYYY'),
    CASE
      WHEN IK.F_TYPE = '02'
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN IK.F_TYPE = '03'
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN IK.F_TYPE = '04'
      THEN 1
      ELSE 0
    END
  FROM T_SYS_INFO_CARD IK,
    T_SYS_EXPERTZ E,
    T_SYS_FABULA F,
    T_DIC_ADDRESS A
  WHERE IK.SYS_DELETED = 'N'
  AND (IK.F_TYPE       = '02'
  OR IK.F_TYPE         = '03'
  OR IK.F_TYPE         = '04')
  AND E.SYS_DELETED    = 'N'
  AND E.SYS_ID         = IK.F_REF_EXPERTZ
  AND F.SYS_DELETED    = 'N'
  AND F.SYS_ID         = E.F_REF_FABULA
  AND A.SYS_DELETED    = 'N'
  AND A.SYS_ID         = F.F_ADDR
  UNION
  SELECT IK.SYS_ID,
    (SELECT R.F_REF_DOMAIN
    FROM T_DIC_MAIN R
    WHERE (A.F_AREA    = R.F_CODE)
    AND (R.F_DOMAIN    = 'Area')
    AND (R.SYS_DELETED = 'N')
    ),
    CASE
      WHEN EXISTS
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (A.F_AREA    = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      THEN
        (SELECT R.F_MEAN
        FROM T_DIC_MAIN R
        WHERE (A.F_AREA    = R.F_CODE)
        AND (R.F_DOMAIN    = 'Area')
        AND (R.SYS_DELETED = 'N')
        )
      ELSE ''
    END,
    IK.F_EKC_DEPART,
    TO_CHAR(REV.F_DATE,'YYYY'),
    TO_CHAR(REV.F_DATE,'MM'),
    0,
    1,
    0,
    TO_CHAR(F.F_DATE,'YYYY'),
    CASE
      WHEN IK.F_TYPE = '02'
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN IK.F_TYPE = '03'
      THEN 1
      ELSE 0
    END,
    CASE
      WHEN IK.F_TYPE = '04'
      THEN 1
      ELSE 0
    END
  FROM T_SYS_INFO_CARD IK,
    T_SYS_EXPERTZ E,
    T_SYS_FABULA F,
    T_DIC_ADDRESS A,
    T_SYS_REVELATION REV
  WHERE IK.SYS_DELETED   = 'N'
  AND (IK.F_TYPE         = '02'
  OR IK.F_TYPE           = '03'
  OR IK.F_TYPE           = '04')
  AND E.SYS_DELETED      = 'N'
  AND E.SYS_ID           = IK.F_REF_EXPERTZ
  AND F.SYS_DELETED      = 'N'
  AND F.SYS_ID           = E.F_REF_FABULA
  AND A.SYS_DELETED      = 'N'
  AND A.SYS_ID           = F.F_ADDR
  AND REV.SYS_DELETED    = 'N'
  AND REV.F_REVEL_TYPE   = 'S'
  AND REV.F_REF_INFO_CARD=IK.SYS_ID
  ) ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_UNIONS_INFO_CARD" ("F_DATE", "F_REF_INFO_CARD")
AS
  SELECT r.f_date,
    r.f_ref_info_card
  FROM t_sys_revelation r
  WHERE r.sys_deleted='N'
  AND r.f_revel_type ='U'
  UNION
  SELECT r.f_date,
    r.f_ref_info_card2
  FROM t_sys_revelation r
  WHERE r.sys_deleted='N'
  AND r.f_revel_type ='U' ;



CREATE OR REPLACE FORCE VIEW "EKC15"."V_WATCHDOG_UNIONS" ("REV_ID", "EXP_ID", "F_REVEL_HOW", "F_REF_WATCHDOG", "F_REF_WATCHDOG2", "F_REG_NUM", "F_REG_NUM2", "FABULA1_ID", "FABULA2_ID")
AS
  SELECT r.sys_id,
    l.f_ref_expertz,
    r.f_revel_how,
    r.f_ref_info_card,
    r.f_ref_info_card2,
    wd.F_INIT_REG_NUM,
    wd2.F_INIT_REG_NUM,
    wd.P_FABULA_ID,
    wd2.P_FABULA_ID
  FROM t_sys_revelation r,
    t_sys_revelation_in_expertz l,
    v_information_card wd,
    v_information_card wd2
    --       t_sys_info_card wd,
    --        t_sys_info_card wd2
  WHERE r.sys_deleted    = 'N'
  AND l.sys_deleted      = 'N'
  AND l.f_ref_revelation = r.sys_id
  AND r.f_revel_type     = 'U'
  AND r.f_ref_info_card  = wd.sys_id
  AND r.f_ref_info_card2 = wd2.sys_id ;



